@@ -13,12 +13,8 @@
 #
 # Copyright Buildbot Team Members
 #
-# Keep in sync with slave/buildslave/__init__.py
-#
 # We can't put this method in utility modules, because they import dependency packages
 
-from __future__ import division
-from __future__ import print_function
 
 import os
 import re
@@ -57,11 +53,11 @@ def mTimeVersion(init_file):
     for root, dirs, files in os.walk(cwd):
         for f in files:
             m = max(os.path.getmtime(os.path.join(root, f)), m)
-    d = datetime.datetime.fromtimestamp(m)
+    d = datetime.datetime.utcfromtimestamp(m)
     return d.strftime("%Y.%m.%d")
 
 
-def getVersionFromArchiveId(git_archive_id='1535914132  (HEAD -> master, tag: v1.4.0)'):
+def getVersionFromArchiveId(git_archive_id='1549551369  (HEAD -> master, tag: v2.0.1)'):
     """ Extract the tag if a source is from git archive.
 
         When source is exported via `git archive`, the git_archive_id init value is modified
@@ -84,7 +80,7 @@ def getVersionFromArchiveId(git_archive_id='1535914132  (HEAD -> master, tag: v1
 
         # archived revision is not tagged, use the commit date
         tstamp = git_archive_id.strip().split()[0]
-        d = datetime.datetime.fromtimestamp(int(tstamp))
+        d = datetime.datetime.utcfromtimestamp(int(tstamp))
         return d.strftime('%Y.%m.%d')
     return None
 
