@@ -17,8 +17,6 @@
 
 # Many thanks to Dave Peticolas for contributing this module
 
-from __future__ import absolute_import
-from __future__ import print_function
 from future.utils import text_type
 
 import datetime
@@ -125,7 +123,7 @@ class P4Source(base.PollingChangeSource, util.ComparableMixin):
                  pollInterval=60 * 10, histmax=None, pollinterval=-2,
                  encoding='utf8', project=None, name=None,
                  use_tickets=False, ticket_login_interval=60 * 60 * 24,
-                 server_tz=None, pollAtLaunch=False, revlink=lambda branch, revision: (u'')):
+                 server_tz=None, pollAtLaunch=False, revlink=lambda branch, revision: (''), resolvewho=lambda who: (who)):
 
         # for backward compatibility; the parameter used to be spelled with 'i'
         if pollinterval != -2:
@@ -149,6 +147,10 @@ class P4Source(base.PollingChangeSource, util.ComparableMixin):
             config.error(
                 "You need to provide a valid callable for revlink")
 
+        if not callable(resolvewho):
+            config.error(
+                "You need to provide a valid callable for resolvewho")
+
         self.p4port = p4port
         self.p4user = p4user
         self.p4passwd = p4passwd
@@ -160,6 +162,7 @@ class P4Source(base.PollingChangeSource, util.ComparableMixin):
         self.use_tickets = use_tickets
         self.ticket_login_interval = ticket_login_interval
         self.revlink_callable = revlink
+        self.resolvewho_callable = resolvewho
         self.server_tz = dateutil.tz.gettz(server_tz) if server_tz else None
         if server_tz is not None and self.server_tz is None:
             raise P4PollerError("Failed to get timezone from server_tz string '{}'".format(server_tz))
@@ -177,8 +180,8 @@ class P4Source(base.PollingChangeSource, util.ComparableMixin):
         return d
 
     def _get_process_output(self, args):
-        env = dict([(e, os.environ.get(e))
-                    for e in self.env_vars if os.environ.get(e)])
+        env = {e: os.environ.get(e)
+               for e in self.env_vars if os.environ.get(e)}
         d = utils.getProcessOutput(self.p4bin, args, env)
         return d
 
@@ -195,9 +198,9 @@ class P4Source(base.PollingChangeSource, util.ComparableMixin):
 
     def _parseTicketPassword(self, text):
         lines = text.split("\n")
-        if len(lines) < 2:
+        if len(lines) < 3:
             return None
-        return lines[1].strip()
+        return lines[2].strip()
 
     def _getPasswd(self):
         if self.use_tickets:
@@ -246,8 +249,8 @@ class P4Source(base.PollingChangeSource, util.ComparableMixin):
         try:
             result = bytes2unicode(result, self.encoding)
         except UnicodeError as ex:
-            log.msg(u"Warning: cannot fully decode {} in {}".format(
-                    repr(result), self.encoding))
+            log.msg("{}: cannot fully decode {} in {}".format(
+                    ex, repr(result), self.encoding))
             result = bytes2unicode(result, encoding=self.encoding, errors="replace")
 
         last_change = self.last_change
@@ -301,7 +304,7 @@ class P4Source(base.PollingChangeSource, util.ComparableMixin):
             if not m:
                 raise P4PollerError(
                     "Unexpected 'p4 describe -s' result: %r" % result)
-            who = m.group('who')
+            who = self.resolvewho_callable(m.group('who'))
             when = datetime.datetime.strptime(m.group('when'), self.datefmt)
             if self.server_tz:
                 # Convert from the server's timezone to the local timezone.
