@@ -13,11 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-from future.utils import PY3
-from future.utils import iteritems
-from future.utils import itervalues
 from future.utils import string_types
 from future.utils import text_type
 
@@ -41,13 +36,11 @@ from buildbot import util
 from buildbot.interfaces import IRenderable
 from buildbot.revlinks import default_revlink_matcher
 from buildbot.util import ComparableMixin
-from buildbot.util import bytes2NativeString
+from buildbot.util import bytes2unicode
 from buildbot.util import config as util_config
 from buildbot.util import identifiers as util_identifiers
 from buildbot.util import safeTranslate
 from buildbot.util import service as util_service
-from buildbot.worker_transition import WorkerAPICompatMixin
-from buildbot.worker_transition import reportDeprecatedWorkerNameUsage
 from buildbot.www import auth
 from buildbot.www import avatar
 from buildbot.www.authz import authz
@@ -71,8 +64,6 @@ class ConfigErrors(Exception):
 
     def __bool__(self):
         return bool(len(self.errors))
-    if not PY3:
-        __nonzero__ = __bool__
 
 
 _errors = None
@@ -192,7 +183,7 @@ class FileLoader(ComparableMixin, object):
         return config
 
 
-class MasterConfig(util.ComparableMixin, WorkerAPICompatMixin):
+class MasterConfig(util.ComparableMixin):
 
     def __init__(self):
         # local import to avoid circular imports
@@ -239,7 +230,6 @@ class MasterConfig(util.ComparableMixin, WorkerAPICompatMixin):
         self.secretsProviders = []
         self.builders = []
         self.workers = []
-        self._registerOldWorkerAttr("workers")
         self.change_sources = []
         self.status = []
         self.user_managers = []
@@ -298,10 +288,6 @@ class MasterConfig(util.ComparableMixin, WorkerAPICompatMixin):
         "validation",
         "www",
         "workers",
-
-        # deprecated, c['protocols']['pb']['port'] should be used
-        "slavePortnum",
-        "slaves",  # deprecated, "worker" should be used
     ])
     compare_attrs = list(_known_config_keys)
 
@@ -314,10 +300,10 @@ class MasterConfig(util.ComparableMixin, WorkerAPICompatMixin):
             'when_timestamp': kwargs.get('when_timestamp', None),
             'branch': kwargs.get('branch', None),
             'category': kwargs.get('category', None),
-            'revlink': kwargs.get('revlink', u''),
+            'revlink': kwargs.get('revlink', ''),
             'properties': kwargs.get('properties', {}),
-            'repository': kwargs.get('repository', u''),
-            'project': kwargs.get('project', u''),
+            'repository': kwargs.get('repository', ''),
+            'project': kwargs.get('project', ''),
             'codebase': kwargs.get('codebase', None)
         }
 
@@ -489,17 +475,12 @@ class MasterConfig(util.ComparableMixin, WorkerAPICompatMixin):
 
         protocols = config_dict.get('protocols', {})
         if isinstance(protocols, dict):
-            for proto, options in iteritems(protocols):
+            for proto, options in protocols.items():
                 if not isinstance(proto, str):
                     error("c['protocols'] keys must be strings")
                 if not isinstance(options, dict):
                     error("c['protocols']['%s'] must be a dict" % proto)
                     return
-                if (proto == "pb" and options.get("port") and
-                        'slavePortnum' in config_dict):
-                    error("Both c['slavePortnum'] and c['protocols']['pb']['port']"
-                          " defined, recommended to remove slavePortnum and leave"
-                          " only c['protocols']['pb']['port']")
                 if proto == "wamp":
                     self.check_wamp_proto(options)
         else:
@@ -507,19 +488,6 @@ class MasterConfig(util.ComparableMixin, WorkerAPICompatMixin):
             return
         self.protocols = protocols
 
-        # saved for backward compatibility
-        if 'slavePortnum' in config_dict:
-            reportDeprecatedWorkerNameUsage(
-                "c['slavePortnum'] key is deprecated, use "
-                "c['protocols']['pb']['port'] instead",
-                filename=filename)
-            port = config_dict.get('slavePortnum')
-            if isinstance(port, int):
-                port = "tcp:%d" % port
-            pb_options = self.protocols.get('pb', {})
-            pb_options['port'] = port
-            self.protocols['pb'] = pb_options
-
         if 'multiMaster' in config_dict:
             self.multiMaster = config_dict["multiMaster"]
 
@@ -618,7 +586,7 @@ class MasterConfig(util.ComparableMixin, WorkerAPICompatMixin):
             if not isinstance(caches, dict):
                 error("c['caches'] must be a dictionary")
             else:
-                for (name, value) in iteritems(caches):
+                for (name, value) in caches.items():
                     if not isinstance(value, int):
                         error("value for cache size '%s' must be an integer"
                               % name)
@@ -730,31 +698,16 @@ class MasterConfig(util.ComparableMixin, WorkerAPICompatMixin):
     def load_workers(self, filename, config_dict):
         config_valid = True
 
-        deprecated_workers = config_dict.get('slaves')
-        if deprecated_workers is not None:
-            reportDeprecatedWorkerNameUsage(
-                "c['slaves'] key is deprecated, use c['workers'] instead",
-                filename=filename)
-            if not self._check_workers(deprecated_workers, "c['slaves']"):
-                config_valid = False
-
         workers = config_dict.get('workers')
         if workers is not None:
             if not self._check_workers(workers, "c['workers']"):
                 config_valid = False
 
-        if deprecated_workers is not None and workers is not None:
-            error("Use of c['workers'] and c['slaves'] at the same time is "
-                  "not supported. Use only c['workers'] instead")
-            return
-
         if not config_valid:
             return
 
-        elif deprecated_workers is not None or workers is not None:
+        elif workers is not None:
             self.workers = []
-            if deprecated_workers is not None:
-                self.workers.extend(deprecated_workers)
             if workers is not None:
                 self.workers.extend(workers)
 
@@ -857,8 +810,8 @@ class MasterConfig(util.ComparableMixin, WorkerAPICompatMixin):
             error("no builders are configured")
 
         # check that all builders are implemented on this master
-        unscheduled_buildernames = set([b.name for b in self.builders])
-        for s in itervalues(self.schedulers):
+        unscheduled_buildernames = {b.name for b in self.builders}
+        for s in self.schedulers.values():
             builderNames = s.listBuilderNames()
             if interfaces.IRenderable.providedBy(builderNames):
                 unscheduled_buildernames.clear()
@@ -877,9 +830,9 @@ class MasterConfig(util.ComparableMixin, WorkerAPICompatMixin):
         if self.multiMaster:
             return
 
-        all_buildernames = set([b.name for b in self.builders])
+        all_buildernames = {b.name for b in self.builders}
 
-        for s in itervalues(self.schedulers):
+        for s in self.schedulers.values():
             builderNames = s.listBuilderNames()
             if interfaces.IRenderable.providedBy(builderNames):
                 continue
@@ -913,7 +866,7 @@ class MasterConfig(util.ComparableMixin, WorkerAPICompatMixin):
     def check_builders(self):
         # look both for duplicate builder names, and for builders pointing
         # to unknown workers
-        workernames = set([w.workername for w in self.workers])
+        workernames = {w.workername for w in self.workers}
         seen_names = set()
         seen_builddirs = set()
 
@@ -933,7 +886,7 @@ class MasterConfig(util.ComparableMixin, WorkerAPICompatMixin):
     def check_ports(self):
         ports = set()
         if self.protocols:
-            for proto, options in iteritems(self.protocols):
+            for proto, options in self.protocols.items():
                 if proto == 'null':
                     port = -1
                 else:
@@ -953,48 +906,15 @@ class MasterConfig(util.ComparableMixin, WorkerAPICompatMixin):
             error("workers are configured, but c['protocols'] not")
 
 
-class BuilderConfig(util_config.ConfiguredMixin, WorkerAPICompatMixin):
+class BuilderConfig(util_config.ConfiguredMixin):
 
     def __init__(self, name=None, workername=None, workernames=None,
                  builddir=None, workerbuilddir=None, factory=None,
                  tags=None, category=None,
                  nextWorker=None, nextBuild=None, locks=None, env=None,
                  properties=None, collapseRequests=None, description=None,
-                 canStartBuild=None, defaultProperties=None,
-
-                 slavename=None,  # deprecated, use `workername` instead
-                 slavenames=None,  # deprecated, use `workernames` instead
-                 # deprecated, use `workerbuilddir` instead
-                 slavebuilddir=None,
-                 nextSlave=None,  # deprecated, use `nextWorker` instead
+                 canStartBuild=None, defaultProperties=None
                  ):
-
-        # Deprecated API support.
-        if slavename is not None:
-            reportDeprecatedWorkerNameUsage(
-                "'slavename' keyword argument is deprecated, "
-                "use 'workername' instead")
-            assert workername is None
-            workername = slavename
-        if slavenames is not None:
-            reportDeprecatedWorkerNameUsage(
-                "'slavenames' keyword argument is deprecated, "
-                "use 'workernames' instead")
-            assert workernames is None
-            workernames = slavenames
-        if slavebuilddir is not None:
-            reportDeprecatedWorkerNameUsage(
-                "'slavebuilddir' keyword argument is deprecated, "
-                "use 'workerbuilddir' instead")
-            assert workerbuilddir is None
-            workerbuilddir = slavebuilddir
-        if nextSlave is not None:
-            reportDeprecatedWorkerNameUsage(
-                "'nextSlave' keyword argument is deprecated, "
-                "use 'nextWorker' instead")
-            assert nextWorker is None
-            nextWorker = nextSlave
-
         # name is required, and can't start with '_'
         if not name or type(name) not in (bytes, text_type):
             error("builder's name is required")
@@ -1037,19 +957,17 @@ class BuilderConfig(util_config.ConfiguredMixin, WorkerAPICompatMixin):
                   (name,))
 
         self.workernames = workernames
-        self._registerOldWorkerAttr("workernames")
 
         # builddir defaults to name
         if builddir is None:
             builddir = safeTranslate(name)
-            builddir = bytes2NativeString(builddir)
+            builddir = bytes2unicode(builddir)
         self.builddir = builddir
 
         # workerbuilddir defaults to builddir
         if workerbuilddir is None:
             workerbuilddir = builddir
         self.workerbuilddir = workerbuilddir
-        self._registerOldWorkerAttr("workerbuilddir")
 
         # remainder are optional
 
@@ -1072,7 +990,7 @@ class BuilderConfig(util_config.ConfiguredMixin, WorkerAPICompatMixin):
                     "builder '%s': tags list contains something that is not a string" % (name,))
 
             if len(tags) != len(set(tags)):
-                dupes = " ".join(set([x for x in tags if tags.count(x) > 1]))
+                dupes = " ".join({x for x in tags if tags.count(x) > 1})
                 error(
                     "builder '%s': tags list contains duplicate tags: %s" % (name, dupes))
         else:
@@ -1081,7 +999,6 @@ class BuilderConfig(util_config.ConfiguredMixin, WorkerAPICompatMixin):
         self.tags = tags
 
         self.nextWorker = nextWorker
-        self._registerOldWorkerAttr("nextWorker")
         if nextWorker and not callable(nextWorker):
             error('nextWorker must be a callable')
         # Keeping support of the previous nextWorker API
