@@ -13,13 +13,9 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-from future.builtins import range
-from future.moves.collections import UserList
-
 import copy
 import re
+from collections import UserList
 
 from twisted.internet import defer
 
@@ -53,8 +49,7 @@ class ResourceType(object):
 
     def getEndpoints(self):
         endpoints = self.endpoints[:]
-        for i in range(len(endpoints)):
-            ep = endpoints[i]
+        for i, ep in enumerate(endpoints):
             if not issubclass(ep, Endpoint):
                 raise TypeError("Not an Endpoint subclass")
             endpoints[i] = ep(self, self.master)
@@ -110,7 +105,7 @@ class BuildNestingMixin(object):
         # need to look in the context of a step, specified by build or
         # builder or whatever
         if 'buildid' in kwargs:
-            defer.returnValue(kwargs['buildid'])
+            return kwargs['buildid']
         else:
             builderid = yield self.getBuilderId(kwargs)
             if builderid is None:
@@ -120,12 +115,12 @@ class BuildNestingMixin(object):
                 number=kwargs['build_number'])
             if not build:
                 return
-            defer.returnValue(build['id'])
+            return build['id']
 
     @defer.inlineCallbacks
     def getStepid(self, kwargs):
         if 'stepid' in kwargs:
-            defer.returnValue(kwargs['stepid'])
+            return kwargs['stepid']
         else:
             buildid = yield self.getBuildid(kwargs)
             if buildid is None:
@@ -137,7 +132,7 @@ class BuildNestingMixin(object):
                                                         name=kwargs.get('step_name'))
             if not dbdict:
                 return
-            defer.returnValue(dbdict['id'])
+            return dbdict['id']
 
     def getBuilderId(self, kwargs):
         if 'buildername' in kwargs:
