@@ -13,8 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
 
 # copy some exceptions from the DB layer
 from buildbot.db.schedulers import SchedulerAlreadyClaimedError
