@@ -13,8 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
 
 from twisted.internet import defer
 from twisted.internet import reactor
@@ -54,10 +52,9 @@ class MasterEndpoint(base.Endpoint):
             builder = yield self.master.db.builders.getBuilder(
                 builderid=kwargs['builderid'])
             if not builder or kwargs['masterid'] not in builder['masterids']:
-                defer.returnValue(None)
-                return
+                return None
         m = yield self.master.db.masters.getMaster(kwargs['masterid'])
-        defer.returnValue(_db2data(m) if m else None)
+        return _db2data(m) if m else None
 
 
 class MastersEndpoint(base.Endpoint):
@@ -80,7 +77,7 @@ class MastersEndpoint(base.Endpoint):
                 masterlist = [m for m in masterlist if m['id'] in masterids]
             else:
                 masterlist = []
-        defer.returnValue([_db2data(m) for m in masterlist])
+        return [_db2data(m) for m in masterlist]
 
 
 class Master(base.ResourceType):
@@ -115,7 +112,7 @@ class Master(base.ResourceType):
         too_old = epoch2datetime(_reactor.seconds() - 60 * EXPIRE_MINUTES)
         masters = yield self.master.db.masters.getMasters()
         for m in masters:
-            if not forceHouseKeeping and m['last_active'] is not None and m['last_active'] >= too_old:
+            if m['last_active'] is not None and m['last_active'] >= too_old:
                 continue
 
             # mark the master inactive, and send a message on its behalf
