@@ -13,13 +13,12 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
 
 import itertools
 
 import sqlalchemy as sa
 
+from twisted.internet import defer
 from twisted.internet import reactor
 from twisted.python import log
 
@@ -69,6 +68,7 @@ class BuildRequestsConnectorComponent(base.DBConnectorComponent):
                           builder_tbl.c.name.label('buildername')
                           ]).select_from(from_clause)
 
+    # returns a Deferred that returns a value
     def getBuildRequest(self, brid):
         def thd(conn):
             reqs_tbl = self.db.model.buildrequests
@@ -83,6 +83,7 @@ class BuildRequestsConnectorComponent(base.DBConnectorComponent):
             return rv
         return self.db.pool.do(thd)
 
+    @defer.inlineCallbacks
     def getBuildRequests(self, builderid=None, complete=None, claimed=None,
                          bsid=None, branch=None, repository=None, resultSpec=None):
 
@@ -129,8 +130,10 @@ class BuildRequestsConnectorComponent(base.DBConnectorComponent):
             res = conn.execute(q)
 
             return deduplicateBrdict([self._brdictFromRow(row, self.db.master.masterid) for row in res.fetchall()])
-        return self.db.pool.do(thd)
+        res = yield self.db.pool.do(thd)
+        return res
 
+    @defer.inlineCallbacks
     def claimBuildRequests(self, brids, claimed_at=None, _reactor=reactor):
         if claimed_at is not None:
             claimed_at = datetime2epoch(claimed_at)
@@ -153,8 +156,9 @@ class BuildRequestsConnectorComponent(base.DBConnectorComponent):
 
             transaction.commit()
 
-        return self.db.pool.do(thd)
+        yield self.db.pool.do(thd)
 
+    # returns a Deferred that returns None
     def unclaimBuildRequests(self, brids):
         def thd(conn):
             transaction = conn.begin()
@@ -181,6 +185,7 @@ class BuildRequestsConnectorComponent(base.DBConnectorComponent):
             transaction.commit()
         return self.db.pool.do(thd)
 
+    @defer.inlineCallbacks
     def completeBuildRequests(self, brids, results, complete_at=None,
                               _reactor=reactor):
         assert results != RETRY, "a buildrequest cannot be completed with a retry status!"
@@ -218,7 +223,7 @@ class BuildRequestsConnectorComponent(base.DBConnectorComponent):
                     transaction.rollback()
                     raise NotClaimedError
             transaction.commit()
-        return self.db.pool.do(thd)
+        yield self.db.pool.do(thd)
 
     @staticmethod
     def _brdictFromRow(row, master_masterid):
