@@ -23,27 +23,12 @@ Define the interfaces that are implemented by various buildbot classes.
 # pylint: disable=no-method-argument
 # pylint: disable=inherit-non-class
 
-from __future__ import absolute_import
-from __future__ import print_function
-
 from zope.interface import Attribute
 from zope.interface import Interface
 
-from buildbot.worker_transition import deprecatedWorkerModuleAttribute
-
 # exceptions that can be raised while trying to start a build
 
 
-# This class is deprecated and should no longer be used.
-class NoSlaveError(Exception):
-    pass
-
-
-deprecatedWorkerModuleAttribute(locals(), NoSlaveError,
-                                compat_name="NoSlaveError",
-                                new_name="")
-
-
 class BuilderInUseError(Exception):
     pass
 
@@ -52,10 +37,6 @@ class WorkerTooOldError(Exception):
     pass
 
 
-deprecatedWorkerModuleAttribute(
-    locals(), WorkerTooOldError, compat_name="BuildSlaveTooOldError")
-
-
 class LatentWorkerFailedToSubstantiate(Exception):
     pass
 
@@ -64,11 +45,6 @@ class LatentWorkerCannotSubstantiate(Exception):
     pass
 
 
-deprecatedWorkerModuleAttribute(
-    locals(), LatentWorkerFailedToSubstantiate,
-    compat_name="LatentBuildSlaveFailedToSubstantiate")
-
-
 class LatentWorkerSubstantiatiationCancelled(Exception):
     pass
 
@@ -87,7 +63,7 @@ class IChangeSource(IPlugin):
     directories are changed in version control, this object should represent
     the changes as a change dictionary and call::
 
-      self.master.addChange(who=.., rev=.., ..)
+      self.master.data.updates.addChange(who=.., rev=.., ..)
 
     See 'Writing Change Sources' in the manual for more information.
     """
@@ -181,9 +157,6 @@ class IWorker(IPlugin):
     pass
 
 
-deprecatedWorkerModuleAttribute(locals(), IWorker, compat_name="IBuildSlave")
-
-
 class ILatentWorker(IWorker):
 
     """A worker that is not always running, but can run when requested.
@@ -215,10 +188,6 @@ class ILatentWorker(IWorker):
         """
 
 
-deprecatedWorkerModuleAttribute(
-    locals(), ILatentWorker, compat_name="ILatentBuildSlave")
-
-
 class IRenderable(Interface):
 
     """An object that can be interpolated with properties from a build.
@@ -433,10 +402,6 @@ class IStatus(Interface):
                            of builds that will be examined within any given
                            Builder.
         """
-        if builders is None:
-            builders = []
-        if branches is None:
-            branches = []
 
     def subscribe(receiver):
         """Register an IStatusReceiver to receive new status events. The
@@ -551,9 +516,6 @@ class IWorkerStatus(Interface):
         recent message was received from the worker."""
 
 
-deprecatedWorkerModuleAttribute(locals(), IWorkerStatus)
-
-
 class ISchedulerStatus(Interface):
 
     def getName():
@@ -663,8 +625,6 @@ class IBuilderStatus(Interface):
                            This argument imposes a hard limit on the number
                            of builds that will be examined.
         """
-        if branches is None:
-            branches = []
 
     def subscribe(receiver):
         """Register an IStatusReceiver to receive new status events. The
@@ -702,14 +662,6 @@ class IEventSource(Interface):
         @param minTime: a timestamp. Do not generate events occurring prior to
         this timestamp.
         """
-        if branches is None:
-            branches = []
-        if categories is None:
-            categories = []
-        if committers is None:
-            committers = []
-        if projects is None:
-            projects = []
 
 
 class IBuildStatus(Interface):
@@ -1017,15 +969,6 @@ class IStatusReceiver(IPlugin):
         """
 
 
-class IControl(Interface):
-
-    def addChange(change):
-        """Add a change to the change queue, for analysis by schedulers."""
-
-    def getBuilder(name):
-        """Retrieve the IBuilderControl object for the given Builder."""
-
-
 class IBuilderControl(Interface):
 
     def rebuildBuild(buildStatus, reason="<rebuild, no reason given>"):
