@@ -13,11 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-from future.utils import iteritems
-from future.utils import itervalues
-
 from twisted.internet import defer
 from twisted.internet import reactor
 from twisted.python import log
@@ -102,6 +97,11 @@ class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService):
             dl = []
             for builder in self.builders.values():
                 for build in builder.building:
+                    # build may be waiting for ping to worker to succeed which
+                    # may never happen if the connection to worker was broken
+                    # without TCP connection being severed
+                    build.workerforbuilder.abortPingIfAny()
+
                     dl.append(build.waitUntilFinished())
             if not dl:
                 log.msg("No running jobs, starting shutdown immediately")
@@ -141,20 +141,20 @@ class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService):
     @metrics.countMethod('BotMaster.workerLost()')
     def workerLost(self, bot):
         metrics.MetricCountEvent.log("BotMaster.attached_workers", -1)
-        for name, b in iteritems(self.builders):
+        for name, b in self.builders.items():
             if bot.workername in b.config.workernames:
                 b.detached(bot)
 
     @metrics.countMethod('BotMaster.getBuildersForWorker()')
     def getBuildersForWorker(self, workername):
-        return [b for b in itervalues(self.builders)
+        return [b for b in self.builders.values()
                 if workername in b.config.workernames]
 
     def getBuildernames(self):
         return self.builderNames
 
     def getBuilders(self):
-        return list(itervalues(self.builders))
+        return list(self.builders.values())
 
     @defer.inlineCallbacks
     def startService(self):
@@ -163,7 +163,7 @@ class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService):
             builderid = msg['builderid']
             buildername = None
             # convert builderid to buildername
-            for builder in itervalues(self.builders):
+            for builder in self.builders.values():
                 if builderid == (yield builder.getBuilderId()):
                     buildername = builder.name
                     break
@@ -205,12 +205,12 @@ class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService):
         timer.start()
 
         # arrange builders by name
-        old_by_name = dict([(b.name, b)
-                            for b in list(self)
-                            if isinstance(b, Builder)])
+        old_by_name = {b.name: b
+                       for b in list(self)
+                       if isinstance(b, Builder)}
         old_set = set(old_by_name)
-        new_by_name = dict([(bc.name, bc)
-                            for bc in new_config.builders])
+        new_by_name = {bc.name: bc
+                       for bc in new_config.builders}
         new_set = set(new_by_name)
 
         # calculate new builders, by name, and removed builders
@@ -227,9 +227,7 @@ class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService):
                 builder.master = None
                 builder.botmaster = None
 
-                # pylint: disable=cell-var-from-loop
-                yield defer.maybeDeferred(lambda:
-                                          builder.disownServiceParent())
+                yield defer.maybeDeferred(builder.disownServiceParent)
 
             for n in added_names:
                 builder = Builder(n)
