@@ -13,11 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-from future.utils import PY3
-from future.utils import iteritems
-from future.utils import itervalues
 from future.utils import raise_with_traceback
 from future.utils import string_types
 from future.utils import text_type
@@ -60,11 +55,9 @@ from buildbot.process.results import SUCCESS
 from buildbot.process.results import WARNINGS
 from buildbot.process.results import Results
 from buildbot.process.results import worst_status
-from buildbot.util import bytes2NativeString
+from buildbot.util import bytes2unicode
 from buildbot.util import debounce
 from buildbot.util import flatten
-from buildbot.worker_transition import WorkerAPICompatMixin
-from buildbot.worker_transition import deprecatedWorkerClassMethod
 
 
 class BuildStepFailed(Exception):
@@ -196,23 +189,24 @@ class SyncLogFileWrapper(logobserver.LogObserver):
     # write methods
 
     def addStdout(self, data):
-        data = bytes2NativeString(data)
+        data = bytes2unicode(data)
         self.chunks.append((self.STDOUT, data))
         self._delay(lambda: self.asyncLogfile.addStdout(data))
 
     def addStderr(self, data):
-        data = bytes2NativeString(data)
+        data = bytes2unicode(data)
         self.chunks.append((self.STDERR, data))
         self._delay(lambda: self.asyncLogfile.addStderr(data))
 
     def addHeader(self, data):
-        data = bytes2NativeString(data)
+        data = bytes2unicode(data)
         self.chunks.append((self.HEADER, data))
         self._delay(lambda: self.asyncLogfile.addHeader(data))
 
     def finish(self):
         self.finished = True
         self._maybeFinished()
+        # pylint: disable=unnecessary-lambda
         self._delay(lambda: self.asyncLogfile.finish())
 
     def unwrap(self):
@@ -259,7 +253,6 @@ class BuildStepStatus(object):
 @implementer(interfaces.IBuildStep)
 class BuildStep(results.ResultComputingConfigMixin,
                 properties.PropertiesMixin,
-                WorkerAPICompatMixin,
                 util.ComparableMixin):
 
     alwaysRun = False
@@ -329,7 +322,6 @@ class BuildStep(results.ResultComputingConfigMixin,
 
     def __init__(self, **kwargs):
         self.worker = None
-        self._registerOldWorkerAttr("worker", name="buildslave")
 
         for p in self.__class__.parms:
             if p in kwargs:
@@ -394,8 +386,6 @@ class BuildStep(results.ResultComputingConfigMixin,
 
     def setWorker(self, worker):
         self.worker = worker
-    deprecatedWorkerClassMethod(
-        locals(), setWorker, compat_name="setBuildSlave")
 
     @deprecate.deprecated(versions.Version("buildbot", 0, 9, 0))
     def setDefaultWorkdir(self, workdir):
@@ -447,30 +437,30 @@ class BuildStep(results.ResultComputingConfigMixin,
         if self.description is not None:
             stepsumm = util.join_list(self.description)
             if self.descriptionSuffix:
-                stepsumm += u' ' + util.join_list(self.descriptionSuffix)
+                stepsumm += ' ' + util.join_list(self.descriptionSuffix)
         else:
-            stepsumm = u'running'
-        return {u'step': stepsumm}
+            stepsumm = 'running'
+        return {'step': stepsumm}
 
     def getResultSummary(self):
         if self.descriptionDone is not None or self.description is not None:
             stepsumm = util.join_list(self.descriptionDone or self.description)
             if self.descriptionSuffix:
-                stepsumm += u' ' + util.join_list(self.descriptionSuffix)
+                stepsumm += ' ' + util.join_list(self.descriptionSuffix)
         else:
-            stepsumm = u'finished'
+            stepsumm = 'finished'
 
         if self.results != SUCCESS:
-            stepsumm += u' (%s)' % Results[self.results]
+            stepsumm += ' (%s)' % Results[self.results]
 
-        return {u'step': stepsumm}
+        return {'step': stepsumm}
 
     @defer.inlineCallbacks
     def getBuildResultSummary(self):
         summary = yield self.getResultSummary()
-        if self.results in self.updateBuildSummaryPolicy and u'build' not in summary and u'step' in summary:
-            summary[u'build'] = summary[u'step']
-        defer.returnValue(summary)
+        if self.results in self.updateBuildSummaryPolicy and 'build' not in summary and 'step' in summary:
+            summary['build'] = summary['step']
+        return summary
 
     @debounce.method(wait=1)
     @defer.inlineCallbacks
@@ -491,7 +481,7 @@ class BuildStep(results.ResultComputingConfigMixin,
                 raise TypeError('getCurrentSummary must return a dictionary: ' +
                                 methodInfo(self.getCurrentSummary))
 
-        stepResult = summary.get('step', u'finished')
+        stepResult = summary.get('step', 'finished')
         if not isinstance(stepResult, text_type):
             raise TypeError("step result string must be unicode (got %r)"
                             % (stepResult,))
@@ -631,12 +621,12 @@ class BuildStep(results.ResultComputingConfigMixin,
             self.results = EXCEPTION
         self.releaseLocks()
 
-        defer.returnValue(self.results)
+        return self.results
 
     @defer.inlineCallbacks
     def finishUnfinishedLogs(self):
         ok = True
-        not_finished_logs = [v for (k, v) in iteritems(self.logs)
+        not_finished_logs = [v for (k, v) in self.logs.items()
                              if not v.finished]
         finish_logs = yield defer.DeferredList([v.finish() for v in not_finished_logs],
                                                consumeErrors=True)
@@ -644,7 +634,7 @@ class BuildStep(results.ResultComputingConfigMixin,
             if not success:
                 log.err(res, "when trying to finish a log")
                 ok = False
-        defer.returnValue(ok)
+        return ok
 
     def acquireLocks(self, res=None):
         self._acquiringLock = None
@@ -730,7 +720,7 @@ class BuildStep(results.ResultComputingConfigMixin,
                         results = EXCEPTION
                 unhandled = self._start_unhandled_deferreds
 
-        defer.returnValue(results)
+        return results
 
     def finished(self, results):
         assert self._start_deferred, \
@@ -744,9 +734,7 @@ class BuildStep(results.ResultComputingConfigMixin,
 
     def isNewStyle(self):
         # **temporary** method until new-style steps are the only supported style
-        if PY3:
-            return self.run.__func__ is not BuildStep.run
-        return self.run.im_func is not BuildStep.run.im_func
+        return self.run.__func__ is not BuildStep.run
 
     def start(self):
         # New-style classes implement 'run'.
@@ -784,7 +772,6 @@ class BuildStep(results.ResultComputingConfigMixin,
 
     def workerVersion(self, command, oldversion=None):
         return self.build.getWorkerCommandVersion(command, oldversion)
-    deprecatedWorkerClassMethod(locals(), workerVersion)
 
     def workerVersionIsOlderThan(self, command, minversion):
         sv = self.build.getWorkerCommandVersion(command, None)
@@ -793,17 +780,14 @@ class BuildStep(results.ResultComputingConfigMixin,
         if [int(s) for s in sv.split(".")] < [int(m) for m in minversion.split(".")]:
             return True
         return False
-    deprecatedWorkerClassMethod(locals(), workerVersionIsOlderThan)
 
     def checkWorkerHasCommand(self, command):
         if not self.workerVersion(command):
             message = "worker is too old, does not know about %s" % command
             raise WorkerTooOldError(message)
-    deprecatedWorkerClassMethod(locals(), checkWorkerHasCommand)
 
     def getWorkerName(self):
         return self.build.getWorkerName()
-    deprecatedWorkerClassMethod(locals(), getWorkerName)
 
     def addLog(self, name, type='s', logEncoding=None):
         d = self.master.data.updates.addLog(self.stepid,
@@ -837,8 +821,8 @@ class BuildStep(results.ResultComputingConfigMixin,
     @defer.inlineCallbacks
     def addCompleteLog(self, name, text):
         logid = yield self.master.data.updates.addLog(self.stepid,
-                                                      util.bytes2unicode(name), u't')
-        _log = self._newLog(name, u't', logid)
+                                                      util.bytes2unicode(name), 't')
+        _log = self._newLog(name, 't', logid)
         yield _log.addContent(text)
         yield _log.finish()
 
@@ -846,9 +830,9 @@ class BuildStep(results.ResultComputingConfigMixin,
     @defer.inlineCallbacks
     def addHTMLLog(self, name, html):
         logid = yield self.master.data.updates.addLog(self.stepid,
-                                                      util.bytes2unicode(name), u'h')
-        _log = self._newLog(name, u'h', logid)
-        html = bytes2NativeString(html)
+                                                      util.bytes2unicode(name), 'h')
+        _log = self._newLog(name, 'h', logid)
+        html = bytes2unicode(html)
         yield _log.addContent(html)
         yield _log.finish()
 
@@ -890,7 +874,7 @@ class BuildStep(results.ResultComputingConfigMixin,
     @defer.inlineCallbacks
     def addURL(self, name, url):
         yield self.master.data.updates.addStepURL(self.stepid, text_type(name), text_type(url))
-        defer.returnValue(None)
+        return None
 
     @defer.inlineCallbacks
     def runCommand(self, command):
@@ -900,7 +884,7 @@ class BuildStep(results.ResultComputingConfigMixin,
             res = yield command.run(self, self.remote, self.build.builder.name)
         finally:
             self.cmd = None
-        defer.returnValue(res)
+        return res
 
     def hasStatistic(self, name):
         return name in self.statistics
@@ -1020,7 +1004,7 @@ class LoggingBuildStep(BuildStep):
         d.addErrback(self.failed)
 
     def setupLogfiles(self, cmd, logfiles):
-        for logname, remotefilename in iteritems(logfiles):
+        for logname, remotefilename in logfiles.items():
             if self.lazylogfiles:
                 # Ask RemoteCommand to watch a logfile, but only add
                 # it when/if we see any data.
@@ -1108,9 +1092,9 @@ class CommandMixin(object):
         if abandonOnFailure and cmd.didFail():
             raise BuildStepFailed()
         if makeResult:
-            defer.returnValue(makeResult(cmd))
+            return makeResult(cmd)
         else:
-            defer.returnValue(not cmd.didFail())
+            return not cmd.didFail()
 
     def runRmdir(self, dir, log=None, abandonOnFailure=True):
         return self._runRemoteCommand('rmdir', abandonOnFailure,
@@ -1195,8 +1179,8 @@ class ShellMixin(object):
     def makeRemoteShellCommand(self, collectStdout=False, collectStderr=False,
                                stdioLogName='stdio',
                                **overrides):
-        kwargs = dict([(arg, getattr(self, arg))
-                       for arg in self._shellMixinArgs])
+        kwargs = {arg: getattr(self, arg)
+                  for arg in self._shellMixinArgs}
         kwargs.update(overrides)
         stdio = None
         if stdioLogName is not None:
@@ -1252,7 +1236,7 @@ class ShellMixin(object):
         # set up logging
         if stdio is not None:
             cmd.useLog(stdio, False)
-        for logname, remotefilename in iteritems(self.logfiles):
+        for logname, remotefilename in self.logfiles.items():
             if self.lazylogfiles:
                 # it's OK if this does, or does not, return a Deferred
                 def callback(cmd_arg, local_logname=logname):
@@ -1264,13 +1248,13 @@ class ShellMixin(object):
                 # and tell the RemoteCommand to feed it
                 cmd.useLog(newlog, False)
 
-        defer.returnValue(cmd)
+        return cmd
 
     def getResultSummary(self):
         summary = util.command_to_string(self.command)
         if not summary:
             return super(ShellMixin, self).getResultSummary()
-        return {u'step': summary}
+        return {'step': summary}
 
 # Parses the logs for a list of regexs. Meant to be invoked like:
 # regexes = ((re.compile(...), FAILURE), (re.compile(...), WARNINGS))
@@ -1292,7 +1276,7 @@ def regex_log_evaluator(cmd, _, regexes):
         if worst_status(worst, possible_status) == possible_status:
             if isinstance(err, string_types):
                 err = re.compile(".*%s.*" % err, re.DOTALL)
-            for l in itervalues(cmd.logs):
+            for l in cmd.logs.values():
                 if err.search(l.getText()):
                     worst = possible_status
     return worst
