@@ -13,16 +13,12 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
 
 from twisted.internet import defer
 from twisted.python import log
 from twisted.python.constants import NamedConstant
 from twisted.python.constants import Names
 
-from buildbot.worker_transition import WorkerAPICompatMixin
-
 
 class States(Names):
     # The worker isn't attached, or is in the process of attaching.
@@ -33,13 +29,12 @@ class States(Names):
     BUILDING = NamedConstant()
 
 
-class AbstractWorkerForBuilder(WorkerAPICompatMixin, object):
+class AbstractWorkerForBuilder(object):
 
     def __init__(self):
         self.ping_watchers = []
         self.state = None  # set in subclass
         self.worker = None
-        self._registerOldWorkerAttr("worker")
         self.builder_name = None
         self.locks = None
 
@@ -137,6 +132,11 @@ class AbstractWorkerForBuilder(WorkerAPICompatMixin, object):
 
         return d
 
+    def abortPingIfAny(self):
+        watchers, self.ping_watchers = self.ping_watchers, []
+        for d in watchers:
+            d.errback(PingException('aborted ping'))
+
     def _pong(self, res):
         watchers, self.ping_watchers = self.ping_watchers, []
         for d in watchers:
@@ -228,7 +228,6 @@ class LatentWorkerForBuilder(AbstractWorkerForBuilder):
             return defer.succeed(False)
 
         self.state = States.DETACHED
-        log.msg("substantiating worker %s" % (self,))
         d = self.substantiate(build)
         return d
 
