@@ -13,9 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-from future.utils import iteritems
 from future.utils import string_types
 
 import re
@@ -236,19 +233,19 @@ class MailNotifier(NotifierBase):
         # interpolation if only one build was given
         if self.extraHeaders:
             extraHeaders = self.extraHeaders
-            if len(builds) == 1:
+            if builds is not None and len(builds) == 1:
                 props = Properties.fromDict(builds[0]['properties'])
                 props.master = self.master
                 extraHeaders = yield props.render(extraHeaders)
 
-            for k, v in iteritems(extraHeaders):
+            for k, v in extraHeaders.items():
                 if k in m:
                     twlog.msg("Warning: Got header " + k +
                               " in self.extraHeaders "
                               "but it already exists in the Message - "
                               "not adding it.")
                 m[k] = v
-        defer.returnValue(m)
+        return m
 
     @defer.inlineCallbacks
     def sendMessage(self, body, subject=None, type='plain', builderName=None,
@@ -301,7 +298,7 @@ class MailNotifier(NotifierBase):
                 else:
                     twlog.msg("INVALID EMAIL: {}".format(r))
 
-        defer.returnValue(recipients)
+        return recipients
 
     def processRecipients(self, blamelist, m):
         to_recipients = set(blamelist)
