@@ -13,10 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-from future.utils import iteritems
-from future.utils import itervalues
 from future.utils import string_types
 
 import re
@@ -30,7 +26,6 @@ from buildbot.process.properties import Properties
 from buildbot.reporters.mail import VALID_EMAIL_ADDR
 from buildbot.schedulers import base
 from buildbot.util import identifiers
-from buildbot.worker_transition import deprecatedWorkerModuleAttribute
 
 
 class ValidationError(ValueError):
@@ -42,7 +37,7 @@ class CollectedValidationError(ValueError):
     def __init__(self, errors):
         self.errors = errors
         ValueError.__init__(
-            self, "\n".join([k + ":" + v for k, v in iteritems(errors)]))
+            self, "\n".join([k + ":" + v for k, v in errors.items()]))
 
 
 class ValidationErrorCollector(object):
@@ -56,11 +51,11 @@ class ValidationErrorCollector(object):
         try:
             res = yield defer.maybeDeferred(fn, *args, **kwargs)
         except CollectedValidationError as e:
-            for error_name, e in iteritems(e.errors):
+            for error_name, e in e.errors.items():
                 self.errors[error_name] = e
         except ValueError as e:
             self.errors[name] = str(e)
-        defer.returnValue(res)
+        return res
 
     def maybeRaiseCollectedErrors(self):
         errors = self.errors
@@ -77,7 +72,7 @@ class BaseParameter(object):
     BaseParameter provides a base implementation for property customization
     """
     spec_attributes = ["name", "fullName", "label", "tablabel", "type", "default", "required",
-                       "multiple", "regex", "hide", "maxsize"]
+                       "multiple", "regex", "hide", "maxsize", "autopopulate"]
     name = ""
     parentName = None
     label = ""
@@ -90,6 +85,7 @@ class BaseParameter(object):
     debug = True
     hide = False
     maxsize = None
+    autopopulate = None
 
     @property
     def fullName(self):
@@ -375,10 +371,6 @@ class WorkerChoiceParameter(ChoiceStringParameter):
         return workernames
 
 
-deprecatedWorkerModuleAttribute(locals(), WorkerChoiceParameter,
-                                compat_name="BuildslaveChoiceParameter")
-
-
 class FileParameter(BaseParameter):
     """A parameter which allows to download a whole file and store it as a property or patch
     """
@@ -555,14 +547,14 @@ class CodebaseParameter(NestedParameter):
 
         fields_dict = dict(branch=branch, revision=revision,
                            repository=repository, project=project)
-        for k, v in iteritems(fields_dict):
+        for k, v in fields_dict.items():
             if v is DefaultField:
                 v = StringParameter(name=k, label=k.capitalize() + ":")
             elif isinstance(v, string_types):
                 v = FixedParameter(name=k, default=v)
             fields_dict[k] = v
 
-        fields = [val for k, val in sorted(iteritems(fields_dict), key=lambda x: x[0]) if val]
+        fields = [val for k, val in sorted(fields_dict.items(), key=lambda x: x[0]) if val]
         if patch is not None:
             if patch.name != "patch":
                 config.error(
@@ -789,10 +781,10 @@ class ForceScheduler(base.BaseScheduler):
         changeids = [type(a) == int and a or a.number for a in changeids]
 
         real_properties = Properties()
-        for pname, pvalue in iteritems(properties):
+        for pname, pvalue in properties.items():
             real_properties.setProperty(pname, pvalue, "Force Build Form")
 
-        defer.returnValue((real_properties, changeids, sourcestamps))
+        return (real_properties, changeids, sourcestamps)
 
     @defer.inlineCallbacks
     def computeBuilderNames(self, builderNames=None, builderid=None):
@@ -805,7 +797,7 @@ class ForceScheduler(base.BaseScheduler):
         else:
             builderNames = sorted(
                 set(builderNames).intersection(self.builderNames))
-        defer.returnValue(builderNames)
+        return builderNames
 
     @defer.inlineCallbacks
     def force(self, owner, builderNames=None, builderid=None, **kwargs):
@@ -819,7 +811,7 @@ class ForceScheduler(base.BaseScheduler):
         # Currently the validation code expects all kwargs to be lists
         # I don't want to refactor that now so much sure we comply...
         kwargs = dict((k, [v]) if not isinstance(v, list) else (k, v)
-                      for k, v in iteritems(kwargs))
+                      for k, v in kwargs.items())
 
         # probably need to clean that out later as the IProperty is already a
         # validation mechanism
@@ -841,9 +833,9 @@ class ForceScheduler(base.BaseScheduler):
         r = self.reasonString % {'owner': owner, 'reason': reason}
 
         # turn sourcestamps into a list
-        for cb, ss in iteritems(sourcestamps):
+        for cb, ss in sourcestamps.items():
             ss['codebase'] = cb
-        sourcestamps = list(itervalues(sourcestamps))
+        sourcestamps = list(sourcestamps.values())
 
         # everything is validated, we can create our source stamp, and
         # buildrequest
@@ -854,4 +846,4 @@ class ForceScheduler(base.BaseScheduler):
             builderNames=builderNames,
         )
 
-        defer.returnValue(res)
+        return res
