@@ -13,8 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
 
 import json
 import os
@@ -44,4 +42,4 @@ def dataspec(config):
         f.write("window." + config['global'] + '=')
     f.write(json.dumps(data.allEndpoints(), indent=2))
     f.close()
-    defer.returnValue(0)
+    return 0
