@@ -19,11 +19,6 @@
 # Also don't forget to mirror your changes on command-line options in manual
 # pages and reStructuredText documentation.
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from future.builtins import range
-
 import sys
 import textwrap
 
@@ -191,6 +186,11 @@ class RestartOptions(base.BasedirMixin, base.SubcommandOptions):
         ['nodaemon', None, "Don't daemonize (stay in foreground)"],
         ["clean", "c", "Clean shutdown master"],
     ]
+    optParameters = [
+        ['start_timeout', None, None,
+         'The amount of time the script waits for the master to restart until '
+         'it declares the operation as failure'],
+    ]
 
     def getSynopsis(self):
         return "Usage:    buildbot restart [<basedir>]"
@@ -202,6 +202,11 @@ class StartOptions(base.BasedirMixin, base.SubcommandOptions):
         ['quiet', 'q', "Don't display startup log messages"],
         ['nodaemon', None, "Don't daemonize (stay in foreground)"],
     ]
+    optParameters = [
+        ['start_timeout', None, None,
+         'The amount of time the script waits for the master to start until it '
+         'declares the operation as failure'],
+    ]
 
     def getSynopsis(self):
         return "Usage:    buildbot start [<basedir>]"
@@ -429,8 +434,8 @@ class TryOptions(base.SubcommandOptions):
         # We need to split the value of this option
         # into a dictionary of properties
         propertylist = option.split(",")
-        for i in range(0, len(propertylist)):
-            splitproperty = propertylist[i].split("=", 1)
+        for prop in propertylist:
+            splitproperty = prop.split("=", 1)
             self['properties'][splitproperty[0]] = splitproperty[1]
 
     def opt_property(self, option):
@@ -557,8 +562,8 @@ class UserOptions(base.SubcommandOptions):
             info_elem["identifier"] = info_list[0]
             self['info'].append(info_elem)
         else:
-            for i in range(0, len(info_list)):
-                split_info = info_list[i].split("=", 1)
+            for info_item in info_list:
+                split_info = info_item.split("=", 1)
 
                 # pull identifier from update --info
                 if ":" in split_info[0]:
@@ -616,7 +621,7 @@ class UserOptions(base.SubcommandOptions):
         if not info and not ids:
             raise usage.UsageError("must specify either --ids or --info")
 
-        if op == 'add' or op == 'update':
+        if op in ('add', 'update'):
             if ids:
                 raise usage.UsageError("cannot use --ids with 'add' or "
                                        "'update'")
@@ -631,7 +636,7 @@ class UserOptions(base.SubcommandOptions):
                     if 'identifier' in user:
                         raise usage.UsageError("identifier found in add info, "
                                                "use: --info=type=value,type=value,..")
-        if op == 'remove' or op == 'get':
+        if op in ('remove', 'get'):
             if info:
                 raise usage.UsageError("cannot use --info with 'remove' "
                                        "or 'get'")
