@@ -63,10 +63,6 @@
 
 # Written by Mark Hammond, 2006.
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from future.builtins import range
 
 import os
 import sys
