@@ -13,10 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-from future.utils import PY3
-from future.utils import iteritems
 from future.utils import string_types
 
 import inspect
@@ -134,13 +130,9 @@ class ShellCommand(buildstep.LoggingBuildStep):
 
         # check validity of arguments being passed to RemoteShellCommand
         invalid_args = []
-        if PY3:
-            signature = inspect.signature(
-                remotecommand.RemoteShellCommand.__init__)
-            valid_rsc_args = signature.parameters.keys()
-        else:
-            valid_rsc_args = inspect.getargspec(
-                remotecommand.RemoteShellCommand.__init__)[0]
+        signature = inspect.signature(
+            remotecommand.RemoteShellCommand.__init__)
+        valid_rsc_args = signature.parameters.keys()
         for arg in kwargs:
             if arg not in valid_rsc_args:
                 invalid_args.append(arg)
@@ -167,19 +159,19 @@ class ShellCommand(buildstep.LoggingBuildStep):
 
     def describe(self, done=False):
         if self.stopped and not self.rendered:
-            return u"stopped early"
+            return "stopped early"
         assert(self.rendered)
         desc = self._describe(done)
         if not desc:
             return None
         if self.descriptionSuffix:
-            desc = desc + u' ' + join_list(self.descriptionSuffix)
+            desc = desc + ' ' + join_list(self.descriptionSuffix)
         return desc
 
     def getCurrentSummary(self):
         cmdsummary = self._getLegacySummary(False)
         if cmdsummary:
-            return {u'step': cmdsummary}
+            return {'step': cmdsummary}
         return super(ShellCommand, self).getCurrentSummary()
 
     def getResultSummary(self):
@@ -187,8 +179,8 @@ class ShellCommand(buildstep.LoggingBuildStep):
 
         if cmdsummary:
             if self.results != SUCCESS:
-                cmdsummary += u' (%s)' % Results[self.results]
-            return {u'step': cmdsummary}
+                cmdsummary += ' (%s)' % Results[self.results]
+            return {'step': cmdsummary}
 
         return super(ShellCommand, self).getResultSummary()
 
@@ -216,7 +208,7 @@ class ShellCommand(buildstep.LoggingBuildStep):
 
             # add the descriptionSuffix, if one was given
             if self.descriptionSuffix:
-                rv = rv + u' ' + join_list(self.descriptionSuffix)
+                rv = rv + ' ' + join_list(self.descriptionSuffix)
 
             return rv
 
@@ -351,14 +343,14 @@ class SetPropertyFromCommand(ShellCommand):
             new_props = self.extract_fn(cmd.rc,
                                         self.observer.getStdout(),
                                         self.observer.getStderr())
-            for k, v in iteritems(new_props):
+            for k, v in new_props.items():
                 self.setProperty(k, v, "SetPropertyFromCommand Step")
             self.property_changes = new_props
 
     def createSummary(self, log):
         if self.property_changes:
             props_set = ["%s: %r" % (k, v)
-                         for k, v in sorted(iteritems(self.property_changes))]
+                         for k, v in sorted(self.property_changes.items())]
             self.addCompleteLog('property changes', "\n".join(props_set))
 
     def describe(self, done=False):
@@ -400,8 +392,8 @@ class WarningCountingShellCommand(ShellCommand, CompositeStepMixin):
     warnCount = 0
     warningPattern = '(?i).*warning[: ].*'
     # The defaults work for GNU Make.
-    directoryEnterPattern = (u"make.*: Entering directory "
-                             u"[\u2019\"`'](.*)[\u2019'`\"]")
+    directoryEnterPattern = ("make.*: Entering directory "
+                             "[\u2019\"`'](.*)[\u2019'`\"]")
     directoryLeavePattern = "make.*: Leaving directory"
     suppressionFile = None
 
@@ -552,8 +544,8 @@ class WarningCountingShellCommand(ShellCommand, CompositeStepMixin):
                     continue
                 if not (warnRe is None or warnRe.search(text)):
                     continue
-                if not ((start is None and end is None) or
-                        (lineNo is not None and start <= lineNo and end >= lineNo)):
+                if ((start is not None and end is not None) and
+                   not (lineNo is not None and start <= lineNo <= end)):
                     continue
                 return
 
