@@ -13,8 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
 
 import json
 import os
@@ -34,8 +32,6 @@ from buildbot.process.buildstep import BuildStep
 from buildbot.steps.worker import CompositeStepMixin
 from buildbot.util import flatten
 from buildbot.util.eventual import eventually
-from buildbot.worker_transition import WorkerAPICompatMixin
-from buildbot.worker_transition import reportDeprecatedWorkerNameUsage
 
 
 def makeStatusRemoteCommand(step, remote_command, args):
@@ -88,25 +84,21 @@ class _TransferBuildStep(BuildStep):
             return d
 
 
-class FileUpload(_TransferBuildStep, WorkerAPICompatMixin):
+class FileUpload(_TransferBuildStep):
 
     name = 'upload'
 
-    renderables = ['workersrc', 'masterdest', 'url']
+    renderables = [
+        'masterdest',
+        'url',
+        'urlText',
+        'workersrc',
+    ]
 
     def __init__(self, workersrc=None, masterdest=None,
-                 workdir=None, maxsize=None, blocksize=16 * 1024, mode=None,
+                 workdir=None, maxsize=None, blocksize=256 * 1024, mode=None,
                  keepstamp=False, url=None, urlText=None,
-                 slavesrc=None,  # deprecated, use `workersrc` instead
                  **buildstep_kwargs):
-        # Deprecated API support.
-        if slavesrc is not None:
-            reportDeprecatedWorkerNameUsage(
-                "'slavesrc' keyword argument is deprecated, "
-                "use 'workersrc' instead")
-            assert workersrc is None
-            workersrc = slavesrc
-
         # Emulate that first two arguments are positional.
         if workersrc is None or masterdest is None:
             raise TypeError("__init__() takes at least 3 arguments")
@@ -114,7 +106,6 @@ class FileUpload(_TransferBuildStep, WorkerAPICompatMixin):
         _TransferBuildStep.__init__(self, workdir=workdir, **buildstep_kwargs)
 
         self.workersrc = workersrc
-        self._registerOldWorkerAttr("workersrc")
         self.masterdest = masterdest
         self.maxsize = maxsize
         self.blocksize = blocksize
@@ -189,7 +180,7 @@ class FileUpload(_TransferBuildStep, WorkerAPICompatMixin):
         d.addCallback(self.finished).addErrback(self.failed)
 
 
-class DirectoryUpload(_TransferBuildStep, WorkerAPICompatMixin):
+class DirectoryUpload(_TransferBuildStep):
 
     name = 'upload'
 
@@ -197,18 +188,9 @@ class DirectoryUpload(_TransferBuildStep, WorkerAPICompatMixin):
 
     def __init__(self, workersrc=None, masterdest=None,
                  workdir=None, maxsize=None, blocksize=16 * 1024,
-                 compress=None, url=None,
-                 slavesrc=None,  # deprecated, use `workersrc` instead
+                 compress=None, url=None, urlText=None,
                  **buildstep_kwargs
                  ):
-        # Deprecated API support.
-        if slavesrc is not None:
-            reportDeprecatedWorkerNameUsage(
-                "'slavesrc' keyword argument is deprecated, "
-                "use 'workersrc' instead")
-            assert workersrc is None
-            workersrc = slavesrc
-
         # Emulate that first two arguments are positional.
         if workersrc is None or masterdest is None:
             raise TypeError("__init__() takes at least 3 arguments")
@@ -216,7 +198,6 @@ class DirectoryUpload(_TransferBuildStep, WorkerAPICompatMixin):
         _TransferBuildStep.__init__(self, workdir=workdir, **buildstep_kwargs)
 
         self.workersrc = workersrc
-        self._registerOldWorkerAttr("workersrc")
         self.masterdest = masterdest
         self.maxsize = maxsize
         self.blocksize = blocksize
@@ -225,6 +206,7 @@ class DirectoryUpload(_TransferBuildStep, WorkerAPICompatMixin):
                 "'compress' must be one of None, 'gz', or 'bz2'")
         self.compress = compress
         self.url = url
+        self.urlText = urlText
 
     def start(self):
         self.checkWorkerHasCommand("uploadDirectory")
@@ -241,8 +223,12 @@ class DirectoryUpload(_TransferBuildStep, WorkerAPICompatMixin):
 
         self.descriptionDone = "uploading %s" % os.path.basename(source)
         if self.url is not None:
-            self.addURL(
-                os.path.basename(os.path.normpath(masterdest)), self.url)
+            urlText = self.urlText
+
+            if urlText is None:
+                urlText = os.path.basename(os.path.normpath(masterdest))
+
+            self.addURL(urlText, self.url)
 
         # we use maxsize to limit the amount of data on both sides
         dirWriter = remotetransfer.DirectoryWriter(
@@ -267,8 +253,7 @@ class DirectoryUpload(_TransferBuildStep, WorkerAPICompatMixin):
         d.addCallback(self.finished).addErrback(self.failed)
 
 
-class MultipleFileUpload(_TransferBuildStep, WorkerAPICompatMixin,
-                         CompositeStepMixin):
+class MultipleFileUpload(_TransferBuildStep, CompositeStepMixin):
 
     name = 'upload'
     logEnviron = False
@@ -278,15 +263,7 @@ class MultipleFileUpload(_TransferBuildStep, WorkerAPICompatMixin,
     def __init__(self, workersrcs=None, masterdest=None,
                  workdir=None, maxsize=None, blocksize=16 * 1024, glob=False,
                  mode=None, compress=None, keepstamp=False, url=None,
-                 slavesrcs=None,  # deprecated, use `workersrcs` instead
                  **buildstep_kwargs):
-        # Deprecated API support.
-        if slavesrcs is not None:
-            reportDeprecatedWorkerNameUsage(
-                "'slavesrcs' keyword argument is deprecated, "
-                "use 'workersrcs' instead")
-            assert workersrcs is None
-            workersrcs = slavesrcs
 
         # Emulate that first two arguments are positional.
         if workersrcs is None or masterdest is None:
@@ -295,7 +272,6 @@ class MultipleFileUpload(_TransferBuildStep, WorkerAPICompatMixin,
         _TransferBuildStep.__init__(self, workdir=workdir, **buildstep_kwargs)
 
         self.workersrcs = workersrcs
-        self._registerOldWorkerAttr("workersrcs")
         self.masterdest = masterdest
         self.maxsize = maxsize
         self.blocksize = blocksize
@@ -410,18 +386,18 @@ class MultipleFileUpload(_TransferBuildStep, WorkerAPICompatMixin,
                     os.path.join(self.workdir, source), abandonOnFailure=False) for source in sources
             ])
             results = [self.workerPathToMasterPath(p) for p in flatten(results)]
-            defer.returnValue(results)
+            return results
 
         @defer.inlineCallbacks
         def uploadSources(sources):
             if not sources:
-                defer.returnValue(SKIPPED)
+                return SKIPPED
             else:
                 for source in sources:
                     result = yield self.startUpload(source, masterdest)
                     if result == FAILURE:
-                        defer.returnValue(FAILURE)
-                defer.returnValue(SUCCESS)
+                        return FAILURE
+                return SUCCESS
 
         def logUpload(sources):
             log.msg("MultipleFileUpload started, from worker %r to master %r" %
@@ -453,7 +429,7 @@ class MultipleFileUpload(_TransferBuildStep, WorkerAPICompatMixin,
         return BuildStep.finished(self, result)
 
 
-class FileDownload(_TransferBuildStep, WorkerAPICompatMixin):
+class FileDownload(_TransferBuildStep):
 
     name = 'download'
 
@@ -461,16 +437,7 @@ class FileDownload(_TransferBuildStep, WorkerAPICompatMixin):
 
     def __init__(self, mastersrc, workerdest=None,
                  workdir=None, maxsize=None, blocksize=16 * 1024, mode=None,
-                 slavedest=None,  # deprecated, use `workerdest` instead
                  **buildstep_kwargs):
-        # Deprecated API support.
-        if slavedest is not None:
-            reportDeprecatedWorkerNameUsage(
-                "'slavedest' keyword argument is deprecated, "
-                "use 'workerdest' instead")
-            assert workerdest is None
-            workerdest = slavedest
-
         # Emulate that first two arguments are positional.
         if workerdest is None:
             raise TypeError("__init__() takes at least 3 arguments")
@@ -479,7 +446,6 @@ class FileDownload(_TransferBuildStep, WorkerAPICompatMixin):
 
         self.mastersrc = mastersrc
         self.workerdest = workerdest
-        self._registerOldWorkerAttr("workerdest")
         self.maxsize = maxsize
         self.blocksize = blocksize
         if not isinstance(mode, (int, type(None))):
@@ -532,7 +498,7 @@ class FileDownload(_TransferBuildStep, WorkerAPICompatMixin):
         d.addCallback(self.finished).addErrback(self.failed)
 
 
-class StringDownload(_TransferBuildStep, WorkerAPICompatMixin):
+class StringDownload(_TransferBuildStep):
 
     name = 'string_download'
 
@@ -540,16 +506,7 @@ class StringDownload(_TransferBuildStep, WorkerAPICompatMixin):
 
     def __init__(self, s, workerdest=None,
                  workdir=None, maxsize=None, blocksize=16 * 1024, mode=None,
-                 slavedest=None,  # deprecated, use `workerdest` instead
                  **buildstep_kwargs):
-        # Deprecated API support.
-        if slavedest is not None:
-            reportDeprecatedWorkerNameUsage(
-                "'slavedest' keyword argument is deprecated, "
-                "use 'workerdest' instead")
-            assert workerdest is None
-            workerdest = slavedest
-
         # Emulate that first two arguments are positional.
         if workerdest is None:
             raise TypeError("__init__() takes at least 3 arguments")
@@ -558,7 +515,6 @@ class StringDownload(_TransferBuildStep, WorkerAPICompatMixin):
 
         self.s = s
         self.workerdest = workerdest
-        self._registerOldWorkerAttr("workerdest")
         self.maxsize = maxsize
         self.blocksize = blocksize
         if not isinstance(mode, (int, type(None))):
@@ -602,21 +558,12 @@ class StringDownload(_TransferBuildStep, WorkerAPICompatMixin):
         d.addCallback(self.finished).addErrback(self.failed)
 
 
-class JSONStringDownload(StringDownload, WorkerAPICompatMixin):
+class JSONStringDownload(StringDownload):
 
     name = "json_download"
 
     def __init__(self, o, workerdest=None,
-                 slavedest=None,  # deprecated, use `workerdest` instead
                  **buildstep_kwargs):
-                # Deprecated API support.
-        if slavedest is not None:
-            reportDeprecatedWorkerNameUsage(
-                "'slavedest' keyword argument is deprecated, "
-                "use 'workerdest' instead")
-            assert workerdest is None
-            workerdest = slavedest
-
         # Emulate that first two arguments are positional.
         if workerdest is None:
             raise TypeError("__init__() takes at least 3 arguments")
@@ -628,21 +575,12 @@ class JSONStringDownload(StringDownload, WorkerAPICompatMixin):
             self, s=s, workerdest=workerdest, **buildstep_kwargs)
 
 
-class JSONPropertiesDownload(StringDownload, WorkerAPICompatMixin):
+class JSONPropertiesDownload(StringDownload):
 
     name = "json_properties_download"
 
     def __init__(self, workerdest=None,
-                 slavedest=None,  # deprecated, use `workerdest` instead
                  **buildstep_kwargs):
-        # Deprecated API support.
-        if slavedest is not None:
-            reportDeprecatedWorkerNameUsage(
-                "'slavedest' keyword argument is deprecated, "
-                "use 'workerdest' instead")
-            assert workerdest is None
-            workerdest = slavedest
-
         # Emulate that first two arguments are positional.
         if workerdest is None:
             raise TypeError("__init__() takes at least 2 arguments")
