@@ -13,8 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
 
 import os
 import stat
@@ -25,7 +23,6 @@ from buildbot.process import remotetransfer
 from buildbot.process.results import FAILURE
 from buildbot.process.results import SUCCESS
 from buildbot.util import bytes2unicode
-from buildbot.worker_transition import deprecatedWorkerClassMethod
 
 
 class WorkerBuildStep(buildstep.BuildStep):
@@ -157,12 +154,12 @@ class CopyDirectory(WorkerBuildStep):
     def getResultSummary(self):
         src = bytes2unicode(self.src, errors='replace')
         dest = bytes2unicode(self.dest, errors='replace')
-        copy = u"{} to {}".format(src, dest)
+        copy = "{} to {}".format(src, dest)
         if self.results == SUCCESS:
-            rv = u'Copied ' + copy
+            rv = 'Copied ' + copy
         else:
-            rv = u'Copying ' + copy + ' failed.'
-        return {u'step': rv}
+            rv = 'Copying ' + copy + ' failed.'
+        return {'step': rv}
 
 
 class RemoveDirectory(WorkerBuildStep):
@@ -326,7 +323,6 @@ class CompositeStepMixin():
         return self.runRemoteCommand('uploadFile', args,
                                      abandonOnFailure=abandonOnFailure,
                                      evaluateCommand=commandComplete)
-    deprecatedWorkerClassMethod(locals(), getFileContentFromWorker)
 
     def downloadFileContentToWorker(self, workerdest, strfile,
                                     abandonOnFailure=False, mode=None,
