@@ -13,6 +13,7 @@
 #
 # Copyright Buildbot Team Members
 
+import os
 import sys
 import warnings
 
@@ -63,49 +64,6 @@ if LooseVersion(mock.__version__) < LooseVersion("0.8"):
     raise ImportError("\nBuildbot tests require mock version 0.8.0 or "
                       "higher; try 'pip install -U mock'")
 
-# Force loading of deprecated modules and check that appropriate warnings
-# were emitted.
-# Without explicit load of deprecated modules it's hard to predict when
-# they will be imported and when warning should be caught.
-from buildbot.test.util.warnings import assertProducesWarning  # noqa pylint: disable=wrong-import-position
-from buildbot.worker_transition import DeprecatedWorkerAPIWarning  # noqa pylint: disable=wrong-import-position
-from buildbot.worker_transition import DeprecatedWorkerModuleWarning  # noqa pylint: disable=wrong-import-position
-
-with assertProducesWarning(
-        DeprecatedWorkerModuleWarning,
-        message_pattern=r"'buildbot\.buildslave' module is deprecated"):
-    import buildbot.buildslave as _  # noqa
-
-with assertProducesWarning(
-        DeprecatedWorkerModuleWarning,
-        message_pattern=r"'buildbot\.steps\.slave' module is deprecated"):
-    import buildbot.steps.slave as _  # noqa
-
-with assertProducesWarning(
-        DeprecatedWorkerModuleWarning,
-        message_pattern=r"'buildbot\.process\.slavebuilder' module is deprecated"):
-    import buildbot.process.slavebuilder as _  # noqa
-
-with assertProducesWarning(
-        DeprecatedWorkerModuleWarning,
-        message_pattern=r"'buildbot\.db\.buildslaves' module is deprecated"):
-    import buildbot.db.buildslaves as _  # noqa
-
-with assertProducesWarning(
-        DeprecatedWorkerModuleWarning,
-        message_pattern=r"'buildbot\.buildslave\.ec2' module is deprecated"):
-    import buildbot.buildslave.ec2 as _  # noqa
-
-with assertProducesWarning(
-        DeprecatedWorkerModuleWarning,
-        message_pattern=r"'buildbot\.buildslave\.libvirt' module is deprecated"):
-    import buildbot.buildslave.libvirt as _  # noqa
-
-with assertProducesWarning(
-        DeprecatedWorkerModuleWarning,
-        message_pattern=r"'buildbot\.buildslave\.openstack' module is deprecated"):
-    import buildbot.buildslave.openstack as _  # noqa
-
 # All deprecated modules should be loaded, consider future warnings in tests as errors.
 # In order to not pollute the test outputs,
 # warnings in tests shall be forcefully tested with assertProducesWarning,
@@ -138,3 +96,24 @@ warnings.filterwarnings('ignore', r"object\(\) takes no parameters")
 
 # this warning happens sometimes on python3.4
 warnings.filterwarnings('ignore', r"The value of convert_charrefs will become True in 3.5")
+
+# Twisted 18.4+ adds a deprecation warning and still use the deprecated API in its own code!
+warnings.filterwarnings('ignore', ".*getClientIP was deprecated.*", DeprecationWarning)
+
+# Python 3.7 adds a deprecation warning formatargspec.
+# The signature api that replaces it is not available in 2.7
+warnings.filterwarnings('ignore', ".*`formatargspec` is deprecated.*", DeprecationWarning)
+
+# Python 3.7 adds a deprecation importing ABCs from collection.
+# Such imports are made in dependencies (e.g moto, werzeug, pyparsing)
+warnings.filterwarnings('ignore', ".*Using or importing the ABCs from 'collections'.*", DeprecationWarning)
+
+# more 3.7 warning from moto
+warnings.filterwarnings('ignore', r".*Use 'list\(elem\)' or iteration over elem instead.*", DeprecationWarning)
+
+# ignore ResourceWarnings for unclosed sockets for the pg8000 driver on Python 3+ (tech debt: #4508)
+if sys.version_info[0] >= 3 and "pg8000" in os.getenv("BUILDBOT_TEST_DB_URL", ""):
+    warnings.filterwarnings('ignore', ".*unclosed .*socket", ResourceWarning)
+
+# Python 3.5 on CircleCI shows this warning
+warnings.filterwarnings('ignore', ".*the imp module is deprecated in favour of importlib*")
