@@ -13,10 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-from future.utils import iteritems
-from future.utils import itervalues
 from future.utils import text_type
 
 import json
@@ -62,7 +58,7 @@ class FakeUpdates(service.AsyncService):
 
     def assertProperties(self, sourced, properties):
         self.testcase.assertIsInstance(properties, dict)
-        for k, v in iteritems(properties):
+        for k, v in properties.items():
             self.testcase.assertIsInstance(k, text_type)
             if sourced:
                 self.testcase.assertIsInstance(v, tuple)
@@ -80,8 +76,8 @@ class FakeUpdates(service.AsyncService):
 
     def addChange(self, files=None, comments=None, author=None,
                   revision=None, when_timestamp=None, branch=None, category=None,
-                  revlink=u'', properties=None, repository=u'', codebase=None,
-                  project=u'', src=None):
+                  revlink='', properties=None, repository='', codebase=None,
+                  project='', src=None):
         if properties is None:
             properties = {}
 
@@ -140,7 +136,7 @@ class FakeUpdates(service.AsyncService):
         return defer.succeed(None)
 
     @defer.inlineCallbacks
-    def addBuildset(self, waited_for, scheduler=None, sourcestamps=None, reason=u'',
+    def addBuildset(self, waited_for, scheduler=None, sourcestamps=None, reason='',
                     properties=None, builderids=None, external_idstring=None,
                     parent_buildid=None, parent_relationship=None):
         if sourcestamps is None:
@@ -173,7 +169,7 @@ class FakeUpdates(service.AsyncService):
             properties=properties, builderids=builderids,
             waited_for=waited_for, external_idstring=external_idstring,
             parent_buildid=parent_buildid, parent_relationship=parent_relationship)
-        defer.returnValue((bsid, brids))
+        return (bsid, brids)
 
     def maybeBuildsetComplete(self, bsid):
         self.maybeBuildsetCompleteCalls += 1
@@ -186,15 +182,14 @@ class FakeUpdates(service.AsyncService):
         validation.verifyType(self.testcase, 'claimed_at', claimed_at,
                               validation.NoneOk(validation.DateTimeValidator()))
         if not brids:
-            defer.returnValue(True)
-            return
+            return True
         try:
             yield self.master.db.buildrequests.claimBuildRequests(
                 brids=brids, claimed_at=claimed_at, _reactor=_reactor)
         except AlreadyClaimedError:
-            defer.returnValue(False)
+            return False
         self.claimedBuildRequests.update(set(brids))
-        defer.returnValue(True)
+        return True
 
     @defer.inlineCallbacks
     def unclaimBuildRequests(self, brids):
@@ -237,7 +232,7 @@ class FakeUpdates(service.AsyncService):
                               validation.StringValidator())
         if name not in self.schedulerIds:
             self.schedulerIds[name] = max(
-                [0] + list(itervalues(self.schedulerIds))) + 1
+                [0] + list(self.schedulerIds.values())) + 1
         return defer.succeed(self.schedulerIds[name])
 
     def findChangeSourceId(self, name):
@@ -245,7 +240,7 @@ class FakeUpdates(service.AsyncService):
                               validation.StringValidator())
         if name not in self.changesourceIds:
             self.changesourceIds[name] = max(
-                [0] + list(itervalues(self.changesourceIds))) + 1
+                [0] + list(self.changesourceIds.values())) + 1
         return defer.succeed(self.changesourceIds[name])
 
     def findBuilderId(self, name):
@@ -387,7 +382,7 @@ class FakeUpdates(service.AsyncService):
                               validation.IntValidator())
         validation.verifyType(self.testcase, 'content', content,
                               validation.StringValidator())
-        self.testcase.assertEqual(content[-1], u'\n')
+        self.testcase.assertEqual(content[-1], '\n')
         self.logs[logid]['content'].append(content)
         return defer.succeed(None)
 
