@@ -13,10 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-from future.utils import iteritems
-
 import mock
 
 from twisted.internet import defer
@@ -37,7 +33,6 @@ from buildbot.steps import shell
 from buildbot.test.fake import fakedb
 from buildbot.test.fake import fakemaster
 from buildbot.test.fake import fakeprotocol
-from buildbot.util import unicode2NativeString
 from buildbot.worker.base import Worker
 
 
@@ -77,7 +72,7 @@ class OldStyleCustomBuildStep(buildstep.BuildStep):
 
             _log = self.addLog('foo')
             _log.addStdout('stdout\n')
-            _log.addStdout(u'\N{SNOWMAN}\n'.encode('utf-8'))
+            _log.addStdout('\N{SNOWMAN}\n'.encode('utf-8'))
             _log.addStderr('stderr\n')
             _log.finish()
 
@@ -98,10 +93,10 @@ class Latin1ProducingCustomBuildStep(buildstep.BuildStep):
     @defer.inlineCallbacks
     def run(self):
         _log = yield self.addLog('xx')
-        output_str = unicode2NativeString(u'\N{CENT SIGN}', encoding='latin-1')
+        output_str = '\N{CENT SIGN}'
         yield _log.addStdout(output_str)
         yield _log.finish()
-        defer.returnValue(results.SUCCESS)
+        return results.SUCCESS
 
 
 class FailingCustomStep(buildstep.LoggingBuildStep):
@@ -194,7 +189,7 @@ class RunSteps(unittest.TestCase):
 
         # add the buildset/request
         self.bsid, brids = yield self.master.db.buildsets.addBuildset(
-            sourcestamps=[{}], reason=u'x', properties={},
+            sourcestamps=[{}], reason='x', properties={},
             builderids=[80], waited_for=False)
 
         self.brdict = \
@@ -227,11 +222,11 @@ class RunSteps(unittest.TestCase):
         yield bfd
 
         # then get the BuildStatus and return it
-        defer.returnValue(self.master.status.lastBuilderStatus.lastBuildStatus)
+        return self.master.status.lastBuilderStatus.lastBuildStatus
 
     def assertLogs(self, exp_logs):
         got_logs = {}
-        for id, l in iteritems(self.master.data.updates.logs):
+        for id, l in self.master.data.updates.logs.items():
             self.assertTrue(l['finished'])
             got_logs[l['name']] = ''.join(l['content'])
         self.assertEqual(got_logs, exp_logs)
@@ -261,18 +256,18 @@ class RunSteps(unittest.TestCase):
         yield self.do_test_step()
 
         self.assertLogs({
-            u'compl.html': u'<blink>A very short logfile</blink>\n',
+            'compl.html': '<blink>A very short logfile</blink>\n',
             # this is one of the things that differs independently of
             # new/old style: encoding of logs and newlines
-            u'foo':
+            'foo':
             # 'stdout\n\xe2\x98\x83\nstderr\n',
-            u'ostdout\no\N{SNOWMAN}\nestderr\n',
-            u'obs':
+            'ostdout\no\N{SNOWMAN}\nestderr\n',
+            'obs':
             # if slowDB, the observer won't see anything before the end of this
             # instant step
-            u'Observer saw []\n' if slowDB else
+            'Observer saw []\n' if slowDB else
             # 'Observer saw [\'stdout\\n\', \'\\xe2\\x98\\x83\\n\']',
-            u'Observer saw [' + repr(u'stdout\n') + u", " + repr(u"\u2603\n") + u"]\n"
+            'Observer saw [' + repr('stdout\n') + ", " + repr("\u2603\n") + "]\n"
         })
 
     def test_OldStyleCustomBuildStep(self):
@@ -313,7 +308,7 @@ class RunSteps(unittest.TestCase):
             Latin1ProducingCustomBuildStep(logEncoding='latin-1'))
         yield self.do_test_step()
         self.assertLogs({
-            u'xx': u'o\N{CENT SIGN}\n',
+            'xx': 'o\N{CENT SIGN}\n',
         })
 
     @defer.inlineCallbacks
