@@ -13,12 +13,9 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
 
-from twisted.internet.defer import Deferred
-from twisted.python import threadpool
-from twisted.trial.unittest import SynchronousTestCase
+from twisted.internet import defer
+from twisted.trial.unittest import TestCase
 from zope.interface import implementer
 
 from buildbot.config import BuilderConfig
@@ -27,9 +24,8 @@ from buildbot.process.buildstep import BuildStep
 from buildbot.process.factory import BuildFactory
 from buildbot.process.results import CANCELLED
 from buildbot.test.fake.latent import LatentController
-from buildbot.test.fake.reactor import NonThreadPool
-from buildbot.test.fake.reactor import TestReactor
 from buildbot.test.util.integration import getMaster
+from buildbot.test.util.misc import TestReactorMixin
 from buildbot.worker.local import LocalWorker
 
 try:
@@ -46,7 +42,7 @@ class StepController(object):
         self.steps = []
 
     def buildStep(self):
-        step_deferred = Deferred()
+        step_deferred = defer.Deferred()
         step = ControllableStep(step_deferred, **self.kwargs)
         self.steps.append((step, step_deferred))
         return step
@@ -65,24 +61,21 @@ class ControllableStep(BuildStep):
         self._step_deferred.callback(CANCELLED)
 
 
-class Tests(SynchronousTestCase):
+class Tests(TestCase, TestReactorMixin):
 
     def setUp(self):
-        self.patch(threadpool, 'ThreadPool', NonThreadPool)
-        self.reactor = TestReactor()
+        self.setUpTestReactor()
 
     def tearDown(self):
         self.assertFalse(self.master.running, "master is still running!")
 
+    @defer.inlineCallbacks
     def test_latent_max_builds(self):
         """
         If max_builds is set, only one build is started on a latent
         worker at a time.
         """
-        controller = LatentController(
-            'local',
-            max_builds=1,
-        )
+        controller = LatentController(self, 'local', max_builds=1)
         step_controller = StepController()
         config_dict = {
             'builders': [
@@ -99,41 +92,39 @@ class Tests(SynchronousTestCase):
             'protocols': {'null': {}},
             'multiMaster': True,
         }
-        self.master = master = self.successResultOf(
-            getMaster(self, self.reactor, config_dict))
+        self.master = master = yield getMaster(self, self.reactor, config_dict)
         builder_ids = [
-            self.successResultOf(master.data.updates.findBuilderId('testy-1')),
-            self.successResultOf(master.data.updates.findBuilderId('testy-2')),
+            (yield master.data.updates.findBuilderId('testy-1')),
+            (yield master.data.updates.findBuilderId('testy-2')),
         ]
 
         started_builds = []
-        self.successResultOf(master.mq.startConsuming(
+        yield master.mq.startConsuming(
             lambda key, build: started_builds.append(build),
-            ('builds', None, 'new')))
+            ('builds', None, 'new'))
 
         # Trigger a buildrequest
-        bsid, brids = self.successResultOf(
-            master.data.updates.addBuildset(
-                waited_for=False,
-                builderids=builder_ids,
-                sourcestamps=[
-                    {'codebase': '',
-                     'repository': '',
-                     'branch': None,
-                     'revision': None,
-                     'project': ''},
-                ],
-            )
+        bsid, brids = yield master.data.updates.addBuildset(
+            waited_for=False,
+            builderids=builder_ids,
+            sourcestamps=[
+                {'codebase': '',
+                 'repository': '',
+                 'branch': None,
+                 'revision': None,
+                 'project': ''},
+            ],
         )
 
         # The worker fails to substantiate.
         controller.start_instance(True)
 
-        controller.connect_worker(self)
+        controller.connect_worker()
 
         self.assertEqual(len(started_builds), 1)
-        controller.auto_stop(True)
+        yield controller.auto_stop(True)
 
+    @defer.inlineCallbacks
     def test_local_worker_max_builds(self):
         """
         If max_builds is set, only one build is started on a worker
@@ -155,31 +146,28 @@ class Tests(SynchronousTestCase):
             'protocols': {'null': {}},
             'multiMaster': True,
         }
-        self.master = master = self.successResultOf(
-            getMaster(self, self.reactor, config_dict))
+        self.master = master = yield getMaster(self, self.reactor, config_dict)
         builder_ids = [
-            self.successResultOf(master.data.updates.findBuilderId('testy-1')),
-            self.successResultOf(master.data.updates.findBuilderId('testy-2')),
+            (yield master.data.updates.findBuilderId('testy-1')),
+            (yield master.data.updates.findBuilderId('testy-2')),
         ]
 
         started_builds = []
-        self.successResultOf(master.mq.startConsuming(
+        yield master.mq.startConsuming(
             lambda key, build: started_builds.append(build),
-            ('builds', None, 'new')))
+            ('builds', None, 'new'))
 
         # Trigger a buildrequest
-        bsid, brids = self.successResultOf(
-            master.data.updates.addBuildset(
-                waited_for=False,
-                builderids=builder_ids,
-                sourcestamps=[
-                    {'codebase': '',
-                     'repository': '',
-                     'branch': None,
-                     'revision': None,
-                     'project': ''},
-                ],
-            )
+        bsid, brids = yield master.data.updates.addBuildset(
+            waited_for=False,
+            builderids=builder_ids,
+            sourcestamps=[
+                {'codebase': '',
+                 'repository': '',
+                 'branch': None,
+                 'revision': None,
+                 'project': ''},
+            ],
         )
 
         self.assertEqual(len(started_builds), 1)
