@@ -13,11 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-from future.builtins import range
-from future.utils import iteritems
-
 import sqlalchemy as sa
 
 from twisted.internet import defer
@@ -70,17 +65,17 @@ class Tests(interfaces.InterfaceTests):
     change14_dict = {
         'changeid': 14,
         'parent_changeids': [],
-        'author': u'warner',
-        'branch': u'warnerdb',
-        'category': u'devel',
-        'comments': u'fix whitespace',
-        'files': [u'master/buildbot/__init__.py'],
-        'project': u'Buildbot',
+        'author': 'warner',
+        'branch': 'warnerdb',
+        'category': 'devel',
+        'comments': 'fix whitespace',
+        'files': ['master/buildbot/__init__.py'],
+        'project': 'Buildbot',
         'properties': {},
-        'repository': u'git://warner',
-        'codebase': u'mainapp',
-        'revision': u'0e92a098b',
-        'revlink': u'http://warner/0e92a098b',
+        'repository': 'git://warner',
+        'codebase': 'mainapp',
+        'revision': '0e92a098b',
+        'revlink': 'http://warner/0e92a098b',
         'when_timestamp': epoch2datetime(266738404),
         'sourcestampid': 233,
     }
@@ -105,18 +100,18 @@ class Tests(interfaces.InterfaceTests):
         clock = task.Clock()
         clock.advance(SOMETIME)
         changeid = yield self.db.changes.addChange(
-            author=u'dustin',
+            author='dustin',
             files=[],
-            comments=u'fix spelling',
-            revision=u'2d6caa52',
+            comments='fix spelling',
+            revision='2d6caa52',
             when_timestamp=epoch2datetime(OTHERTIME),
-            branch=u'master',
+            branch='master',
             category=None,
             revlink=None,
             properties={},
-            repository=u'repo://',
-            codebase=u'cb',
-            project=u'proj',
+            repository='repo://',
+            codebase='cb',
+            project='proj',
             _reactor=clock)
         chdict = yield self.db.changes.getChange(changeid)
         validation.verifyDbDict(self, 'chdict', chdict)
@@ -124,31 +119,31 @@ class Tests(interfaces.InterfaceTests):
         ss = yield self.db.sourcestamps.getSourceStamp(chdict['sourcestampid'])
         chdict['sourcestampid'] = ss
         self.assertEqual(chdict, {
-            'author': u'dustin',
-            'branch': u'master',
+            'author': 'dustin',
+            'branch': 'master',
             'category': None,
             'changeid': changeid,
             'parent_changeids': [],
-            'codebase': u'cb',
-            'comments': u'fix spelling',
+            'codebase': 'cb',
+            'comments': 'fix spelling',
             'files': [],
-            'project': u'proj',
+            'project': 'proj',
             'properties': {},
-            'repository': u'repo://',
-            'revision': u'2d6caa52',
+            'repository': 'repo://',
+            'revision': '2d6caa52',
             'revlink': None,
             'sourcestampid': {
-                'branch': u'master',
-                'codebase': u'cb',
+                'branch': 'master',
+                'codebase': 'cb',
                 'patch_author': None,
                 'patch_body': None,
                 'patch_comment': None,
                 'patch_level': None,
                 'patch_subdir': None,
                 'patchid': None,
-                'project': u'proj',
-                'repository': u'repo://',
-                'revision': u'2d6caa52',
+                'project': 'proj',
+                'repository': 'repo://',
+                'revision': '2d6caa52',
                 'created_at': epoch2datetime(SOMETIME),
                 'ssid': ss['ssid'],
             },
@@ -162,18 +157,18 @@ class Tests(interfaces.InterfaceTests):
         clock = task.Clock()
         clock.advance(SOMETIME)
         changeid = yield self.db.changes.addChange(
-            author=u'delanne',
+            author='delanne',
             files=[],
-            comments=u'child of changeid14',
-            revision=u'50adad56',
+            comments='child of changeid14',
+            revision='50adad56',
             when_timestamp=epoch2datetime(OTHERTIME),
-            branch=u'warnerdb',
-            category=u'devel',
+            branch='warnerdb',
+            category='devel',
             revlink=None,
             properties={},
-            repository=u'git://warner',
-            codebase=u'mainapp',
-            project=u'Buildbot',
+            repository='git://warner',
+            codebase='mainapp',
+            project='Buildbot',
             _reactor=clock)
         chdict = yield self.db.changes.getChange(changeid)
         validation.verifyDbDict(self, 'chdict', chdict)
@@ -181,22 +176,22 @@ class Tests(interfaces.InterfaceTests):
         ss = yield self.db.sourcestamps.getSourceStamp(chdict['sourcestampid'])
         chdict['sourcestampid'] = ss
         self.assertEqual(chdict, {
-            'author': u'delanne',
-            'branch': u'warnerdb',
-            'category': u'devel',
+            'author': 'delanne',
+            'branch': 'warnerdb',
+            'category': 'devel',
             'changeid': changeid,
             'parent_changeids': [14],
-            'codebase': u'mainapp',
-            'comments': u'child of changeid14',
+            'codebase': 'mainapp',
+            'comments': 'child of changeid14',
             'files': [],
-            'project': u'Buildbot',
+            'project': 'Buildbot',
             'properties': {},
-            'repository': u'git://warner',
-            'revision': u'50adad56',
+            'repository': 'git://warner',
+            'revision': '50adad56',
             'revlink': None,
             'sourcestampid': {
-                'branch': u'warnerdb',
-                'codebase': u'mainapp',
+                'branch': 'warnerdb',
+                'codebase': 'mainapp',
                 'created_at': epoch2datetime(SOMETIME),
                 'patch_author': None,
                 'patch_body': None,
@@ -204,67 +199,54 @@ class Tests(interfaces.InterfaceTests):
                 'patch_level': None,
                 'patch_subdir': None,
                 'patchid': None,
-                'project': u'Buildbot',
-                'repository': u'git://warner',
-                'revision': u'50adad56',
+                'project': 'Buildbot',
+                'repository': 'git://warner',
+                'revision': '50adad56',
                 'ssid': ss['ssid']
             },
             'when_timestamp': epoch2datetime(OTHERTIME),
         })
 
+    @defer.inlineCallbacks
     def test_getChange_chdict(self):
-        d = self.insertTestData(self.change14_rows)
+        yield self.insertTestData(self.change14_rows)
 
-        def get14(_):
-            return self.db.changes.getChange(14)
-        d.addCallback(get14)
+        chdict = yield self.db.changes.getChange(14)
 
-        def check14(chdict):
-            validation.verifyDbDict(self, 'chdict', chdict)
-            self.assertEqual(chdict, self.change14_dict)
-        d.addCallback(check14)
-        return d
+        validation.verifyDbDict(self, 'chdict', chdict)
+        self.assertEqual(chdict, self.change14_dict)
 
+    @defer.inlineCallbacks
     def test_getChange_missing(self):
-        d = defer.succeed(None)
+        chdict = yield self.db.changes.getChange(14)
 
-        def get14(_):
-            return self.db.changes.getChange(14)
-        d.addCallback(get14)
-
-        def check14(chdict):
-            self.assertTrue(chdict is None)
-        d.addCallback(check14)
-        return d
+        self.assertTrue(chdict is None)
 
     def test_signature_getChangeUids(self):
         @self.assertArgSpecMatches(self.db.changes.getChangeUids)
         def getChangeUids(self, changeid):
             pass
 
+    @defer.inlineCallbacks
     def test_getChangeUids_missing(self):
-        d = self.db.changes.getChangeUids(1)
+        res = yield self.db.changes.getChangeUids(1)
 
-        def check(res):
-            self.assertEqual(res, [])
-        d.addCallback(check)
-        return d
+        self.assertEqual(res, [])
 
+    @defer.inlineCallbacks
     def test_getChangeUids_found(self):
-        d = self.insertTestData(self.change14_rows + [
+        yield self.insertTestData(self.change14_rows + [
             fakedb.SourceStamp(id=92),
             fakedb.User(uid=1),
             fakedb.ChangeUser(changeid=14, uid=1),
         ])
-        d.addCallback(lambda _: self.db.changes.getChangeUids(14))
+        res = yield self.db.changes.getChangeUids(14)
 
-        def check(res):
-            self.assertEqual(res, [1])
-        d.addCallback(check)
-        return d
+        self.assertEqual(res, [1])
 
+    @defer.inlineCallbacks
     def test_getChangeUids_multi(self):
-        d = self.insertTestData(self.change14_rows + self.change13_rows + [
+        yield self.insertTestData(self.change14_rows + self.change13_rows + [
             fakedb.User(uid=1, identifier="one"),
             fakedb.User(uid=2, identifier="two"),
             fakedb.User(uid=99, identifier="nooo"),
@@ -272,12 +254,9 @@ class Tests(interfaces.InterfaceTests):
             fakedb.ChangeUser(changeid=14, uid=2),
             fakedb.ChangeUser(changeid=13, uid=99),  # not selected
         ])
-        d.addCallback(lambda _: self.db.changes.getChangeUids(14))
+        res = yield self.db.changes.getChangeUids(14)
 
-        def check(res):
-            self.assertEqual(sorted(res), [1, 2])
-        d.addCallback(check)
-        return d
+        self.assertEqual(sorted(res), [1, 2])
 
     def test_signature_getRecentChanges(self):
         @self.assertArgSpecMatches(self.db.changes.getRecentChanges)
@@ -299,58 +278,45 @@ class Tests(interfaces.InterfaceTests):
             fakedb.Change(changeid=12, sourcestampid=922),
         ] + self.change13_rows + self.change14_rows)
 
+    @defer.inlineCallbacks
     def test_getRecentChanges_subset(self):
-        d = self.insert7Changes()
-        d.addCallback(lambda _:
-                      self.db.changes.getRecentChanges(5))
+        yield self.insert7Changes()
+        changes = yield self.db.changes.getRecentChanges(5)
 
-        def check(changes):
-            changeids = [c['changeid'] for c in changes]
-            self.assertEqual(changeids, [10, 11, 12, 13, 14])
-        d.addCallback(check)
-        return d
+        changeids = [c['changeid'] for c in changes]
+        self.assertEqual(changeids, [10, 11, 12, 13, 14])
 
+    @defer.inlineCallbacks
     def test_getChangesCount(self):
-        d = self.insert7Changes()
-        d.addCallback(lambda _:
-                      self.db.changes.getChangesCount())
+        yield self.insert7Changes()
+        n = yield self.db.changes.getChangesCount()
 
-        def check(n):
-            self.assertEqual(n, 7)
-        d.addCallback(check)
-        return d
+        self.assertEqual(n, 7)
 
+    @defer.inlineCallbacks
     def test_getChangesHugeCount(self):
-        d = self.insertTestData([
+        yield self.insertTestData([
             fakedb.SourceStamp(id=92),
         ] + [
             fakedb.Change(changeid=i) for i in range(2, 102)])
-        d.addCallback(lambda _:
-                      self.db.changes.getChangesCount())
+        n = yield self.db.changes.getChangesCount()
 
-        def check(n):
-            self.assertEqual(n, 100)
-        d.addCallback(check)
-        return d
+        self.assertEqual(n, 100)
 
+    @defer.inlineCallbacks
     def test_getRecentChanges_empty(self):
-        d = defer.succeed(None)
-        d.addCallback(lambda _:
-                      self.db.changes.getRecentChanges(5))
+        changes = yield self.db.changes.getRecentChanges(5)
 
-        def check(changes):
-            changeids = [c['changeid'] for c in changes]
-            self.assertEqual(changeids, [])
-        d.addCallback(check)
-        d.addCallback(lambda _:
-                      self.db.changes.getChanges())
-        d.addCallback(check)
-        return d
+        changeids = [c['changeid'] for c in changes]
+        self.assertEqual(changeids, [])
+        yield self.db.changes.getChanges()
 
+        changeids = [c['changeid'] for c in changes]
+        self.assertEqual(changeids, [])
+
+    @defer.inlineCallbacks
     def test_getRecentChanges_missing(self):
-        d = self.insertTestData(self.change13_rows + self.change14_rows)
-        d.addCallback(lambda _:
-                      self.db.changes.getRecentChanges(5))
+        yield self.insertTestData(self.change13_rows + self.change14_rows)
 
         def check(changes):
             # requested all, but only got 2
@@ -363,279 +329,239 @@ class Tests(interfaces.InterfaceTests):
                              sorted(['master/README.txt', 'worker/README.txt']))
             self.assertEqual(changes[0]['properties'],
                              {'notest': ('no', 'Change')})
-        d.addCallback(check)
-        d.addCallback(lambda _:
-                      self.db.changes.getChanges())
-        d.addCallback(check)
-        return d
+
+        changes = yield self.db.changes.getRecentChanges(5)
+        check(changes)
+
+        changes = yield self.db.changes.getChanges()
+        check(changes)
 
     def test_signature_getLatestChangeid(self):
         @self.assertArgSpecMatches(self.db.changes.getLatestChangeid)
         def getLatestChangeid(self):
             pass
 
+    @defer.inlineCallbacks
     def test_getLatestChangeid(self):
-        d = self.insertTestData(self.change13_rows)
+        yield self.insertTestData(self.change13_rows)
 
-        def get(_):
-            return self.db.changes.getLatestChangeid()
-        d.addCallback(get)
+        changeid = yield self.db.changes.getLatestChangeid()
 
-        def check(changeid):
-            self.assertEqual(changeid, 13)
-        d.addCallback(check)
-        return d
+        self.assertEqual(changeid, 13)
 
+    @defer.inlineCallbacks
     def test_getLatestChangeid_empty(self):
-        d = defer.succeed(None)
+        changeid = yield self.db.changes.getLatestChangeid()
 
-        def get(_):
-            return self.db.changes.getLatestChangeid()
-        d.addCallback(get)
-
-        def check(changeid):
-            self.assertEqual(changeid, None)
-        d.addCallback(check)
-        return d
+        self.assertEqual(changeid, None)
 
     def test_signature_getParentChangeIds(self):
         @self.assertArgSpecMatches(self.db.changes.getParentChangeIds)
         def getParentChangeIds(self, branch, repository, project, codebase):
             pass
 
+    @defer.inlineCallbacks
     def test_getParentChangeIds(self):
-        d = self.insertTestData(self.change14_rows + self.change13_rows)
+        yield self.insertTestData(self.change14_rows + self.change13_rows)
 
-        def getParent(_):
-            return self.db.changes.getParentChangeIds(branch='warnerdb',
+        changeid = yield self.db.changes.getParentChangeIds(branch='warnerdb',
                                                       repository='git://warner',
                                                       project='Buildbot',
                                                       codebase='mainapp')
-        d.addCallback(getParent)
-
-        def check(changeid):
-            self.assertEqual(changeid, [14])
-        d.addCallback(check)
-        return d
+        self.assertEqual(changeid, [14])
 
 
 class RealTests(Tests):
 
     # tests that only "real" implementations will pass
 
+    @defer.inlineCallbacks
     def test_addChange(self):
         clock = task.Clock()
         clock.advance(SOMETIME)
-        d = self.db.changes.addChange(
-            author=u'dustin',
-            files=[u'master/LICENSING.txt', u'worker/LICENSING.txt'],
-            comments=u'fix spelling',
-            revision=u'2d6caa52',
+        changeid = yield self.db.changes.addChange(
+            author='dustin',
+            files=['master/LICENSING.txt', 'worker/LICENSING.txt'],
+            comments='fix spelling',
+            revision='2d6caa52',
             when_timestamp=epoch2datetime(266738400),
-            branch=u'master',
+            branch='master',
             category=None,
             revlink=None,
-            properties={u'platform': (u'linux', 'Change')},
-            repository=u'',
-            codebase=u'cb',
-            project=u'',
+            properties={'platform': ('linux', 'Change')},
+            repository='',
+            codebase='cb',
+            project='',
             _reactor=clock)
         # check all of the columns of the four relevant tables
 
-        def check_change(changeid):
-            def thd(conn):
-                self.assertEqual(changeid, 1)
-                r = conn.execute(self.db.model.changes.select())
-                r = r.fetchall()
-                self.assertEqual(len(r), 1)
-                self.assertEqual(r[0].changeid, changeid)
-                self.assertEqual(r[0].author, 'dustin')
-                self.assertEqual(r[0].comments, 'fix spelling')
-                self.assertEqual(r[0].branch, 'master')
-                self.assertEqual(r[0].revision, '2d6caa52')
-                self.assertEqual(r[0].when_timestamp, 266738400)
-                self.assertEqual(r[0].category, None)
-                self.assertEqual(r[0].repository, '')
-                self.assertEqual(r[0].codebase, u'cb')
-                self.assertEqual(r[0].project, '')
-                self.assertEqual(r[0].sourcestampid, 1)
-            return self.db.pool.do(thd)
-        d.addCallback(check_change)
+        def thd_change(conn):
+            self.assertEqual(changeid, 1)
+            r = conn.execute(self.db.model.changes.select())
+            r = r.fetchall()
+            self.assertEqual(len(r), 1)
+            self.assertEqual(r[0].changeid, changeid)
+            self.assertEqual(r[0].author, 'dustin')
+            self.assertEqual(r[0].comments, 'fix spelling')
+            self.assertEqual(r[0].branch, 'master')
+            self.assertEqual(r[0].revision, '2d6caa52')
+            self.assertEqual(r[0].when_timestamp, 266738400)
+            self.assertEqual(r[0].category, None)
+            self.assertEqual(r[0].repository, '')
+            self.assertEqual(r[0].codebase, 'cb')
+            self.assertEqual(r[0].project, '')
+            self.assertEqual(r[0].sourcestampid, 1)
+        yield self.db.pool.do(thd_change)
 
-        def check_change_files(_):
-            def thd(conn):
-                query = self.db.model.change_files.select()
-                query.where(self.db.model.change_files.c.changeid == 1)
-                query.order_by(self.db.model.change_files.c.filename)
-                r = conn.execute(query)
-                r = r.fetchall()
-                self.assertEqual(len(r), 2)
-                self.assertEqual(r[0].filename, 'master/LICENSING.txt')
-                self.assertEqual(r[1].filename, 'worker/LICENSING.txt')
-            return self.db.pool.do(thd)
-        d.addCallback(check_change_files)
+        def thd_change_files(conn):
+            query = self.db.model.change_files.select()
+            query.where(self.db.model.change_files.c.changeid == 1)
+            query.order_by(self.db.model.change_files.c.filename)
+            r = conn.execute(query)
+            r = r.fetchall()
+            self.assertEqual(len(r), 2)
+            self.assertEqual(r[0].filename, 'master/LICENSING.txt')
+            self.assertEqual(r[1].filename, 'worker/LICENSING.txt')
+        yield self.db.pool.do(thd_change_files)
 
-        def check_change_properties(_):
-            def thd(conn):
-                query = self.db.model.change_properties.select()
-                query.where(self.db.model.change_properties.c.changeid == 1)
-                query.order_by(self.db.model.change_properties.c.property_name)
-                r = conn.execute(query)
-                r = r.fetchall()
-                self.assertEqual(len(r), 1)
-                self.assertEqual(r[0].property_name, 'platform')
-                self.assertEqual(r[0].property_value, '["linux", "Change"]')
-            return self.db.pool.do(thd)
-        d.addCallback(check_change_properties)
+        def thd_change_properties(conn):
+            query = self.db.model.change_properties.select()
+            query.where(self.db.model.change_properties.c.changeid == 1)
+            query.order_by(self.db.model.change_properties.c.property_name)
+            r = conn.execute(query)
+            r = r.fetchall()
+            self.assertEqual(len(r), 1)
+            self.assertEqual(r[0].property_name, 'platform')
+            self.assertEqual(r[0].property_value, '["linux", "Change"]')
+        yield self.db.pool.do(thd_change_properties)
 
-        def check_change_users(_):
-            def thd(conn):
-                query = self.db.model.change_users.select()
-                r = conn.execute(query)
-                r = r.fetchall()
-                self.assertEqual(len(r), 0)
-            return self.db.pool.do(thd)
-        d.addCallback(check_change_users)
+        def thd_change_users(conn):
+            query = self.db.model.change_users.select()
+            r = conn.execute(query)
+            r = r.fetchall()
+            self.assertEqual(len(r), 0)
+        yield self.db.pool.do(thd_change_users)
 
-        def check_change_sourcestamps(_):
-            def thd(conn):
-                query = self.db.model.sourcestamps.select()
-                r = conn.execute(query)
-                self.assertEqual([dict(row) for row in r.fetchall()], [{
-                    'branch': u'master',
-                    'codebase': u'cb',
-                    'id': 1,
-                    'patchid': None,
-                    'project': u'',
-                    'repository': u'',
-                    'revision': u'2d6caa52',
-                    'created_at': SOMETIME,
-                    'ss_hash': 'b777dbd10d1d4c76651335f6a78e278e88b010d6',
-                }])
-            return self.db.pool.do(thd)
-        d.addCallback(check_change_sourcestamps)
-        return d
+        def thd_change_sourcestamps(conn):
+            query = self.db.model.sourcestamps.select()
+            r = conn.execute(query)
+            self.assertEqual([dict(row) for row in r.fetchall()], [{
+                'branch': 'master',
+                'codebase': 'cb',
+                'id': 1,
+                'patchid': None,
+                'project': '',
+                'repository': '',
+                'revision': '2d6caa52',
+                'created_at': SOMETIME,
+                'ss_hash': 'b777dbd10d1d4c76651335f6a78e278e88b010d6',
+            }])
+        yield self.db.pool.do(thd_change_sourcestamps)
 
+    @defer.inlineCallbacks
     def test_addChange_when_timestamp_None(self):
         clock = task.Clock()
         clock.advance(OTHERTIME)
-        d = self.db.changes.addChange(
-            author=u'dustin',
+        changeid = yield self.db.changes.addChange(
+            author='dustin',
             files=[],
-            comments=u'fix spelling',
-            revision=u'2d6caa52',
+            comments='fix spelling',
+            revision='2d6caa52',
             when_timestamp=None,
-            branch=u'master',
+            branch='master',
             category=None,
             revlink=None,
             properties={},
-            repository=u'',
-            codebase=u'',
-            project=u'',
+            repository='',
+            codebase='',
+            project='',
             _reactor=clock)
         # check all of the columns of the four relevant tables
 
-        def check_change(changeid):
-            def thd(conn):
-                r = conn.execute(self.db.model.changes.select())
-                r = r.fetchall()
-                self.assertEqual(len(r), 1)
-                self.assertEqual(r[0].changeid, changeid)
-                self.assertEqual(r[0].when_timestamp, OTHERTIME)
-            return self.db.pool.do(thd)
-        d.addCallback(check_change)
+        def thd(conn):
+            r = conn.execute(self.db.model.changes.select())
+            r = r.fetchall()
+            self.assertEqual(len(r), 1)
+            self.assertEqual(r[0].changeid, changeid)
+            self.assertEqual(r[0].when_timestamp, OTHERTIME)
+        yield self.db.pool.do(thd)
 
-        def check_change_files(_):
-            def thd(conn):
-                query = self.db.model.change_files.select()
-                r = conn.execute(query)
-                r = r.fetchall()
-                self.assertEqual(len(r), 0)
-            return self.db.pool.do(thd)
-        d.addCallback(check_change_files)
+        def thd_change(conn):
+            query = self.db.model.change_files.select()
+            r = conn.execute(query)
+            r = r.fetchall()
+            self.assertEqual(len(r), 0)
+        yield self.db.pool.do(thd_change)
 
-        def check_change_properties(_):
-            def thd(conn):
-                query = self.db.model.change_properties.select()
-                r = conn.execute(query)
-                r = r.fetchall()
-                self.assertEqual(len(r), 0)
-            return self.db.pool.do(thd)
-        d.addCallback(check_change_properties)
+        def thd_change_file(conn):
+            query = self.db.model.change_properties.select()
+            r = conn.execute(query)
+            r = r.fetchall()
+            self.assertEqual(len(r), 0)
+        yield self.db.pool.do(thd_change_file)
 
-        def check_change_users(_):
-            def thd(conn):
-                query = self.db.model.change_users.select()
-                r = conn.execute(query)
-                r = r.fetchall()
-                self.assertEqual(len(r), 0)
-            return self.db.pool.do(thd)
-        d.addCallback(check_change_users)
-        return d
+        def thd_change_properties(conn):
+            query = self.db.model.change_users.select()
+            r = conn.execute(query)
+            r = r.fetchall()
+            self.assertEqual(len(r), 0)
+        yield self.db.pool.do(thd_change_properties)
 
+    @defer.inlineCallbacks
     def test_addChange_with_uid(self):
-        d = self.insertTestData([
+        yield self.insertTestData([
             fakedb.User(uid=1, identifier="one"),
         ])
-        d.addCallback(lambda _:
-                      self.db.changes.addChange(
-                          author=u'dustin',
+        changeid = yield self.db.changes.addChange(
+                          author='dustin',
                           files=[],
-                          comments=u'fix spelling',
-                          revision=u'2d6caa52',
+                          comments='fix spelling',
+                          revision='2d6caa52',
                           when_timestamp=epoch2datetime(OTHERTIME),
-                          branch=u'master',
+                          branch='master',
                           category=None,
                           revlink=None,
                           properties={},
-                          repository=u'',
-                          codebase=u'',
-                          project=u'',
-                          uid=1))
+                          repository='',
+                          codebase='',
+                          project='',
+                          uid=1)
         # check all of the columns of the five relevant tables
 
-        def check_change(changeid):
-            def thd(conn):
-                r = conn.execute(self.db.model.changes.select())
-                r = r.fetchall()
-                self.assertEqual(len(r), 1)
-                self.assertEqual(r[0].changeid, changeid)
-                self.assertEqual(r[0].when_timestamp, OTHERTIME)
-            return self.db.pool.do(thd)
-        d.addCallback(check_change)
+        def thd_change(conn):
+            r = conn.execute(self.db.model.changes.select())
+            r = r.fetchall()
+            self.assertEqual(len(r), 1)
+            self.assertEqual(r[0].changeid, changeid)
+            self.assertEqual(r[0].when_timestamp, OTHERTIME)
+        yield self.db.pool.do(thd_change)
 
-        def check_change_files(_):
-            def thd(conn):
-                query = self.db.model.change_files.select()
-                r = conn.execute(query)
-                r = r.fetchall()
-                self.assertEqual(len(r), 0)
-            return self.db.pool.do(thd)
-        d.addCallback(check_change_files)
+        def thd_change_files(conn):
+            query = self.db.model.change_files.select()
+            r = conn.execute(query)
+            r = r.fetchall()
+            self.assertEqual(len(r), 0)
+        yield self.db.pool.do(thd_change_files)
 
-        def check_change_properties(_):
-            def thd(conn):
-                query = self.db.model.change_properties.select()
-                r = conn.execute(query)
-                r = r.fetchall()
-                self.assertEqual(len(r), 0)
-            return self.db.pool.do(thd)
-        d.addCallback(check_change_properties)
+        def thd_change_properties(conn):
+            query = self.db.model.change_properties.select()
+            r = conn.execute(query)
+            r = r.fetchall()
+            self.assertEqual(len(r), 0)
+        yield self.db.pool.do(thd_change_properties)
 
-        def check_change_users(_):
-            def thd(conn):
-                query = self.db.model.change_users.select()
-                r = conn.execute(query)
-                r = r.fetchall()
-                self.assertEqual(len(r), 1)
-                self.assertEqual(r[0].changeid, 1)
-                self.assertEqual(r[0].uid, 1)
-            return self.db.pool.do(thd)
-        d.addCallback(check_change_users)
-        return d
+        def thd_change_users(conn):
+            query = self.db.model.change_users.select()
+            r = conn.execute(query)
+            r = r.fetchall()
+            self.assertEqual(len(r), 1)
+            self.assertEqual(r[0].changeid, 1)
+            self.assertEqual(r[0].uid, 1)
+        yield self.db.pool.do(thd_change_users)
 
+    @defer.inlineCallbacks
     def test_pruneChanges(self):
-        d = self.insertTestData([
+        yield self.insertTestData([
             fakedb.Scheduler(id=29),
             fakedb.SourceStamp(id=234, branch='aa'),
             fakedb.SourceStamp(id=235, branch='bb'),
@@ -651,69 +577,62 @@ class RealTests(Tests):
         )
 
         # pruning with a horizon of 2 should delete changes 11, 12 and 13
-        d.addCallback(lambda _: self.db.changes.pruneChanges(2))
+        yield self.db.changes.pruneChanges(2)
 
-        def check(_):
-            def thd(conn):
-                results = {}
-                for tbl_name in ('scheduler_changes', 'change_files',
-                                 'change_properties', 'changes'):
-                    tbl = self.db.model.metadata.tables[tbl_name]
-                    res = conn.execute(sa.select([tbl.c.changeid]))
-                    results[tbl_name] = sorted(
-                        [row[0] for row in res.fetchall()])
-                self.assertEqual(results, {
-                    'scheduler_changes': [14],
-                    'change_files': [14],
-                    'change_properties': [],
-                    'changes': [14, 15],
-                })
-            return self.db.pool.do(thd)
-        d.addCallback(check)
-        return d
+        def thd(conn):
+            results = {}
+            for tbl_name in ('scheduler_changes', 'change_files',
+                             'change_properties', 'changes'):
+                tbl = self.db.model.metadata.tables[tbl_name]
+                res = conn.execute(sa.select([tbl.c.changeid]))
+                results[tbl_name] = sorted(
+                    [row[0] for row in res.fetchall()])
+            self.assertEqual(results, {
+                'scheduler_changes': [14],
+                'change_files': [14],
+                'change_properties': [],
+                'changes': [14, 15],
+            })
+        yield self.db.pool.do(thd)
 
+    @defer.inlineCallbacks
     def test_pruneChanges_lots(self):
-        d = self.insertTestData([
+        yield self.insertTestData([
             fakedb.SourceStamp(id=29),
         ] + [
             fakedb.Change(changeid=n, sourcestampid=29)
             for n in range(1, 151)
         ])
 
-        d.addCallback(lambda _: self.db.changes.pruneChanges(1))
+        yield self.db.changes.pruneChanges(1)
 
-        def check(_):
-            def thd(conn):
-                results = {}
-                for tbl_name in ('scheduler_changes', 'change_files',
-                                 'change_properties', 'changes'):
-                    tbl = self.db.model.metadata.tables[tbl_name]
-                    res = conn.execute(sa.select([tbl.c.changeid]))
-                    results[tbl_name] = len([row for row in res.fetchall()])
-                self.assertEqual(results, {
-                    'scheduler_changes': 0,
-                    'change_files': 0,
-                    'change_properties': 0,
-                    'changes': 1,
-                })
-            return self.db.pool.do(thd)
-        d.addCallback(check)
-        return d
+        def thd(conn):
+            results = {}
+            for tbl_name in ('scheduler_changes', 'change_files',
+                             'change_properties', 'changes'):
+                tbl = self.db.model.metadata.tables[tbl_name]
+                res = conn.execute(sa.select([tbl.c.changeid]))
+                results[tbl_name] = len([row for row in res.fetchall()])
+            self.assertEqual(results, {
+                'scheduler_changes': 0,
+                'change_files': 0,
+                'change_properties': 0,
+                'changes': 1,
+            })
+        yield self.db.pool.do(thd)
 
+    @defer.inlineCallbacks
     def test_pruneChanges_None(self):
-        d = self.insertTestData(self.change13_rows)
+        yield self.insertTestData(self.change13_rows)
 
-        d.addCallback(lambda _: self.db.changes.pruneChanges(None))
+        yield self.db.changes.pruneChanges(None)
 
-        def check(_):
-            def thd(conn):
-                tbl = self.db.model.changes
-                res = conn.execute(tbl.select())
-                self.assertEqual([row.changeid for row in res.fetchall()],
-                                 [13])
-            return self.db.pool.do(thd)
-        d.addCallback(check)
-        return d
+        def thd(conn):
+            tbl = self.db.model.changes
+            res = conn.execute(tbl.select())
+            self.assertEqual([row.changeid for row in res.fetchall()],
+                             [13])
+        yield self.db.pool.do(thd)
 
     @defer.inlineCallbacks
     def test_getChangesForBuild(self):
@@ -762,7 +681,7 @@ class RealTests(Tests):
             buildRows = [fakedb.Buildset(id=lastID["buildsetid"],
                                          reason='foo',
                                          submitted_at=1300305012, results=-1)]
-            for cb, ss in iteritems(codebase_ss):
+            for cb, ss in codebase_ss.items():
                 lastID["buildsetSourceStampid"] += 1
                 buildRows.append(
                     fakedb.BuildsetSourceStamp(id=lastID["buildsetSourceStampid"],
@@ -818,13 +737,13 @@ class RealTests(Tests):
             got_commits = [c['comments'] for c in got]
             self.assertEqual(sorted(got_commits), sorted(commits))
 
-        yield expect(1, [u'2nd commit', u'3rd commit', u'1st commit'])
-        yield expect(2, [u'4th commit'])
-        yield expect(3, [u'6th commit'])
+        yield expect(1, ['2nd commit', '3rd commit', '1st commit'])
+        yield expect(2, ['4th commit'])
+        yield expect(3, ['6th commit'])
         yield expect(4, [])
-        yield expect(5, [u'8th commit', u'9th commit', u'7th commit'])
-        yield expect(6, [u'10th commit'])
-        yield expect(7, [u'11th commit'])
+        yield expect(5, ['8th commit', '9th commit', '7th commit'])
+        yield expect(6, ['10th commit'])
+        yield expect(7, ['11th commit'])
 
 
 class TestFakeDB(unittest.TestCase, Tests):
@@ -840,8 +759,9 @@ class TestRealDB(unittest.TestCase,
                  connector_component.ConnectorComponentMixin,
                  RealTests):
 
+    @defer.inlineCallbacks
     def setUp(self):
-        d = self.setUpConnectorComponent(
+        yield self.setUpConnectorComponent(
             table_names=['changes', 'change_files',
                          'change_properties', 'scheduler_changes', 'schedulers',
                          'sourcestampsets', 'sourcestamps', 'patches', 'change_users',
@@ -849,16 +769,12 @@ class TestRealDB(unittest.TestCase,
                          'buildrequests', 'builds', 'buildset_sourcestamps',
                          'workers'])
 
-        @d.addCallback
-        def finish_setup(_):
-            self.db.changes = changes.ChangesConnectorComponent(self.db)
-            self.db.builds = builds.BuildsConnectorComponent(self.db)
-            self.db.sourcestamps = \
-                sourcestamps.SourceStampsConnectorComponent(self.db)
-            self.master = self.db.master
-            self.master.db = self.db
-
-        return d
+        self.db.changes = changes.ChangesConnectorComponent(self.db)
+        self.db.builds = builds.BuildsConnectorComponent(self.db)
+        self.db.sourcestamps = \
+            sourcestamps.SourceStampsConnectorComponent(self.db)
+        self.master = self.db.master
+        self.master.db = self.db
 
     def tearDown(self):
         return self.tearDownConnectorComponent()
