@@ -1,5 +1,4 @@
-from __future__ import absolute_import
-from __future__ import print_function
+import gc
 
 from twisted.internet import defer
 from twisted.trial import unittest
@@ -37,9 +36,11 @@ class TestInterpolateSecrets(unittest.TestCase, ConfigErrorsMixin):
         rendered = yield self.build.render(command)
         self.assertEqual(rendered, "echo bar")
 
+    @defer.inlineCallbacks
     def test_secret_not_found(self):
         command = Interpolate("echo %(secret:fuo)s")
-        self.assertFailure(self.build.render(command), defer.FirstError)
+        yield self.assertFailure(self.build.render(command), defer.FirstError)
+        gc.collect()
         self.flushLoggedErrors(defer.FirstError)
         self.flushLoggedErrors(KeyError)
 
@@ -50,9 +51,11 @@ class TestInterpolateSecretsNoService(unittest.TestCase, ConfigErrorsMixin):
         self.master = fakemaster.make_master()
         self.build = FakeBuildWithMaster(self.master)
 
+    @defer.inlineCallbacks
     def test_secret(self):
         command = Interpolate("echo %(secret:fuo)s")
-        self.assertFailure(self.build.render(command), defer.FirstError)
+        yield self.assertFailure(self.build.render(command), defer.FirstError)
+        gc.collect()
         self.flushLoggedErrors(defer.FirstError)
         self.flushLoggedErrors(KeyError)
 
