@@ -13,9 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-
 import mock
 
 from twisted.internet import defer
@@ -58,8 +55,8 @@ class MQConnector(unittest.TestCase):
 
     def test_setup_unknown_type(self):
         self.mqconfig['type'] = 'unknown'
-        self.assertRaises(AssertionError, lambda:
-                          self.conn.setup())
+        with self.assertRaises(AssertionError):
+            self.conn.setup()
 
     def test_setup_simple_type(self):
         self.patchFakeMQ(name='simple')
