@@ -13,9 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-
 import operator
 
 from mock import Mock
@@ -42,10 +39,6 @@ from buildbot.test.fake import fakemaster
 from buildbot.test.fake import fakeprotocol
 from buildbot.test.fake import worker
 from buildbot.test.fake.fakebuild import FakeBuildStatus
-from buildbot.test.util.warnings import assertNotProducesWarnings
-from buildbot.test.util.warnings import assertProducesWarning
-from buildbot.worker_transition import DeprecatedWorkerAPIWarning
-from buildbot.worker_transition import DeprecatedWorkerNameWarning
 
 
 class FakeChange:
@@ -94,7 +87,7 @@ class FakeBuildStep(BuildStep):
         BuildStep.__init__(
             self, haltOnFailure=False, flunkOnWarnings=False, flunkOnFailure=True,
             warnOnWarnings=True, warnOnFailure=False, alwaysRun=False, name='fake')
-        self._summary = {u'step': u'result', u'build': u'build result'}
+        self._summary = {'step': 'result', 'build': 'build result'}
         self._expected_results = SUCCESS
 
     def run(self):
@@ -116,9 +109,11 @@ class FakeBuilder:
         self.name = 'fred'
         self.master = master
         self.botmaster = master.botmaster
+        self.builderid = 83
+        self._builders = {}
 
     def getBuilderId(self):
-        return defer.succeed(83)
+        return defer.succeed(self.builderid)
 
     def setupProperties(self, props):
         pass
@@ -127,7 +122,7 @@ class FakeBuilder:
         pass
 
     def getBuilderIdForName(self, name):
-        return defer.succeed(83)
+        return defer.succeed(self._builders.get(name, None) or self.builderid)
 
 
 @implementer(interfaces.IBuildStepFactory)
@@ -270,6 +265,7 @@ class TestBuild(unittest.TestCase):
         d.callback(False)
         self.assertEqual(b.results, RETRY)
 
+    @defer.inlineCallbacks
     def testAlwaysRunStepStopBuild(self):
         """Test that steps marked with alwaysRun=True still get run even if
         the build is stopped."""
@@ -304,16 +300,13 @@ class TestBuild(unittest.TestCase):
         step2.startStep = startStep2
         step1.stepDone = lambda: False
 
-        d = b.startBuild(FakeBuildStatus(), self.workerforbuilder)
+        yield b.startBuild(FakeBuildStatus(), self.workerforbuilder)
 
-        def check(ign):
-            self.assertEqual(b.results, CANCELLED)
-            self.assertIn('stop it', step1.interrupted)
-            self.assertTrue(step2Started[0])
-        d.addCallback(check)
-        return d
+        self.assertEqual(b.results, CANCELLED)
+        self.assertIn('stop it', step1.interrupted)
+        self.assertTrue(step2Started[0])
 
-    def testBuildcanStartWithWorkerForBuilder(self):
+    def testBuild_canAcquireLocks(self):
         b = self.build
 
         workerforbuilder1 = Mock()
@@ -327,13 +320,13 @@ class TestBuild(unittest.TestCase):
         # state/memory)
         lock_list = [(real_lock, counting_access)]
         self.assertTrue(
-            Build.canStartWithWorkerForBuilder(lock_list, workerforbuilder1))
+            Build._canAcquireLocks(lock_list, workerforbuilder1))
         self.assertTrue(
-            Build.canStartWithWorkerForBuilder(lock_list, workerforbuilder1))
+            Build._canAcquireLocks(lock_list, workerforbuilder1))
         self.assertTrue(
-            Build.canStartWithWorkerForBuilder(lock_list, workerforbuilder2))
+            Build._canAcquireLocks(lock_list, workerforbuilder2))
         self.assertTrue(
-            Build.canStartWithWorkerForBuilder(lock_list, workerforbuilder2))
+            Build._canAcquireLocks(lock_list, workerforbuilder2))
 
         worker_lock_1 = real_lock.getLock(workerforbuilder1.worker)
         worker_lock_2 = real_lock.getLock(workerforbuilder2.worker)
@@ -341,25 +334,25 @@ class TestBuild(unittest.TestCase):
         # then have workerforbuilder2 claim its lock:
         worker_lock_2.claim(workerforbuilder2, counting_access)
         self.assertTrue(
-            Build.canStartWithWorkerForBuilder(lock_list, workerforbuilder1))
+            Build._canAcquireLocks(lock_list, workerforbuilder1))
         self.assertTrue(
-            Build.canStartWithWorkerForBuilder(lock_list, workerforbuilder1))
+            Build._canAcquireLocks(lock_list, workerforbuilder1))
         self.assertFalse(
-            Build.canStartWithWorkerForBuilder(lock_list, workerforbuilder2))
+            Build._canAcquireLocks(lock_list, workerforbuilder2))
         self.assertFalse(
-            Build.canStartWithWorkerForBuilder(lock_list, workerforbuilder2))
+            Build._canAcquireLocks(lock_list, workerforbuilder2))
         worker_lock_2.release(workerforbuilder2, counting_access)
 
         # then have workerforbuilder1 claim its lock:
         worker_lock_1.claim(workerforbuilder1, counting_access)
         self.assertFalse(
-            Build.canStartWithWorkerForBuilder(lock_list, workerforbuilder1))
+            Build._canAcquireLocks(lock_list, workerforbuilder1))
         self.assertFalse(
-            Build.canStartWithWorkerForBuilder(lock_list, workerforbuilder1))
+            Build._canAcquireLocks(lock_list, workerforbuilder1))
         self.assertTrue(
-            Build.canStartWithWorkerForBuilder(lock_list, workerforbuilder2))
+            Build._canAcquireLocks(lock_list, workerforbuilder2))
         self.assertTrue(
-            Build.canStartWithWorkerForBuilder(lock_list, workerforbuilder2))
+            Build._canAcquireLocks(lock_list, workerforbuilder2))
         worker_lock_1.release(workerforbuilder1, counting_access)
 
     def testBuilddirPropType(self):
@@ -719,7 +712,7 @@ class TestBuild(unittest.TestCase):
         res = yield b._flushProperties(result)
         self.assertEqual(res, result)
         self.assertEqual(self.master.data.updates.properties,
-                         [(43, u'foo', 'bar', u'test')])
+                         [(43, 'foo', 'bar', 'test')])
 
     def create_fake_steps(self, names):
         steps = []
@@ -822,6 +815,15 @@ class TestBuild(unittest.TestCase):
         url = yield self.build.getUrl()
         self.assertEqual(url, 'http://localhost:8080/#builders/83/builds/3')
 
+    @defer.inlineCallbacks
+    def testGetUrlForVirtualBuilder(self):
+        # Let's fake a virtual builder
+        self.builder._builders['wilma'] = 108
+        self.build.setProperty('virtual_builder_name', 'wilma', 'Build')
+        self.build.number = 33
+        url = yield self.build.getUrl()
+        self.assertEqual(url, 'http://localhost:8080/#builders/108/builds/33')
+
     def test_active_builds_metric(self):
         """
         The number of active builds is increased when a build starts
@@ -1127,72 +1129,3 @@ class TestBuildProperties(unittest.TestCase):
     def test_render(self):
         self.build.render("xyz")
         self.properties.render.assert_called_with("xyz")
-
-    def test_getWorkerName_old_api(self):
-        @implementer(interfaces.IProperties)
-        class FakeProperties(Mock):
-            pass
-        import posixpath
-
-        r = FakeRequest()
-        build = Build([r])
-        build.properties = FakeProperties()
-        build.builder = FakeBuilder(self.master)
-        build.build_status = FakeBuildStatus()
-
-        w = worker.FakeWorker(self.master)
-        w.path_module = posixpath
-        w.properties = FakeProperties()
-        w.workername = 'worker name'
-        w.worker_basedir = None
-
-        workerforbuilder = Mock(name='workerforbuilder')
-        workerforbuilder.worker = w
-
-        build.workerforbuilder = workerforbuilder
-
-        with assertNotProducesWarnings(DeprecatedWorkerAPIWarning):
-            new = build.getWorkerName()
-
-        with assertProducesWarning(
-                DeprecatedWorkerNameWarning,
-                message_pattern="'getSlaveName' method is deprecated"):
-            old = build.getSlaveName()
-
-        self.assertEqual(old, 'worker name')
-        self.assertIdentical(new, old)
-
-    def test_workername_old_api(self):
-        @implementer(interfaces.IProperties)
-        class FakeProperties(Mock):
-            pass
-
-        import posixpath
-
-        r = FakeRequest()
-        build = Build([r])
-        build.properties = FakeProperties()
-        build.builder = FakeBuilder(self.master)
-        build.build_status = FakeBuildStatus()
-
-        w = worker.FakeWorker(self.master)
-        w.path_module = posixpath
-        w.properties = FakeProperties()
-        w.workername = 'worker name'
-        w.worker_basedir = None
-
-        workerforbuilder = Mock(name='workerforbuilder')
-        workerforbuilder.worker = w
-
-        build.setupWorkerForBuilder(workerforbuilder)
-
-        with assertNotProducesWarnings(DeprecatedWorkerAPIWarning):
-            new = build.workername
-
-        with assertProducesWarning(
-                DeprecatedWorkerNameWarning,
-                message_pattern="'slavename' attribute is deprecated"):
-            old = build.slavename
-
-        self.assertEqual(old, 'worker name')
-        self.assertIdentical(new, old)
