@@ -13,10 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-from future.utils import iteritems
-
 import re
 
 import mock
@@ -35,7 +31,7 @@ from buildbot.util import datetime2epoch
 
 class TestContactChannel(unittest.TestCase):
 
-    BUILDER_NAMES = [u'builder1', u'builder2']
+    BUILDER_NAMES = ['builder1', 'builder2']
     BUILDER_IDS = [23, 45]
 
     def setUp(self):
@@ -132,7 +128,7 @@ class TestContactChannel(unittest.TestCase):
         clock = task.Clock()
         self.patch(reactor, 'callLater', clock.callLater)
         self.patch_send()
-        silly_prompt, silly_response = list(iteritems(self.contact.silly))[0]
+        silly_prompt, silly_response = list(self.contact.silly.items())[0]
 
         self.contact.doSilly(silly_prompt)
         clock.pump([0.5] * 20)
@@ -376,8 +372,8 @@ class TestContactChannel(unittest.TestCase):
         # Make first builder configured, but not connected
         # Make second builder configured and connected
         self.master.db.insertTestData([
-            fakedb.Worker(id=1, name=u'linux', info={}),  # connected one
-            fakedb.Worker(id=2, name=u'linux', info={}),  # disconnected one
+            fakedb.Worker(id=1, name='linux', info={}),  # connected one
+            fakedb.Worker(id=2, name='linux', info={}),  # disconnected one
             fakedb.BuilderMaster(
                 id=4012, masterid=13, builderid=self.BUILDER_IDS[0]),
             fakedb.BuilderMaster(
@@ -551,7 +547,7 @@ class TestContactChannel(unittest.TestCase):
                                         complete=True,
                                         complete_at=datetime2epoch(
                                             build['complete_at']),
-                                        state_string=u'',
+                                        state_string='',
                                         results=results,
         ))
 
@@ -608,13 +604,13 @@ class TestContactChannel(unittest.TestCase):
         self.contact.bot.groupChat = groupChat
 
         self.contact.send("unmuted")
-        self.contact.send(u"unmuted, unicode \N{SNOWMAN}")
+        self.contact.send("unmuted, unicode \N{SNOWMAN}")
         self.contact.muted = True
         self.contact.send("muted")
 
         self.assertEqual(events, [
             ('#buildbot', 'unmuted'),
-            ('#buildbot', u'unmuted, unicode \u2603'),
+            ('#buildbot', 'unmuted, unicode \u2603'),
         ])
 
     def test_act(self):
@@ -625,79 +621,67 @@ class TestContactChannel(unittest.TestCase):
         self.contact.bot.groupDescribe = groupDescribe
 
         self.contact.act("unmuted")
-        self.contact.act(u"unmuted, unicode \N{SNOWMAN}")
+        self.contact.act("unmuted, unicode \N{SNOWMAN}")
         self.contact.muted = True
         self.contact.act("muted")
 
         self.assertEqual(events, [
             ('#buildbot', 'unmuted'),
-            ('#buildbot', u'unmuted, unicode \u2603'),
+            ('#buildbot', 'unmuted, unicode \u2603'),
         ])
 
+    @defer.inlineCallbacks
     def test_handleMessage_silly(self):
         silly_prompt = list(self.contact.silly)[0]
         self.contact.doSilly = mock.Mock()
-        d = self.contact.handleMessage(silly_prompt)
+        yield self.contact.handleMessage(silly_prompt)
 
-        @d.addCallback
-        def cb(_):
-            self.contact.doSilly.assert_called_with(silly_prompt)
-        return d
+        self.contact.doSilly.assert_called_with(silly_prompt)
 
+    @defer.inlineCallbacks
     def test_handleMessage_short_command(self):
         self.contact.command_TESTY = mock.Mock()
-        d = self.contact.handleMessage('testy')
+        yield self.contact.handleMessage('testy')
 
-        @d.addCallback
-        def cb(_):
-            self.contact.command_TESTY.assert_called_with('')
-        return d
+        self.contact.command_TESTY.assert_called_with('')
 
+    @defer.inlineCallbacks
     def test_handleMessage_long_command(self):
         self.contact.command_TESTY = mock.Mock()
-        d = self.contact.handleMessage('testy   westy boo')
+        yield self.contact.handleMessage('testy   westy boo')
 
-        @d.addCallback
-        def cb(_):
-            self.contact.command_TESTY.assert_called_with('westy boo')
-        return d
+        self.contact.command_TESTY.assert_called_with('westy boo')
 
+    @defer.inlineCallbacks
     def test_handleMessage_excited(self):
         self.patch_send()
-        d = self.contact.handleMessage('hi!')
+        yield self.contact.handleMessage('hi!')
 
-        @d.addCallback
-        def cb(_):
-            self.assertEqual(len(self.sent), 1)  # who cares what it says..
-        return d
+        self.assertEqual(len(self.sent), 1)  # who cares what it says..
 
+    @defer.inlineCallbacks
     def test_handleMessage_exception(self):
         self.patch_send()
 
         def command_TESTY(msg):
             raise RuntimeError("FAIL")
         self.contact.command_TESTY = command_TESTY
-        d = self.contact.handleMessage('testy boom')
+        yield self.contact.handleMessage('testy boom')
 
-        @d.addCallback
-        def cb(_):
-            self.assertEqual(self.sent,
-                             ["Something bad happened (see logs)"])
-            self.assertEqual(len(self.flushLoggedErrors(RuntimeError)), 1)
-        return d
+        self.assertEqual(self.sent,
+                         ["Something bad happened (see logs)"])
+        self.assertEqual(len(self.flushLoggedErrors(RuntimeError)), 1)
 
+    @defer.inlineCallbacks
     def test_handleMessage_UsageError(self):
         self.patch_send()
 
         def command_TESTY(msg):
             raise words.UsageError("oh noes")
         self.contact.command_TESTY = command_TESTY
-        d = self.contact.handleMessage('testy boom')
+        yield self.contact.handleMessage('testy boom')
 
-        @d.addCallback
-        def cb(_):
-            self.assertEqual(self.sent, ["oh noes"])
-        return d
+        self.assertEqual(self.sent, ["oh noes"])
 
     def test_handleAction_ignored(self):
         self.patch_act()
