@@ -13,11 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from future.utils import iteritems
-
 import json
 
 from twisted.internet import defer
@@ -41,8 +36,6 @@ from buildbot.schedulers.forcesched import UserNameParameter
 from buildbot.schedulers.forcesched import oneCodebase
 from buildbot.test.util import scheduler
 from buildbot.test.util.config import ConfigErrorsMixin
-from buildbot.test.util.warnings import assertProducesWarning
-from buildbot.worker_transition import DeprecatedWorkerNameWarning
 
 
 class TestForceScheduler(scheduler.SchedulerMixin, ConfigErrorsMixin, unittest.TestCase):
@@ -157,10 +150,10 @@ class TestForceScheduler(scheduler.SchedulerMixin, ConfigErrorsMixin, unittest.T
                 builderNames=['a'],
                 waited_for=False,
                 properties={
-                    u'owner': ('user', u'Force Build Form'),
-                    u'reason': ('because', u'Force Build Form'),
+                    'owner': ('user', 'Force Build Form'),
+                    'reason': ('because', 'Force Build Form'),
                 },
-                reason=u"A build was forced by 'user': because",
+                reason="A build was forced by 'user': because",
                 sourcestamps=[
                     {'codebase': '', 'branch': 'a', 'revision': 'c',
                      'repository': 'd', 'project': 'p'},
@@ -184,8 +177,8 @@ class TestForceScheduler(scheduler.SchedulerMixin, ConfigErrorsMixin, unittest.T
         self.assertEqual(self.addBuildsetCalls, [
             ('addBuildsetForSourceStampsWithDefaults', {
                 'builderNames': ['a'],
-                'properties': {u'owner': ('user', u'Force Build Form'),
-                               u'reason': ('because', u'Force Build Form')},
+                'properties': {'owner': ('user', 'Force Build Form'),
+                               'reason': ('because', 'Force Build Form')},
                 'reason': 'user wants it because',
                 'sourcestamps': [{'branch': 'a',
                                   'codebase': '',
@@ -221,10 +214,10 @@ class TestForceScheduler(scheduler.SchedulerMixin, ConfigErrorsMixin, unittest.T
                 builderNames=['a', 'b'],
                 waited_for=False,
                 properties={
-                    u'owner': ('user', u'Force Build Form'),
-                    u'reason': ('because', u'Force Build Form'),
+                    'owner': ('user', 'Force Build Form'),
+                    'reason': ('because', 'Force Build Form'),
                 },
-                reason=u"A build was forced by 'user': because",
+                reason="A build was forced by 'user': because",
                 sourcestamps=[
                     {'codebase': '', 'branch': 'a', 'revision': 'c',
                      'repository': 'd', 'project': 'p'},
@@ -245,10 +238,10 @@ class TestForceScheduler(scheduler.SchedulerMixin, ConfigErrorsMixin, unittest.T
                 builderNames=['a', 'b'],
                 waited_for=False,
                 properties={
-                    u'owner': ('user', u'Force Build Form'),
-                    u'reason': ('because', u'Force Build Form'),
+                    'owner': ('user', 'Force Build Form'),
+                    'reason': ('because', 'Force Build Form'),
                 },
-                reason=u"A build was forced by 'user': because",
+                reason="A build was forced by 'user': because",
                 sourcestamps=[
                     {'codebase': '', 'branch': 'a', 'revision': 'c',
                      'repository': 'd', 'project': 'p'},
@@ -258,19 +251,22 @@ class TestForceScheduler(scheduler.SchedulerMixin, ConfigErrorsMixin, unittest.T
     def test_bad_codebases(self):
 
         # codebases must be a list of either string or BaseParameter types
-        self.assertRaisesConfigError("ForceScheduler 'foo': 'codebases' must be a list of strings or CodebaseParameter objects:",
-                                     lambda: ForceScheduler(name='foo', builderNames=['bar'],
-                                                            codebases=[123],))
-        self.assertRaisesConfigError("ForceScheduler 'foo': 'codebases' must be a list of strings or CodebaseParameter objects:",
-                                     lambda: ForceScheduler(name='foo', builderNames=['bar'],
-                                                            codebases=[IntParameter('foo')],))
+        with self.assertRaisesConfigError(
+                "ForceScheduler 'foo': 'codebases' must be a "
+                "list of strings or CodebaseParameter objects:"):
+            ForceScheduler(name='foo', builderNames=['bar'], codebases=[123],)
+
+        with self.assertRaisesConfigError(
+                "ForceScheduler 'foo': 'codebases' must be a "
+                "list of strings or CodebaseParameter objects:"):
+            ForceScheduler(name='foo', builderNames=['bar'],
+                           codebases=[IntParameter('foo')])
 
         # codebases cannot be empty
-        self.assertRaisesConfigError("ForceScheduler 'foo': 'codebases' cannot be empty; use [CodebaseParameter(codebase='', hide=True)] if needed:",
-                                     lambda: ForceScheduler(name='foo',
-                                                            builderNames=[
-                                                                'bar'],
-                                                            codebases=[]))
+        with self.assertRaisesConfigError(
+                "ForceScheduler 'foo': 'codebases' cannot be "
+                "empty; use [CodebaseParameter(codebase='', hide=True)] if needed:"):
+            ForceScheduler(name='foo', builderNames=['bar'], codebases=[])
 
         # codebases cannot be a dictionary
         # dictType on Python 3 is: "<class 'dict'>"
@@ -279,10 +275,9 @@ class TestForceScheduler(scheduler.SchedulerMixin, ConfigErrorsMixin, unittest.T
         errMsg = ("ForceScheduler 'foo': 'codebases' should be a list "
                   "of strings or CodebaseParameter, "
                   "not {}".format(dictType))
-        self.assertRaisesConfigError(errMsg,
-                                     lambda: ForceScheduler(name='foo',
-                                                            builderNames=['bar'],
-                                                            codebases={'cb': {'branch': 'trunk'}}))
+        with self.assertRaisesConfigError(errMsg):
+            ForceScheduler(name='foo', builderNames=['bar'],
+                           codebases={'cb': {'branch': 'trunk'}})
 
     @defer.inlineCallbacks
     def test_good_codebases(self):
@@ -294,15 +289,15 @@ class TestForceScheduler(scheduler.SchedulerMixin, ConfigErrorsMixin, unittest.T
 
         bsid, brids = res
         expProperties = {
-            u'owner': ('user', 'Force Build Form'),
-            u'reason': ('because', 'Force Build Form'),
+            'owner': ('user', 'Force Build Form'),
+            'reason': ('because', 'Force Build Form'),
         }
         self.assertEqual(self.addBuildsetCalls, [
             ('addBuildsetForSourceStampsWithDefaults', dict(
                 builderNames=['a'],
                 waited_for=False,
                 properties=expProperties,
-                reason=u"A build was forced by 'user': because",
+                reason="A build was forced by 'user': because",
                 sourcestamps=[
                     {'branch': 'a2', 'project': 'p2', 'repository': 'd2',
                         'revision': 'c2', 'codebase': 'bar'},
@@ -321,8 +316,8 @@ class TestForceScheduler(scheduler.SchedulerMixin, ConfigErrorsMixin, unittest.T
 
         bsid, brids = res
         expProperties = {
-            u'owner': ('user', 'Force Build Form'),
-            u'reason': ('because', 'Force Build Form'),
+            'owner': ('user', 'Force Build Form'),
+            'reason': ('because', 'Force Build Form'),
         }
 
         self.assertEqual(self.addBuildsetCalls, [
@@ -330,7 +325,7 @@ class TestForceScheduler(scheduler.SchedulerMixin, ConfigErrorsMixin, unittest.T
                 builderNames=['a'],
                 waited_for=False,
                 properties=expProperties,
-                reason=u"A build was forced by 'user': because",
+                reason="A build was forced by 'user': because",
                 sourcestamps=[
                     {'branch': 'a2', 'project': 'p2', 'repository': 'd2',
                         'revision': 'c2', 'codebase': 'bar',
@@ -410,7 +405,7 @@ class TestForceScheduler(scheduler.SchedulerMixin, ConfigErrorsMixin, unittest.T
             if not isinstance(e, expect):
                 # the exception is the wrong kind
                 raise
-            defer.returnValue(None)  # success
+            return None  # success
 
         expect_props = {
             'owner': ('user', 'Force Build Form'),
@@ -420,7 +415,7 @@ class TestForceScheduler(scheduler.SchedulerMixin, ConfigErrorsMixin, unittest.T
         if expectKind is None:
             expect_props[name] = (expect, 'Force Build Form')
         elif expectKind is dict:
-            for k, v in iteritems(expect):
+            for k, v in expect.items():
                 expect_props[k] = (v, 'Force Build Form')
         else:
             self.fail("expectKind is wrong type!")
@@ -432,7 +427,7 @@ class TestForceScheduler(scheduler.SchedulerMixin, ConfigErrorsMixin, unittest.T
                 builderNames=['a'],
                 waited_for=False,
                 properties=expect_props,
-                reason=u"A build was forced by 'user': because",
+                reason="A build was forced by 'user': because",
                 sourcestamps=[
                     {'branch': '', 'project': '', 'repository': '',
                      'revision': '', 'codebase': ''},
@@ -445,7 +440,7 @@ class TestForceScheduler(scheduler.SchedulerMixin, ConfigErrorsMixin, unittest.T
                               expectJson='{"name": "p1", "fullName": "p1", "label": "p1", '
                               '"tablabel": "p1", "type": "text", "default": "", "required": false, '
                               '"multiple": false, "regex": null, "hide": false, "maxsize": null, '
-                              '"size": 10}')
+                              '"size": 10, "autopopulate": null}')
 
     def test_StringParameter_Required(self):
         self.do_ParameterTest(value=" ", expect=CollectedValidationError,
@@ -468,7 +463,7 @@ class TestForceScheduler(scheduler.SchedulerMixin, ConfigErrorsMixin, unittest.T
                               expectJson='{"name": "p1", "fullName": "p1", "label": "p1", '
                               '"tablabel": "p1", "type": "file", "default": "", "required": false, '
                               '"multiple": false, "regex": null, "hide": false, '
-                              '"maxsize": 10485760}')
+                              '"maxsize": 10485760, "autopopulate": null}')
 
     def test_PatchParameter(self):
         self.do_ParameterTest(req=dict(p1_author='me', reason="because"), expect={
@@ -478,25 +473,25 @@ class TestForceScheduler(scheduler.SchedulerMixin, ConfigErrorsMixin, unittest.T
                                    'level': 1,
                                    'subdir': '.'},
                               klass=PatchParameter,
-                              expectJson='{"name": "p1", "fullName": "p1", "label": "p1", '
+                              expectJson='{"name": "p1", "fullName": "p1", "label": "p1", "autopopulate": null, '
                               '"tablabel": "p1", "type": "nested", "default": "", "required": false, '
                               '"multiple": false, "regex": null, "hide": false, "maxsize": null, '
                               '"layout": "vertical", "columns": 1, "fields": [{"name": "body", '
-                              '"fullName": "p1_body", "label": "body", "tablabel": "body", '
+                              '"fullName": "p1_body", "label": "body", "tablabel": "body", "autopopulate": null, '
                               '"type": "file", "default": "", "required": false, "multiple": false, '
                               '"regex": null, "hide": false, "maxsize": 10485760}, {"name": "level", '
                               '"fullName": "p1_level", "label": "level", "tablabel": "level", '
                               '"type": "int", "default": 1, "required": false, "multiple": false, '
-                              '"regex": null, "hide": false, "maxsize": null, "size": 10}, '
+                              '"regex": null, "hide": false, "maxsize": null, "size": 10, "autopopulate": null}, '
                               '{"name": "author", "fullName": "p1_author", "label": "author", '
-                              '"tablabel": "author", "type": "text", "default": "", '
+                              '"tablabel": "author", "type": "text", "default": "", "autopopulate": null, '
                               '"required": false, "multiple": false, "regex": null, "hide": false, '
-                              '"maxsize": null, "size": 10}, {"name": "comment", '
+                              '"maxsize": null, "size": 10}, {"name": "comment", "autopopulate": null, '
                               '"fullName": "p1_comment", "label": "comment", "tablabel": "comment", '
                               '"type": "text", "default": "", "required": false, "multiple": false, '
                               '"regex": null, "hide": false, "maxsize": null, "size": 10}, '
                               '{"name": "subdir", "fullName": "p1_subdir", "label": "subdir", '
-                              '"tablabel": "subdir", "type": "text", "default": ".", '
+                              '"tablabel": "subdir", "type": "text", "default": ".", "autopopulate": null, '
                               '"required": false, "multiple": false, "regex": null, "hide": false, '
                               '"maxsize": null, "size": 10}]}')
 
@@ -505,7 +500,7 @@ class TestForceScheduler(scheduler.SchedulerMixin, ConfigErrorsMixin, unittest.T
                               expectJson='{"name": "p1", "fullName": "p1", "label": "p1", '
                               '"tablabel": "p1", "type": "int", "default": 0, "required": false, '
                               '"multiple": false, "regex": null, "hide": false, "maxsize": null, '
-                              '"size": 10}')
+                              '"size": 10, "autopopulate": null}')
 
     def test_FixedParameter(self):
         self.do_ParameterTest(value="123", expect="321", klass=FixedParameter,
@@ -513,7 +508,7 @@ class TestForceScheduler(scheduler.SchedulerMixin, ConfigErrorsMixin, unittest.T
                               expectJson='{"name": "p1", "fullName": "p1", "label": "p1", '
                               '"tablabel": "p1", "type": "fixed", "default": "321", '
                               '"required": false, "multiple": false, "regex": null, "hide": true, '
-                              '"maxsize": null}')
+                              '"maxsize": null, "autopopulate": null}')
 
     def test_BooleanParameter_True(self):
         req = dict(p1=True, reason='because')
@@ -522,7 +517,7 @@ class TestForceScheduler(scheduler.SchedulerMixin, ConfigErrorsMixin, unittest.T
                               expectJson='{"name": "p1", "fullName": "p1", "label": "p1", '
                               '"tablabel": "p1", "type": "bool", "default": "", "required": false, '
                               '"multiple": false, "regex": null, "hide": false, '
-                              '"maxsize": null}')
+                              '"maxsize": null, "autopopulate": null}')
 
     def test_BooleanParameter_False(self):
         req = dict(p2=True, reason='because')
@@ -538,7 +533,7 @@ class TestForceScheduler(scheduler.SchedulerMixin, ConfigErrorsMixin, unittest.T
                               '"label": "Your name:", "tablabel": "Your name:", "type": "username", '
                               '"default": "", "required": false, "multiple": false, "regex": null, '
                               '"hide": false, "maxsize": null, "size": 30, '
-                              '"need_email": true}')
+                              '"need_email": true, "autopopulate": null}')
 
     def test_UserNameParameterIsValidMail(self):
         email = "test@buildbot.net"
@@ -549,7 +544,7 @@ class TestForceScheduler(scheduler.SchedulerMixin, ConfigErrorsMixin, unittest.T
                               '"label": "Your name:", "tablabel": "Your name:", "type": "username", '
                               '"default": "", "required": false, "multiple": false, "regex": null, '
                               '"hide": false, "maxsize": null, "size": 30, '
-                              '"need_email": true}')
+                              '"need_email": true, "autopopulate": null}')
 
     def test_UserNameParameterIsValidMailBis(self):
         email = "<test@buildbot.net>"
@@ -560,7 +555,7 @@ class TestForceScheduler(scheduler.SchedulerMixin, ConfigErrorsMixin, unittest.T
                               '"label": "Your name:", "tablabel": "Your name:", "type": "username", '
                               '"default": "", "required": false, "multiple": false, "regex": null, '
                               '"hide": false, "maxsize": null, "size": 30, '
-                              '"need_email": true}')
+                              '"need_email": true, "autopopulate": null}')
 
     def test_ChoiceParameter(self):
         self.do_ParameterTest(value='t1', expect='t1',
@@ -569,7 +564,7 @@ class TestForceScheduler(scheduler.SchedulerMixin, ConfigErrorsMixin, unittest.T
                               expectJson='{"name": "p1", "fullName": "p1", "label": "p1", '
                               '"tablabel": "p1", "type": "list", "default": "", "required": false, '
                               '"multiple": false, "regex": null, "hide": false, "maxsize": null, '
-                              '"choices": ["t1", "t2"], "strict": true}')
+                              '"choices": ["t1", "t2"], "strict": true, "autopopulate": null}')
 
     def test_ChoiceParameterError(self):
         self.do_ParameterTest(value='t3',
@@ -590,7 +585,7 @@ class TestForceScheduler(scheduler.SchedulerMixin, ConfigErrorsMixin, unittest.T
                               expectJson='{"name": "p1", "fullName": "p1", "label": "p1", '
                               '"tablabel": "p1", "type": "list", "default": "", "required": false, '
                               '"multiple": true, "regex": null, "hide": false, "maxsize": null, '
-                              '"choices": ["t1", "t2"], "strict": true}')
+                              '"choices": ["t1", "t2"], "strict": true, "autopopulate": null}')
 
     def test_ChoiceParameterMultipleError(self):
         self.do_ParameterTest(value=['t1', 't3'],
@@ -607,11 +602,11 @@ class TestForceScheduler(scheduler.SchedulerMixin, ConfigErrorsMixin, unittest.T
         self.do_ParameterTest(req=dict(p1_foo='123', reason="because"),
                               expect=dict(foo=123),
                               klass=NestedParameter, fields=fields,
-                              expectJson='{"name": "p1", "fullName": "p1", "label": "p1", '
+                              expectJson='{"name": "p1", "fullName": "p1", "label": "p1", "autopopulate": null, '
                               '"tablabel": "p1", "type": "nested", "default": "", "required": false, '
                               '"multiple": false, "regex": null, "hide": false, "maxsize": null, '
                               '"layout": "vertical", "columns": 1, "fields": [{"name": "foo", '
-                              '"fullName": "p1_foo", "label": "foo", "tablabel": "foo", '
+                              '"fullName": "p1_foo", "label": "foo", "tablabel": "foo", "autopopulate": null, '
                               '"type": "int", "default": 0, "required": false, "multiple": false, '
                               '"regex": null, "hide": false, "maxsize": null, "size": 10}]}')
 
@@ -663,84 +658,81 @@ class TestForceScheduler(scheduler.SchedulerMixin, ConfigErrorsMixin, unittest.T
                               klass=NestedParameter, fields=fields, name='')
 
     def test_bad_reason(self):
-        self.assertRaisesConfigError("ForceScheduler 'testsched': reason must be a StringParameter",
-                                     lambda: ForceScheduler(name='testsched', builderNames=[],
-                                                            codebases=['bar'], reason="foo"))
+        with self.assertRaisesConfigError(
+                "ForceScheduler 'testsched': reason must be a StringParameter"):
+            ForceScheduler(name='testsched', builderNames=[],
+                           codebases=['bar'], reason="foo")
 
     def test_bad_username(self):
-        self.assertRaisesConfigError("ForceScheduler 'testsched': username must be a StringParameter",
-                                     lambda: ForceScheduler(name='testsched', builderNames=[],
-                                                            codebases=['bar'], username="foo"))
+        with self.assertRaisesConfigError(
+                "ForceScheduler 'testsched': username must be a StringParameter"):
+            ForceScheduler(name='testsched', builderNames=[],
+                           codebases=['bar'], username="foo")
 
     def test_notstring_name(self):
-        self.assertRaisesConfigError("ForceScheduler name must be a unicode string:",
-                                     lambda: ForceScheduler(name=1234, builderNames=[],
-                                                            codebases=['bar'], username="foo"))
+        with self.assertRaisesConfigError(
+                "ForceScheduler name must be a unicode string:"):
+            ForceScheduler(name=1234, builderNames=[], codebases=['bar'],
+                           username="foo")
 
     def test_notidentifier_name(self):
         # FIXME: this test should be removed eventually when bug 3460 gets a
         # real fix
-        self.assertRaisesConfigError("ForceScheduler name must be an identifier: 'my scheduler'",
-                                     lambda: ForceScheduler(name='my scheduler', builderNames=[],
-                                                            codebases=['bar'], username="foo"))
+        with self.assertRaisesConfigError(
+                "ForceScheduler name must be an identifier: 'my scheduler'"):
+            ForceScheduler(name='my scheduler', builderNames=[],
+                           codebases=['bar'], username="foo")
 
     def test_emptystring_name(self):
-        self.assertRaisesConfigError("ForceScheduler name must not be empty:",
-                                     lambda: ForceScheduler(name='', builderNames=[],
-                                                            codebases=['bar'], username="foo"))
+        with self.assertRaisesConfigError(
+                "ForceScheduler name must not be empty:"):
+            ForceScheduler(name='', builderNames=[], codebases=['bar'],
+                           username="foo")
 
     def test_integer_builderNames(self):
-        self.assertRaisesConfigError("ForceScheduler 'testsched': builderNames must be a list of strings:",
-                                     lambda: ForceScheduler(name='testsched', builderNames=1234,
-                                                            codebases=['bar'], username="foo"))
+        with self.assertRaisesConfigError(
+                "ForceScheduler 'testsched': builderNames must be a list of strings:"):
+            ForceScheduler(name='testsched', builderNames=1234,
+                           codebases=['bar'], username="foo")
 
     def test_listofints_builderNames(self):
-        self.assertRaisesConfigError("ForceScheduler 'testsched': builderNames must be a list of strings:",
-                                     lambda: ForceScheduler(name='testsched', builderNames=[1234],
-                                                            codebases=['bar'], username="foo"))
+        with self.assertRaisesConfigError(
+                "ForceScheduler 'testsched': builderNames must be a list of strings:"):
+            ForceScheduler(name='testsched', builderNames=[1234],
+                           codebases=['bar'], username="foo")
 
     def test_listofunicode_builderNames(self):
-        ForceScheduler(name='testsched', builderNames=[u'a', u'b'])
+        ForceScheduler(name='testsched', builderNames=['a', 'b'])
 
     def test_listofmixed_builderNames(self):
-        self.assertRaisesConfigError("ForceScheduler 'testsched': builderNames must be a list of strings:",
-                                     lambda: ForceScheduler(name='testsched',
-                                                            builderNames=[
-                                                                'test', 1234],
-                                                            codebases=['bar'], username="foo"))
+        with self.assertRaisesConfigError(
+                "ForceScheduler 'testsched': builderNames must be a list of strings:"):
+            ForceScheduler(name='testsched', builderNames=['test', 1234],
+                           codebases=['bar'], username="foo")
 
     def test_integer_properties(self):
-        self.assertRaisesConfigError("ForceScheduler 'testsched': properties must be a list of BaseParameters:",
-                                     lambda: ForceScheduler(name='testsched', builderNames=[],
-                                                            codebases=['bar'], username="foo",
-                                                            properties=1234))
+        with self.assertRaisesConfigError(
+                "ForceScheduler 'testsched': properties must be a list of BaseParameters:"):
+            ForceScheduler(name='testsched', builderNames=[],
+                           codebases=['bar'], username="foo",
+                           properties=1234)
 
     def test_listofints_properties(self):
-        self.assertRaisesConfigError("ForceScheduler 'testsched': properties must be a list of BaseParameters:",
-                                     lambda: ForceScheduler(name='testsched', builderNames=[],
-                                                            codebases=['bar'], username="foo",
-                                                            properties=[1234, 2345]))
+        with self.assertRaisesConfigError(
+                "ForceScheduler 'testsched': properties must be a list of BaseParameters:"):
+            ForceScheduler(name='testsched', builderNames=[],
+                           codebases=['bar'], username="foo",
+                           properties=[1234, 2345])
 
     def test_listofmixed_properties(self):
-        self.assertRaisesConfigError("ForceScheduler 'testsched': properties must be a list of BaseParameters:",
-                                     lambda: ForceScheduler(name='testsched', builderNames=[],
-                                                            codebases=['bar'], username="foo",
-                                                            properties=[BaseParameter(name="test",),
-                                                                        4567]))
+        with self.assertRaisesConfigError(
+                "ForceScheduler 'testsched': properties must be a list of BaseParameters:"):
+            ForceScheduler(name='testsched', builderNames=[],
+                           codebases=['bar'], username="foo",
+                           properties=[BaseParameter(name="test",),
+                           4567])
 
     def test_novalue_to_parameter(self):
-        self.assertRaisesConfigError("Use default='1234' instead of value=... to give a default Parameter value",
-                                     lambda: BaseParameter(name="test", value="1234"))
-
-
-class TestWorkerTransition(unittest.TestCase):
-
-    def test_BuildslaveChoiceParameter_deprecated(self):
-        from buildbot.schedulers.forcesched import WorkerChoiceParameter
-
-        with assertProducesWarning(
-                DeprecatedWorkerNameWarning,
-                message_pattern="BuildslaveChoiceParameter was deprecated"):
-            from buildbot.schedulers.forcesched import BuildslaveChoiceParameter
-
-        self.assertIdentical(BuildslaveChoiceParameter, WorkerChoiceParameter)
+        with self.assertRaisesConfigError(
+                "Use default='1234' instead of value=... to give a default Parameter value"):
+            BaseParameter(name="test", value="1234")
