@@ -13,9 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-
 import datetime
 import time
 
@@ -210,19 +207,19 @@ class Nightly(scheduler.SchedulerMixin, unittest.TestCase):
                 'builderNames': None,
                 'sourcestamps': [{'codebase': ''}],
                 'properties': None,
-                'reason': u"The Nightly scheduler named 'test' triggered this build",
+                'reason': "The Nightly scheduler named 'test' triggered this build",
                 'waited_for': False}),
             ('addBuildsetForSourceStampsWithDefaults', {
                 'builderNames': None,
                 'sourcestamps': [{'codebase': ''}],
                 'properties': None,
-                'reason': u"The Nightly scheduler named 'test' triggered this build",
+                'reason': "The Nightly scheduler named 'test' triggered this build",
                 'waited_for': False}),
             ('addBuildsetForSourceStampsWithDefaults', {
                 'builderNames': None,
                 'sourcestamps': [{'codebase': ''}],
                 'properties': None,
-                'reason': u"The Nightly scheduler named 'test' triggered this build",
+                'reason': "The Nightly scheduler named 'test' triggered this build",
                 'waited_for': False})])
         self.db.state.assertStateByClass('test', 'Nightly',
                                          last_build=1260 + self.localtime_offset)
@@ -245,7 +242,7 @@ class Nightly(scheduler.SchedulerMixin, unittest.TestCase):
                 'builderNames': None,
                 'sourcestamps': [{'codebase': ''}],
                 'properties': None,
-                'reason': u"The Nightly scheduler named 'test' triggered this build",
+                'reason': "The Nightly scheduler named 'test' triggered this build",
                 'waited_for': False})])
         self.db.state.assertStateByClass('test', 'Nightly',
                                          last_build=300 + self.localtime_offset)
@@ -330,7 +327,7 @@ class Nightly(scheduler.SchedulerMixin, unittest.TestCase):
                 'changeids': [3, 5, 6],
                 'external_idstring': None,
                 'properties': None,
-                'reason': u"The Nightly scheduler named 'test' triggered this build",
+                'reason': "The Nightly scheduler named 'test' triggered this build",
                 'waited_for': False})])
         self.db.state.assertStateByClass('test', 'Nightly',
                                          last_build=1500 + self.localtime_offset)
@@ -357,7 +354,7 @@ class Nightly(scheduler.SchedulerMixin, unittest.TestCase):
                 'changeids': [3],
                 'external_idstring': None,
                 'properties': None,
-                'reason': u"The Nightly scheduler named 'test' triggered this build",
+                'reason': "The Nightly scheduler named 'test' triggered this build",
                 'waited_for': False})])
         self.db.state.assertStateByClass('test', 'Nightly', lastCodebases={
             'a': dict(revision='2345:bcd', branch=None, repository='', lastChange=3)})
@@ -394,7 +391,7 @@ class Nightly(scheduler.SchedulerMixin, unittest.TestCase):
                 'changeids': [3],
                 'external_idstring': None,
                 'properties': None,
-                'reason': u"The Nightly scheduler named 'test' triggered this build",
+                'reason': "The Nightly scheduler named 'test' triggered this build",
                 'waited_for': False})])
         self.db.state.assertStateByClass('test', 'Nightly', lastCodebases={
             'a': dict(revision='2345:bcd', branch=None, repository='', lastChange=3),
@@ -423,7 +420,7 @@ class Nightly(scheduler.SchedulerMixin, unittest.TestCase):
                 'changeids': [3, 4],
                 'external_idstring': None,
                 'properties': None,
-                'reason': u"The Nightly scheduler named 'test' triggered this build",
+                'reason': "The Nightly scheduler named 'test' triggered this build",
                 'waited_for': False})])
         self.db.state.assertStateByClass('test', 'Nightly', lastCodebases={
             'a': dict(revision='2345:bcd', branch=None, repository='', lastChange=3),
