@@ -13,9 +13,7 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-
+from twisted.internet import defer
 from twisted.trial import unittest
 
 from buildbot import config
@@ -454,12 +452,12 @@ class TestSphinx(steps.BuildStepMixin, unittest.TestCase):
         return self.tearDownBuildStep()
 
     def test_builddir_required(self):
-        self.assertRaises(config.ConfigErrors, lambda:
-                          python.Sphinx())
+        with self.assertRaises(config.ConfigErrors):
+            python.Sphinx()
 
     def test_bad_mode(self):
-        self.assertRaises(config.ConfigErrors, lambda: python.Sphinx(
-            sphinx_builddir="_build", mode="don't care"))
+        with self.assertRaises(config.ConfigErrors):
+            python.Sphinx(sphinx_builddir="_build", mode="don't care")
 
     def test_success(self):
         self.setupStep(python.Sphinx(sphinx_builddir="_build"))
@@ -499,6 +497,7 @@ class TestSphinx(steps.BuildStepMixin, unittest.TestCase):
                            state_string="sphinx 0 warnings")
         return self.runStep()
 
+    @defer.inlineCallbacks
     def test_warnings(self):
         self.setupStep(python.Sphinx(sphinx_builddir="_build"))
         self.expectCommands(
@@ -511,12 +510,9 @@ class TestSphinx(steps.BuildStepMixin, unittest.TestCase):
         self.expectOutcome(result=WARNINGS,
                            state_string="sphinx 2 warnings (warnings)")
         self.expectLogfile("warnings", warnings)
-        d = self.runStep()
+        yield self.runStep()
 
-        def check(_):
-            self.assertEqual(self.step.statistics, {'warnings': 2})
-        d.addCallback(check)
-        return d
+        self.assertEqual(self.step.statistics, {'warnings': 2})
 
     def test_constr_args(self):
         self.setupStep(python.Sphinx(sphinx_sourcedir='src',
