@@ -13,10 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-from future.utils import iteritems
-
 import json
 import os
 import shutil
@@ -27,6 +23,7 @@ from io import BytesIO
 
 from mock import Mock
 
+from twisted.internet import defer
 from twisted.trial import unittest
 
 from buildbot import config
@@ -40,12 +37,8 @@ from buildbot.steps import transfer
 from buildbot.test.fake.remotecommand import Expect
 from buildbot.test.fake.remotecommand import ExpectRemoteRef
 from buildbot.test.util import steps
-from buildbot.test.util.warnings import assertNotProducesWarnings
-from buildbot.test.util.warnings import assertProducesWarning
-from buildbot.util import bytes2NativeString
+from buildbot.util import bytes2unicode
 from buildbot.util import unicode2bytes
-from buildbot.worker_transition import DeprecatedWorkerAPIWarning
-from buildbot.worker_transition import DeprecatedWorkerNameWarning
 
 
 def uploadString(string, timestamp=None):
@@ -75,7 +68,7 @@ def uploadTarFile(filename, **members):
     def behavior(command):
         f = BytesIO()
         archive = tarfile.TarFile(fileobj=f, name=filename, mode='w')
-        for name, content in iteritems(members):
+        for name, content in members.items():
             content = unicode2bytes(content)
             archive.addfile(tarfile.TarInfo(name), BytesIO(content))
         writer = command.args['writer']
@@ -111,8 +104,8 @@ class TestFileUpload(steps.BuildStepMixin, unittest.TestCase):
         return self.tearDownBuildStep()
 
     def testConstructorModeType(self):
-        self.assertRaises(config.ConfigErrors, lambda:
-                          transfer.FileUpload(workersrc=__file__, masterdest='xyz', mode='g+rwx'))
+        with self.assertRaises(config.ConfigErrors):
+            transfer.FileUpload(workersrc=__file__, masterdest='xyz', mode='g+rwx')
 
     def testBasic(self):
         self.setupStep(
@@ -121,7 +114,7 @@ class TestFileUpload(steps.BuildStepMixin, unittest.TestCase):
         self.expectCommands(
             Expect('uploadFile', dict(
                 workersrc="srcfile", workdir='wkdir',
-                blocksize=16384, maxsize=None, keepstamp=False,
+                blocksize=262144, maxsize=None, keepstamp=False,
                 writer=ExpectRemoteRef(remotetransfer.FileWriter)))
             + Expect.behavior(uploadString("Hello world!"))
             + 0)
@@ -139,7 +132,7 @@ class TestFileUpload(steps.BuildStepMixin, unittest.TestCase):
         self.expectCommands(
             Expect('uploadFile', dict(
                 slavesrc="srcfile", workdir='wkdir',
-                blocksize=16384, maxsize=None, keepstamp=False,
+                blocksize=262144, maxsize=None, keepstamp=False,
                 writer=ExpectRemoteRef(remotetransfer.FileWriter)))
             + Expect.behavior(uploadString("Hello world!"))
             + 0)
@@ -149,6 +142,7 @@ class TestFileUpload(steps.BuildStepMixin, unittest.TestCase):
         d = self.runStep()
         return d
 
+    @defer.inlineCallbacks
     def testTimestamp(self):
         self.setupStep(
             transfer.FileUpload(workersrc=__file__, masterdest=self.destfile, keepstamp=True))
@@ -159,7 +153,7 @@ class TestFileUpload(steps.BuildStepMixin, unittest.TestCase):
         self.expectCommands(
             Expect('uploadFile', dict(
                 workersrc=__file__, workdir='wkdir',
-                blocksize=16384, maxsize=None, keepstamp=True,
+                blocksize=262144, maxsize=None, keepstamp=True,
                 writer=ExpectRemoteRef(remotetransfer.FileWriter)))
             + Expect.behavior(uploadString('test', timestamp=timestamp))
             + 0)
@@ -168,19 +162,16 @@ class TestFileUpload(steps.BuildStepMixin, unittest.TestCase):
             result=SUCCESS,
             state_string="uploading %s" % os.path.basename(__file__))
 
-        d = self.runStep()
+        yield self.runStep()
 
-        @d.addCallback
-        def checkTimestamp(_):
-            desttimestamp = (os.path.getatime(self.destfile),
-                             os.path.getmtime(self.destfile))
+        desttimestamp = (os.path.getatime(self.destfile),
+                         os.path.getmtime(self.destfile))
 
-            srctimestamp = [int(t) for t in timestamp]
-            desttimestamp = [int(d) for d in desttimestamp]
+        srctimestamp = [int(t) for t in timestamp]
+        desttimestamp = [int(d) for d in desttimestamp]
 
-            self.assertEqual(srctimestamp[0], desttimestamp[0])
-            self.assertEqual(srctimestamp[1], desttimestamp[1])
-        return d
+        self.assertEqual(srctimestamp[0], desttimestamp[0])
+        self.assertEqual(srctimestamp[1], desttimestamp[1])
 
     def testDescriptionDone(self):
         self.setupStep(
@@ -192,7 +183,7 @@ class TestFileUpload(steps.BuildStepMixin, unittest.TestCase):
         self.expectCommands(
             Expect('uploadFile', dict(
                 workersrc=__file__, workdir='wkdir',
-                blocksize=16384, maxsize=None, keepstamp=False,
+                blocksize=262144, maxsize=None, keepstamp=False,
                 writer=ExpectRemoteRef(remotetransfer.FileWriter)))
             + Expect.behavior(uploadString("Hello world!"))
             + 0)
@@ -204,6 +195,7 @@ class TestFileUpload(steps.BuildStepMixin, unittest.TestCase):
         d = self.runStep()
         return d
 
+    @defer.inlineCallbacks
     def testURL(self):
         self.setupStep(
             transfer.FileUpload(workersrc=__file__, masterdest=self.destfile, url="http://server/file"))
@@ -213,7 +205,7 @@ class TestFileUpload(steps.BuildStepMixin, unittest.TestCase):
         self.expectCommands(
             Expect('uploadFile', dict(
                 workersrc=__file__, workdir='wkdir',
-                blocksize=16384, maxsize=None, keepstamp=False,
+                blocksize=262144, maxsize=None, keepstamp=False,
                 writer=ExpectRemoteRef(remotetransfer.FileWriter)))
             + Expect.behavior(uploadString("Hello world!"))
             + 0)
@@ -222,14 +214,12 @@ class TestFileUpload(steps.BuildStepMixin, unittest.TestCase):
             result=SUCCESS,
             state_string="uploading %s" % os.path.basename(__file__))
 
-        d = self.runStep()
+        yield self.runStep()
 
-        @d.addCallback
-        def checkURL(_):
-            self.step.addURL.assert_called_once_with(
-                os.path.basename(self.destfile), "http://server/file")
-        return d
+        self.step.addURL.assert_called_once_with(
+            os.path.basename(self.destfile), "http://server/file")
 
+    @defer.inlineCallbacks
     def testURLText(self):
         self.setupStep(
             transfer.FileUpload(workersrc=__file__, masterdest=self.destfile, url="http://server/file", urlText="testfile"))
@@ -239,7 +229,7 @@ class TestFileUpload(steps.BuildStepMixin, unittest.TestCase):
         self.expectCommands(
             Expect('uploadFile', dict(
                 workersrc=__file__, workdir='wkdir',
-                blocksize=16384, maxsize=None, keepstamp=False,
+                blocksize=262144, maxsize=None, keepstamp=False,
                 writer=ExpectRemoteRef(remotetransfer.FileWriter)))
             + Expect.behavior(uploadString("Hello world!"))
             + 0)
@@ -248,13 +238,10 @@ class TestFileUpload(steps.BuildStepMixin, unittest.TestCase):
             result=SUCCESS,
             state_string="uploading %s" % os.path.basename(__file__))
 
-        d = self.runStep()
+        yield self.runStep()
 
-        @d.addCallback
-        def checkURL(_):
-            self.step.addURL.assert_called_once_with(
-                "testfile", "http://server/file")
-        return d
+        self.step.addURL.assert_called_once_with(
+            "testfile", "http://server/file")
 
     def testFailure(self):
         self.setupStep(
@@ -263,7 +250,7 @@ class TestFileUpload(steps.BuildStepMixin, unittest.TestCase):
         self.expectCommands(
             Expect('uploadFile', dict(
                 workersrc="srcfile", workdir='wkdir',
-                blocksize=16384, maxsize=None, keepstamp=False,
+                blocksize=262144, maxsize=None, keepstamp=False,
                 writer=ExpectRemoteRef(remotetransfer.FileWriter)))
             + 1)
 
@@ -273,6 +260,7 @@ class TestFileUpload(steps.BuildStepMixin, unittest.TestCase):
         d = self.runStep()
         return d
 
+    @defer.inlineCallbacks
     def testException(self):
         self.setupStep(
             transfer.FileUpload(workersrc='srcfile', masterdest=self.destfile))
@@ -282,60 +270,34 @@ class TestFileUpload(steps.BuildStepMixin, unittest.TestCase):
         self.expectCommands(
             Expect('uploadFile', dict(
                 workersrc="srcfile", workdir='wkdir',
-                blocksize=16384, maxsize=None, keepstamp=False,
+                blocksize=262144, maxsize=None, keepstamp=False,
                 writer=ExpectRemoteRef(remotetransfer.FileWriter)))
             + Expect.behavior(behavior))
 
         self.expectOutcome(
             result=EXCEPTION, state_string="uploading srcfile (exception)")
-        d = self.runStep()
+        yield self.runStep()
 
-        @d.addCallback
-        def check(_):
-            self.assertEqual(behavior.writer.cancel.called, True)
-            self.assertEqual(
-                len(self.flushLoggedErrors(RuntimeError)), 1)
+        self.assertEqual(behavior.writer.cancel.called, True)
+        self.assertEqual(
+            len(self.flushLoggedErrors(RuntimeError)), 1)
 
-        return d
-
-    def test_workersrc_old_api(self):
-        step = transfer.FileUpload(workersrc='srcfile', masterdest='dstfile')
-
-        with assertNotProducesWarnings(DeprecatedWorkerAPIWarning):
-            new = step.workersrc
-
-        with assertProducesWarning(
-                DeprecatedWorkerNameWarning,
-                message_pattern="'slavesrc' attribute is deprecated"):
-            old = step.slavesrc
-
-        self.assertIdentical(new, old)
-
-    def test_init_workersrc_new_api_no_warns(self):
-        with assertNotProducesWarnings(DeprecatedWorkerAPIWarning):
-            step = transfer.FileUpload(
-                workersrc='srcfile', masterdest='dstfile')
-
-        self.assertEqual(step.workersrc, 'srcfile')
-
-    def test_init_workersrc_old_api_warns(self):
-        with assertProducesWarning(
-                DeprecatedWorkerNameWarning,
-                message_pattern="'slavesrc' keyword argument is deprecated"):
-            step = transfer.FileUpload(
-                slavesrc='srcfile', masterdest='dstfile')
+    def test_init_workersrc_keyword(self):
+        step = transfer.FileUpload(
+            workersrc='srcfile', masterdest='dstfile')
 
         self.assertEqual(step.workersrc, 'srcfile')
 
     def test_init_workersrc_positional(self):
-        with assertNotProducesWarnings(DeprecatedWorkerAPIWarning):
-            step = transfer.FileUpload('srcfile', 'dstfile')
+        step = transfer.FileUpload('srcfile', 'dstfile')
 
         self.assertEqual(step.workersrc, 'srcfile')
 
     def test_init_positional_args(self):
-        self.assertRaises(TypeError, lambda: transfer.FileUpload())
-        self.assertRaises(TypeError, lambda: transfer.FileUpload('src'))
+        with self.assertRaises(TypeError):
+            transfer.FileUpload()
+        with self.assertRaises(TypeError):
+            transfer.FileUpload('src')
 
 
 class TestDirectoryUpload(steps.BuildStepMixin, unittest.TestCase):
@@ -405,6 +367,7 @@ class TestDirectoryUpload(steps.BuildStepMixin, unittest.TestCase):
         d = self.runStep()
         return d
 
+    @defer.inlineCallbacks
     def testException(self):
         self.setupStep(
             transfer.DirectoryUpload(workersrc='srcdir', masterdest=self.destdir))
@@ -421,55 +384,28 @@ class TestDirectoryUpload(steps.BuildStepMixin, unittest.TestCase):
         self.expectOutcome(
             result=EXCEPTION,
             state_string="uploading srcdir (exception)")
-        d = self.runStep()
+        yield self.runStep()
 
-        @d.addCallback
-        def check(_):
-            self.assertEqual(behavior.writer.cancel.called, True)
-            self.assertEqual(
+        self.assertEqual(behavior.writer.cancel.called, True)
+        self.assertEqual(
                 len(self.flushLoggedErrors(RuntimeError)), 1)
 
-        return d
-
-    def test_workersrc_old_api(self):
+    def test_init_workersrc_keyword(self):
         step = transfer.DirectoryUpload(
             workersrc='srcfile', masterdest='dstfile')
 
-        with assertNotProducesWarnings(DeprecatedWorkerAPIWarning):
-            new = step.workersrc
-
-        with assertProducesWarning(
-                DeprecatedWorkerNameWarning,
-                message_pattern="'slavesrc' attribute is deprecated"):
-            old = step.slavesrc
-
-        self.assertIdentical(new, old)
-
-    def test_init_workersrc_new_api_no_warns(self):
-        with assertNotProducesWarnings(DeprecatedWorkerAPIWarning):
-            step = transfer.DirectoryUpload(
-                workersrc='srcfile', masterdest='dstfile')
-
-        self.assertEqual(step.workersrc, 'srcfile')
-
-    def test_init_workersrc_old_api_warns(self):
-        with assertProducesWarning(
-                DeprecatedWorkerNameWarning,
-                message_pattern="'slavesrc' keyword argument is deprecated"):
-            step = transfer.DirectoryUpload(
-                slavesrc='srcfile', masterdest='dstfile')
-
         self.assertEqual(step.workersrc, 'srcfile')
 
     def test_init_workersrc_positional(self):
-        with assertNotProducesWarnings(DeprecatedWorkerAPIWarning):
-            step = transfer.DirectoryUpload('srcfile', 'dstfile')
+        step = transfer.DirectoryUpload('srcfile', 'dstfile')
 
         self.assertEqual(step.workersrc, 'srcfile')
 
     def test_init_positional_args(self):
-        self.assertRaises(TypeError, lambda: transfer.DirectoryUpload())
-        self.assertRaises(TypeError, lambda: transfer.DirectoryUpload('src'))
+        with self.assertRaises(TypeError):
+            transfer.DirectoryUpload()
+        with self.assertRaises(TypeError):
+            transfer.DirectoryUpload('src')
 
 
 class TestMultipleFileUpload(steps.BuildStepMixin, unittest.TestCase):
@@ -721,6 +657,7 @@ class TestMultipleFileUpload(steps.BuildStepMixin, unittest.TestCase):
         d = self.runStep()
         return d
 
+    @defer.inlineCallbacks
     def testException(self):
         self.setupStep(
             transfer.MultipleFileUpload(workersrcs=["srcfile", "srcdir"], masterdest=self.destdir))
@@ -740,16 +677,13 @@ class TestMultipleFileUpload(steps.BuildStepMixin, unittest.TestCase):
 
         self.expectOutcome(
             result=EXCEPTION, state_string="uploading 2 files (exception)")
-        d = self.runStep()
+        yield self.runStep()
 
-        @d.addCallback
-        def check(_):
-            self.assertEqual(behavior.writer.cancel.called, True)
-            self.assertEqual(
+        self.assertEqual(behavior.writer.cancel.called, True)
+        self.assertEqual(
                 len(self.flushLoggedErrors(RuntimeError)), 1)
 
-        return d
-
+    @defer.inlineCallbacks
     def testSubclass(self):
         class CustomStep(transfer.MultipleFileUpload):
             uploadDone = Mock(return_value=None)
@@ -784,9 +718,8 @@ class TestMultipleFileUpload(steps.BuildStepMixin, unittest.TestCase):
         self.expectOutcome(
             result=SUCCESS, state_string="uploading 2 files")
 
-        d = self.runStep()
+        yield self.runStep()
 
-        @d.addCallback
         def checkCalls(res):
             self.assertEqual(step.uploadDone.call_count, 2)
             self.assertEqual(step.uploadDone.call_args_list[0],
@@ -796,50 +729,23 @@ class TestMultipleFileUpload(steps.BuildStepMixin, unittest.TestCase):
             self.assertEqual(step.allUploadsDone.call_count, 1)
             self.assertEqual(step.allUploadsDone.call_args_list[0],
                              ((SUCCESS, ['srcfile', 'srcdir'], self.destdir), {}))
-            return res
 
-        return d
-
-    def test_workersrcs_old_api(self):
+    def test_init_workersrcs_keyword(self):
         step = transfer.MultipleFileUpload(
             workersrcs=['srcfile'], masterdest='dstfile')
 
-        with assertNotProducesWarnings(DeprecatedWorkerAPIWarning):
-            new = step.workersrcs
-
-        with assertProducesWarning(
-                DeprecatedWorkerNameWarning,
-                message_pattern="'slavesrcs' attribute is deprecated"):
-            old = step.slavesrcs
-
-        self.assertIdentical(new, old)
-
-    def test_init_workersrcs_new_api_no_warns(self):
-        with assertNotProducesWarnings(DeprecatedWorkerAPIWarning):
-            step = transfer.MultipleFileUpload(
-                workersrcs=['srcfile'], masterdest='dstfile')
-
-        self.assertEqual(step.workersrcs, ['srcfile'])
-
-    def test_init_workersrcs_old_api_warns(self):
-        with assertProducesWarning(
-                DeprecatedWorkerNameWarning,
-                message_pattern="'slavesrcs' keyword argument is deprecated"):
-            step = transfer.MultipleFileUpload(
-                slavesrcs=['srcfile'], masterdest='dstfile')
-
         self.assertEqual(step.workersrcs, ['srcfile'])
 
     def test_init_workersrcs_positional(self):
-        with assertNotProducesWarnings(DeprecatedWorkerAPIWarning):
-            step = transfer.MultipleFileUpload(['srcfile'], 'dstfile')
+        step = transfer.MultipleFileUpload(['srcfile'], 'dstfile')
 
         self.assertEqual(step.workersrcs, ['srcfile'])
 
     def test_init_positional_args(self):
-        self.assertRaises(TypeError, lambda: transfer.MultipleFileUpload())
-        self.assertRaises(
-            TypeError, lambda: transfer.MultipleFileUpload(['srcfile']))
+        with self.assertRaises(TypeError):
+            transfer.MultipleFileUpload()
+        with self.assertRaises(TypeError):
+            transfer.MultipleFileUpload(['srcfile'])
 
 
 class TestFileDownload(steps.BuildStepMixin, unittest.TestCase):
@@ -855,45 +761,24 @@ class TestFileDownload(steps.BuildStepMixin, unittest.TestCase):
             os.unlink(self.destfile)
         return self.tearDownBuildStep()
 
-    def test_workerdest_old_api(self):
-        step = transfer.FileDownload(mastersrc='srcfile', workerdest='dstfile')
-
-        with assertNotProducesWarnings(DeprecatedWorkerAPIWarning):
-            new = step.workerdest
-
-        with assertProducesWarning(
-                DeprecatedWorkerNameWarning,
-                message_pattern="'slavedest' attribute is deprecated"):
-            old = step.slavedest
-
-        self.assertIdentical(new, old)
-
-    def test_init_workerdest_new_api_no_warns(self):
-        with assertNotProducesWarnings(DeprecatedWorkerAPIWarning):
-            step = transfer.FileDownload(
-                mastersrc='srcfile', workerdest='dstfile')
-
-        self.assertEqual(step.workerdest, 'dstfile')
-
-    def test_init_workerdest_old_api_warns(self):
-        with assertProducesWarning(
-                DeprecatedWorkerNameWarning,
-                message_pattern="'slavedest' keyword argument is deprecated"):
-            step = transfer.FileDownload(
-                mastersrc='srcfile', slavedest='dstfile')
+    def test_init_workerdest_keyword(self):
+        step = transfer.FileDownload(
+            mastersrc='srcfile', workerdest='dstfile')
 
         self.assertEqual(step.workerdest, 'dstfile')
 
     def test_init_workerdest_positional(self):
-        with assertNotProducesWarnings(DeprecatedWorkerAPIWarning):
-            step = transfer.FileDownload('srcfile', 'dstfile')
+        step = transfer.FileDownload('srcfile', 'dstfile')
 
         self.assertEqual(step.workerdest, 'dstfile')
 
     def test_init_positional_args(self):
-        self.assertRaises(TypeError, lambda: transfer.FileDownload())
-        self.assertRaises(TypeError, lambda: transfer.FileDownload('srcfile'))
+        with self.assertRaises(TypeError):
+            transfer.FileDownload()
+        with self.assertRaises(TypeError):
+            transfer.FileDownload('srcfile')
 
+    @defer.inlineCallbacks
     def testBasic(self):
         master_file = __file__
         self.setupStep(
@@ -915,18 +800,15 @@ class TestFileDownload(steps.BuildStepMixin, unittest.TestCase):
             result=SUCCESS,
             state_string="downloading to {0}".format(
                 os.path.basename(self.destfile)))
-        d = self.runStep()
+        yield self.runStep()
 
-        @d.addCallback
-        def checkCalls(res):
-            with open(master_file, "rb") as f:
-                contents = f.read()
-            # Only first 1000 bytes transferred in downloadString() helper
-            contents = contents[:1000]
-            self.assertEqual(b''.join(read), contents)
-
-        return d
+        with open(master_file, "rb") as f:
+            contents = f.read()
+        # Only first 1000 bytes transferred in downloadString() helper
+        contents = contents[:1000]
+        self.assertEqual(b''.join(read), contents)
 
+    @defer.inlineCallbacks
     def testBasicWorker2_16(self):
         master_file = __file__
         self.setupStep(
@@ -949,9 +831,8 @@ class TestFileDownload(steps.BuildStepMixin, unittest.TestCase):
             result=SUCCESS,
             state_string="downloading to {0}".format(
                 os.path.basename(self.destfile)))
-        d = self.runStep()
+        yield self.runStep()
 
-        @d.addCallback
         def checkCalls(res):
             with open(master_file, "rb") as f:
                 contents = f.read()
@@ -959,8 +840,6 @@ class TestFileDownload(steps.BuildStepMixin, unittest.TestCase):
             contents = contents[:1000]
             self.assertEqual(b''.join(read), contents)
 
-        return d
-
 
 class TestStringDownload(steps.BuildStepMixin, unittest.TestCase):
 
@@ -973,13 +852,12 @@ class TestStringDownload(steps.BuildStepMixin, unittest.TestCase):
     # check that ConfigErrors is raised on invalid 'mode' argument
 
     def testModeConfError(self):
-        self.assertRaisesRegex(
-            config.ConfigErrors,
-            "StringDownload step's mode must be an integer or None,"
-            " got 'not-a-number'",
-            transfer.StringDownload,
-            "string", "file", mode="not-a-number")
+        with self.assertRaisesRegex(config.ConfigErrors,
+                "StringDownload step's mode must be an integer or None,"
+                " got 'not-a-number'"):
+            transfer.StringDownload("string", "file", mode="not-a-number")
 
+    @defer.inlineCallbacks
     def testBasic(self):
         self.setupStep(transfer.StringDownload("Hello World", "hello.txt"))
 
@@ -999,13 +877,12 @@ class TestStringDownload(steps.BuildStepMixin, unittest.TestCase):
 
         self.expectOutcome(
             result=SUCCESS, state_string="downloading to hello.txt")
-        d = self.runStep()
+        yield self.runStep()
 
-        @d.addCallback
         def checkCalls(res):
             self.assertEqual(b''.join(read), b"Hello World")
-        return d
 
+    @defer.inlineCallbacks
     def testBasicWorker2_16(self):
         self.setupStep(
             transfer.StringDownload("Hello World", "hello.txt"),
@@ -1027,12 +904,9 @@ class TestStringDownload(steps.BuildStepMixin, unittest.TestCase):
 
         self.expectOutcome(
             result=SUCCESS, state_string="downloading to hello.txt")
-        d = self.runStep()
+        yield self.runStep()
 
-        @d.addCallback
-        def checkCalls(res):
-            self.assertEqual(b''.join(read), b"Hello World")
-        return d
+        self.assertEqual(b''.join(read), b"Hello World")
 
     def testFailure(self):
         self.setupStep(transfer.StringDownload("Hello World", "hello.txt"))
@@ -1048,43 +922,21 @@ class TestStringDownload(steps.BuildStepMixin, unittest.TestCase):
             result=FAILURE, state_string="downloading to hello.txt (failure)")
         return self.runStep()
 
-    def test_workerdest_old_api(self):
+    def test_init_workerdest_keyword(self):
         step = transfer.StringDownload('srcfile', workerdest='dstfile')
 
-        with assertNotProducesWarnings(DeprecatedWorkerAPIWarning):
-            new = step.workerdest
-
-        with assertProducesWarning(
-                DeprecatedWorkerNameWarning,
-                message_pattern="'slavedest' attribute is deprecated"):
-            old = step.slavedest
-
-        self.assertIdentical(new, old)
-
-    def test_init_workerdest_new_api_no_warns(self):
-        with assertNotProducesWarnings(DeprecatedWorkerAPIWarning):
-            step = transfer.StringDownload('srcfile', workerdest='dstfile')
-
-        self.assertEqual(step.workerdest, 'dstfile')
-
-    def test_init_workerdest_old_api_warns(self):
-        with assertProducesWarning(
-                DeprecatedWorkerNameWarning,
-                message_pattern="'slavedest' keyword argument is deprecated"):
-            step = transfer.StringDownload('srcfile', slavedest='dstfile')
-
         self.assertEqual(step.workerdest, 'dstfile')
 
     def test_init_workerdest_positional(self):
-        with assertNotProducesWarnings(DeprecatedWorkerAPIWarning):
-            step = transfer.StringDownload('srcfile', 'dstfile')
+        step = transfer.StringDownload('srcfile', 'dstfile')
 
         self.assertEqual(step.workerdest, 'dstfile')
 
     def test_init_positional_args(self):
-        self.assertRaises(TypeError, lambda: transfer.StringDownload())
-        self.assertRaises(
-            TypeError, lambda: transfer.StringDownload('srcfile'))
+        with self.assertRaises(TypeError):
+            transfer.StringDownload()
+        with self.assertRaises(TypeError):
+            transfer.StringDownload('srcfile')
 
 
 class TestJSONStringDownload(steps.BuildStepMixin, unittest.TestCase):
@@ -1095,6 +947,7 @@ class TestJSONStringDownload(steps.BuildStepMixin, unittest.TestCase):
     def tearDown(self):
         return self.tearDownBuildStep()
 
+    @defer.inlineCallbacks
     def testBasic(self):
         msg = dict(message="Hello World")
         self.setupStep(transfer.JSONStringDownload(msg, "hello.json"))
@@ -1116,12 +969,9 @@ class TestJSONStringDownload(steps.BuildStepMixin, unittest.TestCase):
 
         self.expectOutcome(
             result=SUCCESS, state_string="downloading to hello.json")
-        d = self.runStep()
+        yield self.runStep()
 
-        @d.addCallback
-        def checkCalls(res):
-            self.assertEqual(b''.join(read), b'{"message": "Hello World"}')
-        return d
+        self.assertEqual(b''.join(read), b'{"message": "Hello World"}')
 
     def testFailure(self):
         msg = dict(message="Hello World")
@@ -1138,43 +988,21 @@ class TestJSONStringDownload(steps.BuildStepMixin, unittest.TestCase):
             result=FAILURE, state_string="downloading to hello.json (failure)")
         return self.runStep()
 
-    def test_workerdest_old_api(self):
+    def test_init_workerdest_keyword(self):
         step = transfer.JSONStringDownload('srcfile', workerdest='dstfile')
 
-        with assertNotProducesWarnings(DeprecatedWorkerAPIWarning):
-            new = step.workerdest
-
-        with assertProducesWarning(
-                DeprecatedWorkerNameWarning,
-                message_pattern="'slavedest' attribute is deprecated"):
-            old = step.slavedest
-
-        self.assertIdentical(new, old)
-
-    def test_init_workerdest_new_api_no_warns(self):
-        with assertNotProducesWarnings(DeprecatedWorkerAPIWarning):
-            step = transfer.JSONStringDownload('srcfile', workerdest='dstfile')
-
-        self.assertEqual(step.workerdest, 'dstfile')
-
-    def test_init_workerdest_old_api_warns(self):
-        with assertProducesWarning(
-                DeprecatedWorkerNameWarning,
-                message_pattern="'slavedest' keyword argument is deprecated"):
-            step = transfer.JSONStringDownload('srcfile', slavedest='dstfile')
-
         self.assertEqual(step.workerdest, 'dstfile')
 
     def test_init_workerdest_positional(self):
-        with assertNotProducesWarnings(DeprecatedWorkerAPIWarning):
-            step = transfer.JSONStringDownload('srcfile', 'dstfile')
+        step = transfer.JSONStringDownload('srcfile', 'dstfile')
 
         self.assertEqual(step.workerdest, 'dstfile')
 
     def test_init_positional_args(self):
-        self.assertRaises(TypeError, lambda: transfer.JSONStringDownload())
-        self.assertRaises(
-            TypeError, lambda: transfer.JSONStringDownload('srcfile'))
+        with self.assertRaises(TypeError):
+            transfer.JSONStringDownload()
+        with self.assertRaises(TypeError):
+            transfer.JSONStringDownload('srcfile')
 
 
 class TestJSONPropertiesDownload(unittest.TestCase):
@@ -1203,7 +1031,7 @@ class TestJSONPropertiesDownload(unittest.TestCase):
                 self.assertEqual(kwargs['workerdest'], 'props.json')
                 reader = kwargs['reader']
                 data = reader.remote_read(100)
-                data = bytes2NativeString(data)
+                data = bytes2unicode(data)
                 actualJson = json.loads(data)
                 expectedJson = dict(sourcestamps=[ss.asDict()], properties={'key1': 'value1'})
                 self.assertEqual(actualJson, expectedJson)
@@ -1235,7 +1063,7 @@ class TestJSONPropertiesDownload(unittest.TestCase):
                 self.assertEqual(kwargs['slavedest'], 'props.json')
                 reader = kwargs['reader']
                 data = reader.remote_read(100)
-                data = bytes2NativeString(data)
+                data = bytes2unicode(data)
                 actualJson = json.loads(data)
                 expectedJson = dict(sourcestamps=[ss.asDict()], properties={'key1': 'value1'})
                 self.assertEqual(actualJson, expectedJson)
@@ -1243,38 +1071,16 @@ class TestJSONPropertiesDownload(unittest.TestCase):
         else:
             raise ValueError("No downloadFile command found")
 
-    def test_workerdest_old_api(self):
+    def test_init_workerdest_keyword(self):
         step = transfer.JSONPropertiesDownload(workerdest='dstfile')
 
-        with assertNotProducesWarnings(DeprecatedWorkerAPIWarning):
-            new = step.workerdest
-
-        with assertProducesWarning(
-                DeprecatedWorkerNameWarning,
-                message_pattern="'slavedest' attribute is deprecated"):
-            old = step.slavedest
-
-        self.assertIdentical(new, old)
-
-    def test_init_workerdest_new_api_no_warns(self):
-        with assertNotProducesWarnings(DeprecatedWorkerAPIWarning):
-            step = transfer.JSONPropertiesDownload(workerdest='dstfile')
-
-        self.assertEqual(step.workerdest, 'dstfile')
-
-    def test_init_workerdest_old_api_warns(self):
-        with assertProducesWarning(
-                DeprecatedWorkerNameWarning,
-                message_pattern="'slavedest' keyword argument is deprecated"):
-            step = transfer.JSONPropertiesDownload(slavedest='dstfile')
-
         self.assertEqual(step.workerdest, 'dstfile')
 
     def test_init_workerdest_positional(self):
-        with assertNotProducesWarnings(DeprecatedWorkerAPIWarning):
-            step = transfer.JSONPropertiesDownload('dstfile')
+        step = transfer.JSONPropertiesDownload('dstfile')
 
         self.assertEqual(step.workerdest, 'dstfile')
 
     def test_init_positional_args(self):
-        self.assertRaises(TypeError, lambda: transfer.JSONPropertiesDownload())
+        with self.assertRaises(TypeError):
+            transfer.JSONPropertiesDownload()
