@@ -14,16 +14,12 @@
 # Portions Copyright Buildbot Team Members
 # Portions Copyright 2014 Longaccess private company
 
-from __future__ import absolute_import
-from __future__ import print_function
-
 import os
 
 from twisted.trial import unittest
 
 from buildbot.test.util.decorators import flaky
 from buildbot.test.util.warnings import assertNotProducesWarnings
-from buildbot.test.util.warnings import assertProducesWarning
 from buildbot.test.util.warnings import assertProducesWarnings
 from buildbot.worker_transition import DeprecatedWorkerNameWarning
 
@@ -41,6 +37,12 @@ if boto3 is not None:
     from buildbot.worker import ec2  # pylint: disable=ungrouped-imports
 
 
+# Current moto (1.3.7) requires dummy credentials to work
+# https://github.com/spulec/moto/issues/1924
+os.environ['AWS_SECRET_ACCESS_KEY'] = 'foobar_secret'
+os.environ['AWS_ACCESS_KEY_ID'] = 'foobar_key'
+
+
 # redefine the mock_ec2 decorator to skip the test if boto3 or moto
 # isn't installed
 def skip_ec2(f):
@@ -93,19 +95,13 @@ class TestEC2LatentWorker(unittest.TestCase):
     def test_constructor_minimal(self):
         c, r = self.botoSetup('latent_buildbot_slave')
         amis = list(r.images.all())
-        with assertProducesWarnings(
-                DeprecatedWorkerNameWarning,
-                messages_patterns=[
-                    r"Use of default value of 'keypair_name' of "
-                    r"EC2LatentWorker constructor is deprecated",
-                    r"Use of default value of 'security_name' of "
-                    r"EC2LatentWorker constructor is deprecated"
-                ]):
-            bs = ec2.EC2LatentWorker('bot1', 'sekrit', 'm1.large',
-                                     identifier='publickey',
-                                     secret_identifier='privatekey',
-                                     ami=amis[0].id
-                                     )
+        bs = ec2.EC2LatentWorker('bot1', 'sekrit', 'm1.large',
+                                 identifier='publickey',
+                                 secret_identifier='privatekey',
+                                 keypair_name='keypair_name',
+                                 security_name='security_name',
+                                 ami=amis[0].id,
+                                 )
         self.assertEqual(bs.workername, 'bot1')
         self.assertEqual(bs.password, 'sekrit')
         self.assertEqual(bs.instance_type, 'm1.large')
@@ -116,20 +112,14 @@ class TestEC2LatentWorker(unittest.TestCase):
         c, r = self.botoSetup('latent_buildbot_slave')
         amis = list(r.images.all())
         tags = {'foo': 'bar'}
-        with assertProducesWarnings(
-                DeprecatedWorkerNameWarning,
-                messages_patterns=[
-                    r"Use of default value of 'keypair_name' of "
-                    r"EC2LatentWorker constructor is deprecated",
-                    r"Use of default value of 'security_name' of "
-                    r"EC2LatentWorker constructor is deprecated"
-                ]):
-            bs = ec2.EC2LatentWorker('bot1', 'sekrit', 'm1.large',
-                                     identifier='publickey',
-                                     secret_identifier='privatekey',
-                                     tags=tags,
-                                     ami=amis[0].id
-                                     )
+        bs = ec2.EC2LatentWorker('bot1', 'sekrit', 'm1.large',
+                                 identifier='publickey',
+                                 secret_identifier='privatekey',
+                                 keypair_name='keypair_name',
+                                 security_name='security_name',
+                                 tags=tags,
+                                 ami=amis[0].id,
+                                 )
         self.assertEqual(bs.tags, tags)
 
     @mock_ec2
@@ -161,7 +151,8 @@ class TestEC2LatentWorker(unittest.TestCase):
                                 subnet_id="sn-1234"
                                 )
 
-        self.assertRaises(ValueError, create_worker)
+        with self.assertRaises(ValueError):
+            create_worker()
 
     @mock_ec2
     def test_start_vpc_instance(self):
@@ -197,19 +188,13 @@ class TestEC2LatentWorker(unittest.TestCase):
     def test_start_instance(self):
         c, r = self.botoSetup()
         amis = list(r.images.all())
-        with assertProducesWarnings(
-                DeprecatedWorkerNameWarning,
-                messages_patterns=[
-                    r"Use of default value of 'keypair_name' of "
-                    r"EC2LatentWorker constructor is deprecated",
-                    r"Use of default value of 'security_name' of "
-                    r"EC2LatentWorker constructor is deprecated"
-                ]):
-            bs = ec2.EC2LatentWorker('bot1', 'sekrit', 'm1.large',
-                                     identifier='publickey',
-                                     secret_identifier='privatekey',
-                                     ami=amis[0].id
-                                     )
+        bs = ec2.EC2LatentWorker('bot1', 'sekrit', 'm1.large',
+                                 identifier='publickey',
+                                 secret_identifier='privatekey',
+                                 keypair_name='keypair_name',
+                                 security_name='security_name',
+                                 ami=amis[0].id
+                                 )
         bs._poll_resolution = 1
         instance_id, image_id, start_time = bs._start_instance()
         self.assertTrue(instance_id.startswith('i-'))
@@ -364,20 +349,14 @@ class TestEC2LatentWorker(unittest.TestCase):
         c, r = self.botoSetup('latent_buildbot_slave')
         amis = list(r.images.all())
         tags = {'foo': 'bar'}
-        with assertProducesWarnings(
-                DeprecatedWorkerNameWarning,
-                messages_patterns=[
-                    r"Use of default value of 'keypair_name' of "
-                    r"EC2LatentWorker constructor is deprecated",
-                    r"Use of default value of 'security_name' of "
-                    r"EC2LatentWorker constructor is deprecated"
-                ]):
-            bs = ec2.EC2LatentWorker('bot1', 'sekrit', 'm1.large',
-                                     identifier='publickey',
-                                     secret_identifier='privatekey',
-                                     tags=tags,
-                                     ami=amis[0].id
-                                     )
+        bs = ec2.EC2LatentWorker('bot1', 'sekrit', 'm1.large',
+                                 identifier='publickey',
+                                 secret_identifier='privatekey',
+                                 keypair_name="latent_buildbot_worker",
+                                 security_name='latent_buildbot_worker',
+                                 tags=tags,
+                                 ami=amis[0].id
+                                 )
         bs._poll_resolution = 0
         id, _, _ = bs._start_instance()
         instances = r.instances.filter(
@@ -385,7 +364,7 @@ class TestEC2LatentWorker(unittest.TestCase):
         instances = list(instances)
         self.assertEqual(len(instances), 1)
         self.assertEqual(instances[0].id, id)
-        self.assertEqual(instances[0].tags, [{u'Value': 'bar', u'Key': 'foo'}])
+        self.assertEqual(instances[0].tags, [{'Value': 'bar', 'Key': 'foo'}])
 
     @mock_ec2
     def test_start_instance_ip(self):
@@ -446,21 +425,15 @@ class TestEC2LatentWorker(unittest.TestCase):
         c, r = self.botoSetup('latent_buildbot_slave')
         amis = list(r.images.all())
         product_description = 'Linux/Unix'
-        with assertProducesWarnings(
-                DeprecatedWorkerNameWarning,
-                messages_patterns=[
-                    r"Use of default value of 'keypair_name' of "
-                    r"EC2LatentWorker constructor is deprecated",
-                    r"Use of default value of 'security_name' of "
-                    r"EC2LatentWorker constructor is deprecated"
-                ]):
-            bs = ec2.EC2LatentWorker('bot1', 'sekrit', 'm1.large',
-                                     identifier='publickey',
-                                     secret_identifier='privatekey',
-                                     ami=amis[0].id, spot_instance=True,
-                                     max_spot_price=1.5,
-                                     product_description=product_description
-                                     )
+        bs = ec2.EC2LatentWorker('bot1', 'sekrit', 'm1.large',
+                                 identifier='publickey',
+                                 secret_identifier='privatekey',
+                                 keypair_name='keypair_name',
+                                 security_name='security_name',
+                                 ami=amis[0].id, spot_instance=True,
+                                 max_spot_price=1.5,
+                                 product_description=product_description
+                                 )
         bs._poll_resolution = 0
         instance_id, _, _ = bs._start_instance()
         instances = r.instances.filter(
@@ -530,7 +503,8 @@ class TestEC2LatentWorker(unittest.TestCase):
                                 valid_ami_location_regex='foobar.*'
                                 )
 
-        self.assertRaises(ValueError, create_worker)
+        with self.assertRaises(ValueError):
+            create_worker()
 
     @mock_ec2
     def test_fail_multiplier_and_max_are_none(self):
@@ -552,7 +526,8 @@ class TestEC2LatentWorker(unittest.TestCase):
                                 price_multiplier=None,
                                 max_spot_price=None
                                 )
-        self.assertRaises(ValueError, create_worker)
+        with self.assertRaises(ValueError):
+            create_worker()
 
 
 class TestEC2LatentWorkerDefaultKeyairSecurityGroup(unittest.TestCase):
@@ -579,64 +554,6 @@ class TestEC2LatentWorkerDefaultKeyairSecurityGroup(unittest.TestCase):
         c.terminate_instances(InstanceIds=[instance.id])
         return c, r
 
-    @mock_ec2
-    def test_use_of_default_keypair_security_warning(self):
-        c, r = self.botoSetup()
-        amis = list(r.images.all())
-        with assertProducesWarnings(
-                DeprecatedWorkerNameWarning,
-                messages_patterns=[
-                    r"Use of default value of 'keypair_name' of "
-                    r"EC2LatentWorker constructor is deprecated",
-                    r"Use of default value of 'security_name' of "
-                    r"EC2LatentWorker constructor is deprecated"
-                ]):
-            bs = ec2.EC2LatentWorker('bot1', 'sekrit', 'm1.large',
-                                     identifier='publickey',
-                                     secret_identifier='privatekey',
-                                     ami=amis[0].id
-                                     )
-        self.assertEqual(bs.keypair_name, 'latent_buildbot_slave')
-        self.assertEqual(bs.security_name, 'latent_buildbot_slave')
-
-    @mock_ec2
-    def test_use_of_default_keypair_warning(self):
-        c, r = self.botoSetup()
-        amis = list(r.images.all())
-        with assertProducesWarnings(
-                DeprecatedWorkerNameWarning,
-                messages_patterns=[
-                    r"Use of default value of 'keypair_name' of "
-                    r"EC2LatentWorker constructor is deprecated",
-                ]):
-            bs = ec2.EC2LatentWorker('bot1', 'sekrit', 'm1.large',
-                                     identifier='publickey',
-                                     secret_identifier='privatekey',
-                                     ami=amis[0].id,
-                                     security_name='test_security_group',
-                                     )
-        self.assertEqual(bs.keypair_name, 'latent_buildbot_slave')
-        self.assertEqual(bs.security_name, 'test_security_group')
-
-    @mock_ec2
-    def test_use_of_default_security_warning(self):
-        c, r = self.botoSetup()
-        amis = list(r.images.all())
-        with assertProducesWarnings(
-                DeprecatedWorkerNameWarning,
-                messages_patterns=[
-                    r"Use of default value of 'security_name' of "
-                    r"EC2LatentWorker constructor is deprecated",
-                ]):
-            bs = ec2.EC2LatentWorker('bot1', 'sekrit', 'm1.large',
-                                     identifier='publickey',
-                                     secret_identifier='privatekey',
-                                     ami=amis[0].id,
-                                     keypair_name='test_keypair',
-                                     )
-        self.assertEqual(bs.keypair_name, 'test_keypair')
-        self.assertEqual(bs.security_name, 'latent_buildbot_slave')
-
     @mock_ec2
     def test_no_default_security_warning_when_security_group_ids(self):
         c, r = self.botoSetup()
@@ -665,16 +582,3 @@ class TestEC2LatentWorkerDefaultKeyairSecurityGroup(unittest.TestCase):
                                      )
         self.assertEqual(bs.keypair_name, 'test_keypair')
         self.assertEqual(bs.security_name, 'test_security_group')
-
-
-class TestWorkerTransition(unittest.TestCase):
-
-    def test_EC2LatentBuildSlave_deprecated(self):
-        from buildbot.worker.ec2 import EC2LatentWorker
-
-        with assertProducesWarning(
-                DeprecatedWorkerNameWarning,
-                message_pattern="EC2LatentBuildSlave was deprecated"):
-            from buildbot.buildslave.ec2 import EC2LatentBuildSlave
-
-        self.assertIdentical(EC2LatentBuildSlave, EC2LatentWorker)
