@@ -13,9 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-from future.builtins import range
 
 from twisted.internet import defer
 
@@ -130,7 +127,7 @@ class SchedulerMixin(interfaces.InterfaceTests):
 
                 self.assertTrue(self._parentMethodCalled,
                     "'%s' did not call its parent" % meth)
-                defer.returnValue(rv)
+                return rv
 
             setattr(scheduler, meth, newMethod)
 
@@ -194,7 +191,7 @@ class SchedulerMixin(interfaces.InterfaceTests):
         assert len(builderids) == len(builderNames)
         bsid = next(self._bsidGenerator)
         brids = dict(zip(builderids, self._bridGenerator))
-        defer.returnValue((bsid, brids))
+        return (bsid, brids)
 
     def fake_addBuildsetForSourceStampsWithDefaults(self, reason, sourcestamps=None,
                                                     waited_for=False, properties=None,
