@@ -19,8 +19,6 @@ linux dirwatcher API (if available) to look for new files. The
 relative to the top of the maildir (so it will look like "new/blahblah").
 """
 
-from __future__ import absolute_import
-from __future__ import print_function
 
 import os
 
