@@ -14,10 +14,6 @@
 # Portions Copyright Buildbot Team Members
 # Portions Copyright Canonical Ltd. 2009
 
-from __future__ import absolute_import
-from __future__ import print_function
-from future.utils import itervalues
-
 import time
 
 from twisted.internet import defer
@@ -33,7 +29,6 @@ from buildbot.status.worker import WorkerStatus
 from buildbot.util import bytes2unicode
 from buildbot.util import service
 from buildbot.util.eventual import eventually
-from buildbot.worker_transition import deprecatedWorkerClassProperty
 
 
 @implementer(IWorker)
@@ -59,6 +54,9 @@ class AbstractWorker(service.BuildbotService, object):
     DEFAULT_MISSING_TIMEOUT = 3600
     DEFAULT_KEEPALIVE_INTERVAL = 3600
 
+    # override to True if isCompatibleWithBuild may return False
+    builds_may_be_incompatible = False
+
     def checkConfig(self, name, password, max_builds=None,
                     notify_on_missing=None,
                     missing_timeout=None,
@@ -105,7 +103,6 @@ class AbstractWorker(service.BuildbotService, object):
 
         self.properties = Properties()
         self.properties.update(properties, "Worker")
-        self.properties.setProperty("slavename", name, "Worker (deprecated)")
         self.properties.setProperty("workername", name, "Worker")
 
         self.lastMessageReceived = 0
@@ -136,7 +133,6 @@ class AbstractWorker(service.BuildbotService, object):
     def workername(self):
         # workername is now an alias to twisted.Service's name
         return self.name
-    deprecatedWorkerClassProperty(locals(), workername)
 
     @property
     def botmaster(self):
@@ -274,7 +270,6 @@ class AbstractWorker(service.BuildbotService, object):
             properties = {}
         self.properties = Properties()
         self.properties.update(properties, "Worker")
-        self.properties.setProperty("slavename", name, "Worker (deprecated)")
         self.properties.setProperty("workername", name, "Worker")
 
         # update our records with the worker manager
@@ -313,6 +308,13 @@ class AbstractWorker(service.BuildbotService, object):
         yield self.master.data.updates.workerConfigured(self.workerid, self.master.masterid, [])
         yield service.BuildbotService.stopService(self)
 
+    def isCompatibleWithBuild(self, build_props):
+        # given a build properties object, determines whether the build is
+        # compatible with the currently running worker or not. This is most
+        # often useful for latent workers where it's possible to request
+        # different kinds of workers.
+        return defer.succeed(True)
+
     def startMissingTimer(self):
         if self.missing_timeout and self.parent and self.running:
             self.stopMissingTimer()  # in case it's already running
@@ -355,6 +357,8 @@ class AbstractWorker(service.BuildbotService, object):
     def attached(self, conn):
         """This is called when the worker connects."""
 
+        assert self.conn is None
+
         metrics.MetricCountEvent.log("AbstractWorker.attached_workers", 1)
 
         # now we go through a sequence of calls, gathering information, then
@@ -410,6 +414,11 @@ class AbstractWorker(service.BuildbotService, object):
 
     @defer.inlineCallbacks
     def detached(self):
+        # protect against race conditions in conn disconnect path and someone
+        # calling detached directly. At the moment the null worker does that.
+        if self.conn is None:
+            return
+
         metrics.MetricCountEvent.log("AbstractWorker.attached_workers", -1)
         self.conn = None
         self._old_builder_list = []
@@ -537,7 +546,7 @@ class AbstractWorker(service.BuildbotService, object):
             return False
 
         if self.max_builds:
-            active_builders = [wfb for wfb in itervalues(self.workerforbuilders)
+            active_builders = [wfb for wfb in self.workerforbuilders.values()
                                if wfb.isBusy()]
             if len(active_builders) >= self.max_builds:
                 return False
@@ -561,7 +570,7 @@ class AbstractWorker(service.BuildbotService, object):
         and has no active builders."""
         if not self._graceful:
             return
-        active_builders = [wfb for wfb in itervalues(self.workerforbuilders)
+        active_builders = [wfb for wfb in self.workerforbuilders.values()
                            if wfb.isBusy()]
         if active_builders:
             return
