@@ -13,8 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
 
 import hmac
 import json
@@ -48,6 +46,7 @@ class GitHubEventHandler(PullRequestMixin):
                  master=None,
                  skips=None,
                  github_api_endpoint=None,
+                 pullrequest_ref=None,
                  token=None,
                  debug=False,
                  verify=False):
@@ -55,6 +54,7 @@ class GitHubEventHandler(PullRequestMixin):
         self._strict = strict
         self._token = token
         self._codebase = codebase
+        self.pullrequest_ref = pullrequest_ref
         self.github_property_whitelist = github_property_whitelist
         self.skips = skips
         self.github_api_endpoint = github_api_endpoint
@@ -87,7 +87,7 @@ class GitHubEventHandler(PullRequestMixin):
             raise ValueError('Unknown event: {}'.format(event_type))
 
         result = yield defer.maybeDeferred(lambda: handler(payload, event_type))
-        defer.returnValue(result)
+        return result
 
     def _get_payload(self, request):
         content = request.content.read()
@@ -112,9 +112,17 @@ class GitHubEventHandler(PullRequestMixin):
             mac = hmac.new(unicode2bytes(self._secret),
                            msg=unicode2bytes(content),
                            digestmod=sha1)
-            # NOTE: hmac.compare_digest should be used, but it's only available
-            # starting Python 2.7.7
-            if mac.hexdigest() != hexdigest:
+
+            def _cmp(a, b):
+                try:
+                    # try the more secure compare_digest() first
+                    from hmac import compare_digest
+                    return compare_digest(a, b)
+                except ImportError:  # pragma: no cover
+                    # and fallback to the insecure simple comparison otherwise
+                    return a == b
+
+            if not _cmp(bytes2unicode(mac.hexdigest()), hexdigest):
                 raise ValueError('Hash mismatch')
 
         content_type = request.getHeader(b'Content-Type')
@@ -156,7 +164,7 @@ class GitHubEventHandler(PullRequestMixin):
     def handle_pull_request(self, payload, event):
         changes = []
         number = payload['number']
-        refname = 'refs/pull/{}/merge'.format(number)
+        refname = 'refs/pull/{}/{}'.format(number, self.pullrequest_ref)
         commits = payload['pull_request']['commits']
         title = payload['pull_request']['title']
         comments = payload['pull_request']['body']
@@ -170,12 +178,12 @@ class GitHubEventHandler(PullRequestMixin):
         if self._has_skip(head_msg):
             log.msg("GitHub PR #{}, Ignoring: "
                     "head commit message contains skip pattern".format(number))
-            defer.returnValue(([], 'git'))
+            return ([], 'git')
 
         action = payload.get('action')
         if action not in ('opened', 'reopened', 'synchronize'):
             log.msg("GitHub PR #{} {}, ignoring".format(number, action))
-            defer.returnValue((changes, 'git'))
+            return (changes, 'git')
 
         properties = self.extractProperties(payload['pull_request'])
         properties.update({'event': event})
@@ -189,7 +197,7 @@ class GitHubEventHandler(PullRequestMixin):
             'category': 'pull',
             # TODO: Get author name based on login id using txgithub module
             'author': payload['sender']['login'],
-            'comments': u'GitHub Pull Request #{0} ({1} commit{2})\n{3}\n{4}'.format(
+            'comments': 'GitHub Pull Request #{0} ({1} commit{2})\n{3}\n{4}'.format(
                 number, commits, 's' if commits != 1 else '', title, comments),
             'properties': properties,
         }
@@ -203,7 +211,7 @@ class GitHubEventHandler(PullRequestMixin):
 
         log.msg("Received {} changes from GitHub PR #{}".format(
             len(changes), number))
-        defer.returnValue((changes, 'git'))
+        return (changes, 'git')
 
     @defer.inlineCallbacks
     def _get_commit_msg(self, repo, sha):
@@ -223,8 +231,8 @@ class GitHubEventHandler(PullRequestMixin):
             debug=self.debug, verify=self.verify)
         res = yield http.get(url)
         data = yield res.json()
-        msg = data['commit']['message']
-        defer.returnValue(msg)
+        msg = data.get('commit', {'message': 'No message field'})['message']
+        return msg
 
     def _process_change(self, payload, user, repo, repo_url, project, event,
                         properties):
@@ -270,7 +278,7 @@ class GitHubEventHandler(PullRequestMixin):
             log.msg("New revision: {}".format(commit['id'][:8]))
 
             change = {
-                'author': u'{} <{}>'.format(commit['author']['name'],
+                'author': '{} <{}>'.format(commit['author']['name'],
                                            commit['author']['email']),
                 'files': files,
                 'comments': commit['message'],
@@ -327,6 +335,7 @@ class GitHubHandler(BaseHookHandler):
             'github_property_whitelist': options.get('github_property_whitelist', None),
             'skips': options.get('skips', None),
             'github_api_endpoint': options.get('github_api_endpoint', None) or 'https://api.github.com',
+            'pullrequest_ref': options.get('pullrequest_ref', None) or 'merge',
             'token': options.get('token', None),
             'debug': options.get('debug', None) or False,
             'verify': options.get('verify', None) or False,
