@@ -19,8 +19,6 @@
 Standard setup script.
 """
 
-from __future__ import absolute_import
-from __future__ import print_function
 
 import glob
 import inspect
@@ -155,17 +153,13 @@ setup_args = {
         'License :: OSI Approved :: GNU General Public License (GPL)',
         'Topic :: Software Development :: Build Tools',
         'Topic :: Software Development :: Testing',
-        'Programming Language :: Python :: 2',
-        'Programming Language :: Python :: 2.7',
         'Programming Language :: Python :: 3',
-        'Programming Language :: Python :: 3.4',
         'Programming Language :: Python :: 3.5',
         'Programming Language :: Python :: 3.6'
     ],
 
     'packages': [
         "buildbot",
-        "buildbot.buildslave",
         "buildbot.configurators",
         "buildbot.worker",
         "buildbot.worker.protocols",
@@ -209,9 +203,6 @@ setup_args = {
         "buildbot.test.unit",
     ]),
     'data_files': [
-        ("buildbot", [
-            "buildbot/buildbot.png",
-        ]),
         include("buildbot/reporters/templates", "*.txt"),
         ("buildbot/db/migrate", [
             "buildbot/db/migrate/migrate.cfg",
@@ -265,7 +256,7 @@ setup_args = {
             ('buildbot.worker.libvirt', ['LibVirtWorker']),
             ('buildbot.worker.openstack', ['OpenStackLatentWorker']),
             ('buildbot.worker.docker', ['DockerLatentWorker']),
-            ('buildbot.worker.hyper', ['HyperLatentWorker']),
+            ('buildbot.worker.kubernetes', ['KubeLatentWorker']),
             ('buildbot.worker.local', ['LocalWorker']),
         ]),
         ('buildbot.steps', [
@@ -392,6 +383,7 @@ setup_args = {
                 ('repo.DownloadsFromProperties',
                  'RepoDownloadsFromProperties')]),
             ('buildbot.steps.shellsequence', ['ShellArg']),
+            ('buildbot.util.kubeclientservice', ['KubeHardcodedConfig', 'KubeCtlProxyConfigLoader', 'KubeInClusterConfigLoader']),
             ('buildbot.www.avatar', ['AvatarGravatar']),
             ('buildbot.www.auth', [
                 'UserPasswordAuth', 'HTPasswdAuth', 'RemoteUserAuth', 'CustomAuth']),
@@ -434,10 +426,10 @@ setup_args = {
 if sys.platform == "win32":
     setup_args['zip_safe'] = False
 
-py_27 = sys.version_info[0] > 2 or (
-    sys.version_info[0] == 2 and sys.version_info[1] >= 7)
-if not py_27:
-    raise RuntimeError("Buildbot master requires at least Python-2.7")
+py_35 = sys.version_info[0] > 3 or (
+    sys.version_info[0] == 3 and sys.version_info[1] >= 5)
+if not py_35:
+    raise RuntimeError("Buildbot master requires at least Python-3.5")
 
 # pip<1.4 doesn't have the --pre flag, and will thus attempt to install alpha
 # and beta versions of Buildbot.  Prevent that from happening.
@@ -457,10 +449,7 @@ if 'a' in version or 'b' in version:
         if LooseVersion(pip_dist.version) < LooseVersion('1.4'):
             raise RuntimeError(VERSION_MSG)
 
-if sys.version_info[0] >= 3:
-    twisted_ver = ">= 17.9.0"
-else:
-    twisted_ver = ">= 16.1.0"
+twisted_ver = ">= 17.9.0"
 autobahn_ver = ">= 0.16.0"
 txaio_ver = ">= 2.2.2"
 
@@ -475,12 +464,13 @@ setup_args['install_requires'] = [
     'zope.interface >= 4.1.1',
     # python-future required for py2/3 compatibility
     'future',
-    'sqlalchemy>=0.8.0',
+    'sqlalchemy>=1.1.0',
     'sqlalchemy-migrate>=0.9',
     'python-dateutil>=1.5',
     'txaio ' + txaio_ver,
     'autobahn ' + autobahn_ver,
     'PyJWT',
+    'pyyaml'
 ]
 
 # Unit test dependencies.
@@ -539,7 +529,6 @@ setup_args['extras_require'] = {
         'docutils>=0.8',
         'sphinx-jinja',
         'towncrier',
-        'pyyaml'
     ],
 }
 
