@@ -82,11 +82,11 @@ def mTimeVersion(init_file):
     for root, dirs, files in os.walk(cwd):
         for f in files:
             m = max(os.path.getmtime(os.path.join(root, f)), m)
-    d = datetime.datetime.fromtimestamp(m)
+    d = datetime.datetime.utcfromtimestamp(m)
     return d.strftime("%Y.%m.%d")
 
 
-def getVersionFromArchiveId(git_archive_id='1535914132  (HEAD -> master, tag: v1.4.0)'):
+def getVersionFromArchiveId(git_archive_id='1549551369  (HEAD -> master, tag: v2.0.1)'):
     """ Extract the tag if a source is from git archive.
 
         When source is exported via `git archive`, the git_archive_id init value is modified
@@ -109,7 +109,7 @@ def getVersionFromArchiveId(git_archive_id='1535914132  (HEAD -> master, tag: v1
 
         # archived revision is not tagged, use the commit date
         tstamp = git_archive_id.strip().split()[0]
-        d = datetime.datetime.fromtimestamp(int(tstamp))
+        d = datetime.datetime.utcfromtimestamp(int(tstamp))
         return d.strftime('%Y.%m.%d')
     return None
 
@@ -205,10 +205,13 @@ class BuildJsCommand(distutils.cmd.Command):
             yarn_version = check_output("yarn --version")
             npm_version = check_output("npm -v")
             print("yarn:", yarn_version, "npm: ", npm_version)
-            npm_bin = check_output("npm bin").strip()
-            assert npm_version != "", "need nodejs and npm installed in current PATH"
-            assert LooseVersion(npm_version) >= LooseVersion(
-                "1.4"), "npm < 1.4 (%s)" % (npm_version)
+            if yarn_version != "":
+                npm_bin = check_output("yarn bin").strip()
+            else:
+                assert npm_version != "", "need nodejs and one of npm or yarn installed in current PATH"
+                assert LooseVersion(npm_version) >= LooseVersion(
+                    "1.4"), "npm < 1.4 (%s)" % (npm_version)
+                npm_bin = check_output("npm bin").strip()
 
             commands = []
 
