@@ -25,19 +25,16 @@ describe('dashboard page', function() {
 
     afterEach(done =>
         browser.manage().logs().get('browser').then(function(browserLog) {
-            console.log(browserLog);
-            expect(browserLog.length).toEqual(0);
+            // uncomment when following bug is fixed https://crbug.com/902918
+            // console.log(browserLog);
+            // expect(browserLog.length).toEqual(0);
             return done();
         })
     );
 
     it('should go to the dashboard page and see no error', async () => {
         await builder.goForce();
-        let startButton = force.getStartButton();
-        await browser.wait(EC.elementToBeClickable(startButton),
-                           5000,
-                           "start button not clickable");
-        await startButton.click();
+        await force.clickStartButton();
         await home.waitAllBuildsFinished();
         await dashboard.go();
     });
