@@ -2,6 +2,7 @@
 // will be called by the different tests
 
 import { BasePage } from "./base";
+import { ExpectedConditions as EC } from 'protractor';
 
 export class ForcePage extends BasePage {
     constructor() {
@@ -40,6 +41,22 @@ export class ForcePage extends BasePage {
         await this.setInputText("revision", RevisionName);
     }
 
+    async clickStartButton() {
+        let button = this.getStartButton();
+        await browser.wait(EC.elementToBeClickable(button),
+                           5000,
+                           "start button not clickable");
+        await button.click();
+    }
+
+    async clickCancelWholeQueue() {
+        let button = this.getCancelWholeQueue();
+        await browser.wait(EC.elementToBeClickable(button),
+                           5000,
+                           "cancel whole queue button not clickable");
+        await button.click();
+    }
+
     getStartButton() {
         return element(By.buttonText('Start Build'));
     }
@@ -49,7 +66,7 @@ export class ForcePage extends BasePage {
     }
 
     getCancelWholeQueue() {
-        return element(By.buttonText('Cancel Whole Queue'));
+        return element(By.buttonText('Cancel whole queue'));
     }
 
     getStopButton() {
