@@ -26,11 +26,7 @@ describe('rebuilds', function() {
         await builder.go();
         const lastbuild: number = await builder.getLastSuccessBuildNumber();
         await builder.goForce();
-        let startButton = force.getStartButton();
-        await browser.wait(EC.elementToBeClickable(startButton),
-                           5000,
-                           "start button not clickable");
-        await startButton.click();
+        await force.clickStartButton();
         await builder.go();
         await builder.waitNextBuildFinished(lastbuild);
         await builder.goBuild(lastbuild);
